@@ -2,51 +2,56 @@
  * Provides an API for the rest of the AI scripts to query the world state at a
  * higher level than the raw data.
  */
-var GameState = function(SharedScript, state, player) {
+var GameState = function() {
+	this.ai = null; // must be updated by the AIs.
+	this.cellSize = 4.0; // Size of each map tile
+
+	this.buildingsBuilt = 0;
+	this.turnCache = {};
+};
+
+GameState.prototype.init = function(SharedScript, state, player) {
 	this.sharedScript = SharedScript;
 	this.EntCollecNames = SharedScript._entityCollectionsName;
 	this.EntCollec = SharedScript._entityCollections;
-	this.timeElapsed = state.timeElapsed;
+	this.timeElapsed = SharedScript.timeElapsed;
 	this.templates = SharedScript._templates;
 	this.techTemplates = SharedScript._techTemplates;
 	this.entities = SharedScript.entities;
 	this.player = player;
-	this.playerData = state.players[player];
-	this.techModifications = SharedScript.techModifications[player];
-	this.buildingsBuilt = 0;
-	
-	this.ai = null; // must be updated by the AIs.
-	
-	this.cellSize = 4; // Size of each map tile
-	
-	this.turnCache = {};
+	this.playerData = this.sharedScript.playersData[this.player];
+	this.techModifications = SharedScript._techModifications[this.player];
 };
+
 GameState.prototype.update = function(SharedScript, state) {
 	this.sharedScript = SharedScript;
 	this.EntCollecNames = SharedScript._entityCollectionsName;
 	this.EntCollec = SharedScript._entityCollections;
-	this.timeElapsed = state.timeElapsed;
+	this.timeElapsed = SharedScript.timeElapsed;
 	this.templates = SharedScript._templates;
 	this.techTemplates = SharedScript._techTemplates;
+	this._entities = SharedScript._entities;
 	this.entities = SharedScript.entities;
-	this.playerData = state.players[this.player];
-	this.techModifications = SharedScript.techModifications[this.player];
+	this.playerData = SharedScript.playersData[this.player];
+	this.techModifications = SharedScript._techModifications[this.player];
 
 	this.buildingsBuilt = 0;
 	this.turnCache = {};
 };
 
-GameState.prototype.updatingCollection = function(id, filter, collection){
+GameState.prototype.updatingCollection = function(id, filter, collection, allowQuick){
 	// automatically add the player ID
 	id = this.player + "-" + id;
-		
 	if (!this.EntCollecNames[id]){
 		if (collection !== undefined)
 			this.EntCollecNames[id] = collection.filter(filter);
 		else {
 			this.EntCollecNames[id] = this.entities.filter(filter);
 		}
+		if (allowQuick)
+			this.EntCollecNames[id].allowQuickIter();
 		this.EntCollecNames[id].registerUpdates();
+		//	warn ("New Collection named " +id);
 	}
 	
 	return this.EntCollecNames[id];
@@ -69,13 +74,16 @@ GameState.prototype.getEC = function(id){
 	return undefined;
 };
 
-GameState.prototype.updatingGlobalCollection = function(id, filter, collection) {
+GameState.prototype.updatingGlobalCollection = function(id, filter, collection, allowQuick) {
 	if (!this.EntCollecNames[id]){
 		if (collection !== undefined)
 			this.EntCollecNames[id] = collection.filter(filter);
 		else
 			this.EntCollecNames[id] = this.entities.filter(filter);
+		if (allowQuick)
+			this.EntCollecNames[id].allowQuickIter();
 		this.EntCollecNames[id].registerUpdates();
+		//warn ("New Global Collection named " +id);
 	}
 	
 	return this.EntCollecNames[id];
@@ -105,6 +113,18 @@ GameState.prototype.currentPhase = function()
 	return 0;
 };
 
+GameState.prototype.townPhase = function()
+{
+	if (this.playerData.civ == "athen")
+		return "phase_town_athen";
+	return "phase_town_generic";
+};
+
+GameState.prototype.cityPhase = function()
+{
+	return "phase_city_generic";
+};
+
 GameState.prototype.isResearched = function(template)
 {
 	return this.playerData.researchedTechs[template] !== undefined;
@@ -228,6 +248,7 @@ GameState.prototype.getTemplate = function(type)
 GameState.prototype.applyCiv = function(str) {
 	return str.replace(/\{civ\}/g, this.playerData.civ);
 };
+
 GameState.prototype.civ = function() {
 	return this.playerData.civ;
 };
@@ -349,48 +370,56 @@ GameState.prototype.getEntityById = function(id){
 	return undefined;
 };
 
-GameState.prototype.getOwnEntitiesByMetadata = function(key, value){
-	return this.updatingCollection(key + "-" + value, Filters.byMetadata(this.player, key, value),this.getOwnEntities());
+GameState.prototype.getOwnEntitiesByMetadata = function(key, value, maintain){
+	if (maintain === true)
+		return this.updatingCollection(key + "-" + value, Filters.byMetadata(this.player, key, value),this.getOwnEntities());
+	return this.getOwnEntities().filter(Filters.byMetadata(this.player, key, value));
 };
 
 GameState.prototype.getOwnEntitiesByRole = function(role){
-	return this.getOwnEntitiesByMetadata("role", role);
+	return this.getOwnEntitiesByMetadata("role", role, true);
 };
 
 GameState.prototype.getOwnTrainingFacilities = function(){
-	return this.updatingCollection("own-training-facilities", Filters.byTrainingQueue(), this.getOwnEntities());
+	return this.updatingCollection("own-training-facilities", Filters.byTrainingQueue(), this.getOwnEntities(), true);
 };
 
 GameState.prototype.getOwnResearchFacilities = function(){
-	return this.updatingCollection("own-research-facilities", Filters.byResearchAvailable(), this.getOwnEntities());
+	return this.updatingCollection("own-research-facilities", Filters.byResearchAvailable(), this.getOwnEntities(), true);
 };
 
-GameState.prototype.getOwnEntitiesByType = function(type){
+GameState.prototype.getOwnEntitiesByType = function(type, maintain){
 	var filter = Filters.byType(type);
-	return this.updatingCollection("own-by-type-" + type, filter, this.getOwnEntities());
+	if (maintain === true)
+		return this.updatingCollection("own-by-type-" + type, filter, this.getOwnEntities());
+	return this.getOwnEntities().filter(filter);
+
 };
 
-GameState.prototype.countEntitiesByType = function(type) {
-	return this.getOwnEntitiesByType(type).length;
+GameState.prototype.countEntitiesByType = function(type, maintain) {
+	return this.getOwnEntitiesByType(type, maintain).length;
 };
 
 GameState.prototype.countEntitiesAndQueuedByType = function(type) {
-	var count = this.countEntitiesByType(type);
+	var count = this.countEntitiesByType(type, true);
 	
 	// Count building foundations
-	count += this.countEntitiesByType("foundation|" + type);
-	
-	// Count animal resources
-	count += this.countEntitiesByType("resource|" + type);
-
-	// Count entities in building production queues
-	this.getOwnTrainingFacilities().forEach(function(ent){
-		ent.trainingQueue().forEach(function(item) {
-			if (item.unitTemplate == type){
-				count += item.count;
-			}
+	if (this.getTemplate(type).hasClass("Structure") === true)
+		count += this.countEntitiesByType("foundation|" + type, true);
+	else if (this.getTemplate(type).resourceSupplyType() !== undefined)	// animal resources
+		count += this.countEntitiesByType("resource|" + type, true);
+	else
+	{
+		// Count entities in building production queues
+		// TODO: maybe this fails for corrals.
+		this.getOwnTrainingFacilities().forEach(function(ent){
+			ent.trainingQueue().forEach(function(item) {
+				if (item.unitTemplate == type){
+					count += item.count;
+				}
+			});
 		});
-	});
+	}
 	
 	return count;
 };
@@ -486,7 +515,7 @@ GameState.prototype.findResearchers = function(templateName, noRequirementCheck)
 	
 	return this.getOwnResearchFacilities().filter(function(ent) { //}){
 		var techs = ent.researchableTechs();
-		for (i in techs)
+		for (var i in techs)
 		{
 			var thisTemp = self.getTemplate(techs[i]);
 			if (thisTemp.pairDef())
@@ -508,11 +537,13 @@ GameState.prototype.getOwnFoundations = function() {
 };
 
 GameState.prototype.getOwnDropsites = function(resource){
-	return this.updatingCollection("dropsite-own-" + resource, Filters.isDropsite(resource), this.getOwnEntities());
+	if (resource !== undefined)
+		return this.updatingCollection("dropsite-own-" + resource, Filters.isDropsite(resource), this.getOwnEntities(), true);
+	return this.updatingCollection("dropsite-own", Filters.isDropsite(), this.getOwnEntities(), true);
 };
 
 GameState.prototype.getResourceSupplies = function(resource){
-	return this.updatingGlobalCollection("resource-" + resource, Filters.byResource(resource), this.getEntities());
+	return this.updatingGlobalCollection("resource-" + resource, Filters.byResource(resource), this.getEntities(), true);
 };
 
 GameState.prototype.getEntityLimits = function() {
@@ -527,10 +558,7 @@ GameState.prototype.getEntityCounts = function() {
 GameState.prototype.isEntityLimitReached = function(category) {
 	if(this.playerData.entityLimits[category] === undefined || this.playerData.entityCounts[category] === undefined)
 		return false;
-	if(this.playerData.entityLimits[category].LimitsPerCivCentre != undefined)
-		return (this.playerData.entityCounts[category] >= this.playerData.entityCounts["CivilCentre"]*this.playerData.entityLimits[category].LimitPerCivCentre);
-	else
-		return (this.playerData.entityCounts[category] >= this.playerData.entityLimits[category]);
+	return (this.playerData.entityCounts[category] >= this.playerData.entityLimits[category]);
 };
 
 GameState.prototype.findTrainableUnits = function(classes){
@@ -549,7 +577,7 @@ GameState.prototype.findTrainableUnits = function(classes){
 		var template = this.getTemplate(allTrainable[i]);
 		var okay = true;
 		
-		for (o in classes)
+		for (var o in classes)
 			if (!template.hasClass(classes[o]))
 				okay = false;
 		
@@ -589,7 +617,7 @@ GameState.prototype.findAvailableTech = function() {
 			if (this.canResearch(techs[1]._templateName))
 				ret.push([techs[1]._templateName, techs[1]] );
 		} else {
-			if (this.canResearch(allResearchable[i]) && template._templateName != "phase_town" && template._templateName != "phase_city_generic")
+			if (this.canResearch(allResearchable[i]) && template._templateName != this.townPhase() && template._templateName != this.cityPhase())
 				ret.push( [allResearchable[i], template] );
 		}
 	}
