@@ -395,7 +395,7 @@ EconomyManager.prototype.buildMarket = function(gameState, queues){
 	if (gameState.getTimeElapsed() > 600 * 1000){
 		if (queues.economicBuilding.totalLength() === 0 && 
 			gameState.countEntitiesAndQueuedByType(gameState.applyCiv("structures/{civ}_market")) === 0){ 
-			//only ever build one mill/CC/market at a time
+			//only ever build one storehouse/CC/market at a time
 			queues.economicBuilding.addItem(new BuildingConstructionPlan(gameState, "structures/{civ}_market"));
 		}
 	}
@@ -403,9 +403,9 @@ EconomyManager.prototype.buildMarket = function(gameState, queues){
 
 EconomyManager.prototype.buildDropsites = function(gameState, queues){
 	if (queues.economicBuilding.totalLength() === 0 && 
-			gameState.countFoundationsWithType(gameState.applyCiv("structures/{civ}_mill")) === 0 &&
+			gameState.countFoundationsWithType(gameState.applyCiv("structures/{civ}_storehouse")) === 0 &&
 			gameState.countFoundationsWithType(gameState.applyCiv("structures/{civ}_civil_centre")) === 0){ 
-			//only ever build one mill/CC/market at a time
+			//only ever build one storehouse/CC/market at a time
 		if (gameState.getTimeElapsed() > 30 * 1000){
 			for (var resource in this.dropsiteNumbers){
 				if (this.checkResourceConcentrations(gameState, resource) < this.dropsiteNumbers[resource]){
@@ -424,7 +424,7 @@ EconomyManager.prototype.buildDropsites = function(gameState, queues){
 					if (myCivCentres.length === 0){
 						queues.economicBuilding.addItem(new BuildingConstructionPlan(gameState, "structures/{civ}_civil_centre", spot));
 					}else{
-						queues.economicBuilding.addItem(new BuildingConstructionPlan(gameState, "structures/{civ}_mill", spot));
+						queues.economicBuilding.addItem(new BuildingConstructionPlan(gameState, "structures/{civ}_storehouse", spot));
 					}
 					break;
 				}
