@@ -1,4 +1,3 @@
-
 function initMusic()
 {
 	// Probably will need to put this in a place where it won't get
@@ -25,18 +24,10 @@ function Music()
 		PEACE: "peace",
 		BATTLE: "battle",
 		VICTORY: "victory",
-		DEFEAT: "defeat",
-		DEFEAT_CUE: "defeat_cue"
+		DEFEAT: "defeat"
 	};
 
-	this.tracks = {
-		MENU: ["Honor_Bound.ogg"],
-		PEACE: [],
-		BATTLE: ["Taiko_1.ogg", "Taiko_2.ogg"],
-		VICTORY : ["You_are_Victorious!.ogg"],
-		DEFEAT : ["Dried_Tears.ogg"],
-		DEFEAT_CUE : ["gen_loss_cue.ogg"]
-	};
+	this.resetTracks();
 
 	this.states = {
 		OFF : 0,
@@ -44,8 +35,7 @@ function Music()
 		PEACE : 2,
 		BATTLE : 3,
 		VICTORY :4,
-		DEFEAT : 5,
-		DEFEAT_CUE : 6
+		DEFEAT : 5
 	};
 
 	this.musicGain = 0.3;
@@ -53,13 +43,22 @@ function Music()
 	this.currentState = 0;
 	this.oldState = 0;
 
-	this.currentMusic = null;
-
 	// timer for delay between tracks
 	this.timer = [];
 	this.time = Date.now();
 }
 
+Music.prototype.resetTracks = function()
+{
+	this.tracks = {
+		MENU: ["Honor_Bound.ogg"],
+		PEACE: [],
+		BATTLE: ["Taiko_1.ogg", "Taiko_2.ogg"],
+		VICTORY : ["You_are_Victorious!.ogg"],
+		DEFEAT : ["Dried_Tears.ogg"]
+	};
+};
+
 // "reference" refers to this instance of Music (needed if called from the timer)
 Music.prototype.setState = function(state)
 {
@@ -76,11 +75,7 @@ Music.prototype.updateState = function()
 		switch (this.currentState)
 		{
 		case this.states.OFF:
-			if (this.isPlaying())
-			{
-				var thePlayer = SoundPlayer();
-				thePlayer.stopMusic();
-			}
+			Engine.StopMusic();
 			break;
 
 		case this.states.MENU:
@@ -88,24 +83,19 @@ Music.prototype.updateState = function()
 			break;
 
 		case this.states.PEACE:
-			this.switchMusic(this.getRandomTrack(this.tracks.PEACE), 3.0, true);
+			this.startPlayList(this.tracks.PEACE, 3.0, true);
 			break;
 
 		case this.states.BATTLE:
-			this.switchMusic(this.getRandomTrack(this.tracks.BATTLE), 2.0, true);
+			this.startPlayList(this.tracks.BATTLE, 2.0, true);
 			break;
 
 		case this.states.VICTORY:
-			this.switchMusic(this.getRandomTrack(this.tracks.VICTORY), 2.0, true);
+			this.startPlayList(this.tracks.VICTORY, 2.0, true);
 			break;
 
 		case this.states.DEFEAT:
-			this.switchMusic(this.getRandomTrack(this.tracks.DEFEAT), 2.0, true);
-			break;
-
-		case this.states.DEFEAT_CUE:
-			this.switchMusic(this.getRandomTrack(this.tracks.DEFEAT_CUE), 2.0, false);
-			this.setDelay(this.states.DEFEAT, 7000);
+			this.startPlayList(this.tracks.DEFEAT, 2.0, true);
 			break;
 
 		default:
@@ -117,6 +107,7 @@ Music.prototype.updateState = function()
 
 Music.prototype.storeTracks = function(civMusic)
 {
+	this.resetTracks();
 	for each (var music in civMusic)
 	{
 		var type = undefined;
@@ -144,35 +135,32 @@ Music.prototype.getRandomTrack = function(tracks)
 	return tracks[getRandom(0, tracks.length-1)];
 };
 
+Music.prototype.startPlayList = function(tracks, fadeInPeriod, isLooping)
+{
+	Engine.ClearPlaylist();
+	for (var i in tracks)
+	{
+		Engine.AddPlaylistItem( this.RELATIVE_MUSIC_PATH + tracks[i] );
+	}
+
+	Engine.StartPlaylist(isLooping);
+};
+
 Music.prototype.switchMusic = function(track, fadeInPeriod, isLooping)
 {
-	this.currentMusic = new MusicSound(this.RELATIVE_MUSIC_PATH + track);
-
-	if (this.currentMusic)
-	{
-		if (isLooping)
-			this.currentMusic.loop();
-		else
-			this.currentMusic.play();
-	}
+  Engine.ClearPlaylist();
+	Engine.AddPlaylistItem( this.RELATIVE_MUSIC_PATH + track );
+	Engine.StartPlaylist(isLooping);
 };
 
 Music.prototype.isPlaying = function()
 {
-	if (!this.currentMusic)
-		return false;
-
-	// should return whether there is a valid handle; gain and fade do this also
-	// However, if looping is not set, then it always returns false because the
-	// handle is immediately cleared out
-//	return this.currentMusic.isPlaying();
-	return true;
+	return Engine.MusicPlaying();
 };
 
 Music.prototype.start = function()
 {
-	var thePlayer = SoundPlayer();
-	thePlayer.startMusic();
+	Engine.StartMusic();
 	this.setState(this.states.PEACE);
 };
 
@@ -181,31 +169,3 @@ Music.prototype.stop = function()
 	this.setState(this.states.OFF);
 };
 
-// =============================================================================
-// This allows for delays between tracks
-// =============================================================================
-Music.prototype.setDelay = function(state, delay)
-{
-	this.timer = [this.time + delay, state];
-};
-
-Music.prototype.stopTimer = function()
-{
-	this.timer = null;
-};
-
-// Needs to be called in onTick() to work
-Music.prototype.updateTimer = function()
-{
-	this.time = Date.now();
-
-	if (this.timer && (this.timer[0] <= this.time))
-	{
-		// Setting to OFF first guarantees that a state
-		// change will take place even if the current
-		// state is the same as the new state
-		this.reference.setState(this.states.OFF);
-		this.reference.setState(this.timer[1]);
-		this.stopTimer();
-	}
-};
\ No newline at end of file
