@@ -34,6 +34,7 @@ Armour.prototype.Schema =
 
 Armour.prototype.Init = function()
 {
+	this.nextAlertTime = 0;
 	this.invulnerable = false;
 };
 
@@ -42,20 +43,35 @@ Armour.prototype.SetInvulnerability = function(invulnerability)
 	this.invulnerable = invulnerability;
 };
 
-Armour.prototype.TakeDamage = function(hack, pierce, crush)
+/**
+ * Take damage according to the entity's armor.
+ * Returns object of the form { "killed": false, "change": -12 }
+ */
+Armour.prototype.TakeDamage = function(hack, pierce, crush, source)
 {
+	// Alert target owner of attack
+	var cmpOwnership = Engine.QueryInterface(this.entity, IID_Ownership);
+	var cmpAttackDetection = QueryPlayerIDInterface(cmpOwnership.GetOwner(), IID_AttackDetection);
+	var cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
+	var now = cmpTimer.GetTime();
+	if (now > this.nextAlertTime)
+	{
+		this.nextAlertTime = now + cmpAttackDetection.GetSuppressionTime();
+		cmpAttackDetection.AttackAlert(this.entity, source);
+	}
+
 	if (this.invulnerable) 
-		return { "killed": false };
+		return { "killed": false, "change": 0 };
 
-	// Adjust damage values based on armour
+	// Adjust damage values based on armour; exponential armour: damage = attack * 0.9^armour
 	var armourStrengths = this.GetArmourStrengths();
-	var adjHack = Math.max(0, hack - armourStrengths.hack);
-	var adjPierce = Math.max(0, pierce - armourStrengths.pierce);
-	var adjCrush = Math.max(0, crush - armourStrengths.crush);
+	var adjHack = hack * Math.pow(0.9, armourStrengths.hack);
+	var adjPierce = pierce * Math.pow(0.9, armourStrengths.pierce);
+	var adjCrush = crush * Math.pow(0.9, armourStrengths.crush);
 
-	// Total is sum of individual damages, with minimum damage 1
-	//	Round to nearest integer, since HP is integral
-	var total = Math.max(1, Math.round(adjHack + adjPierce + adjCrush));
+	// Total is sum of individual damages
+	// Don't bother rounding, since HP is no longer integral.
+	var total = Math.max(1, adjHack + adjPierce + adjCrush);
 
 	// Reduce health
 	var cmpHealth = Engine.QueryInterface(this.entity, IID_Health);
@@ -67,7 +83,7 @@ Armour.prototype.GetArmourStrengths = function()
 	// Work out the armour values with technology effects
 	var self = this;
 	
-	var applyTechs = function(type, foundation)
+	var applyMods = function(type, foundation)
 	{
 		var strength;
 		if (foundation) 
@@ -80,26 +96,24 @@ Armour.prototype.GetArmourStrengths = function()
 			strength = +self.template[type];
 		}
 		
-		// All causes caching problems so disable it for now.
-		// var allComponent = ApplyTechModificationsToEntity("Armour/All", strength, self.entity) - self.template[type];
-		strength = ApplyTechModificationsToEntity("Armour/" + type, strength, self.entity);
+		strength = ApplyValueModificationsToEntity("Armour/" + type, strength, self.entity);
 		return strength;
 	};
 	
 	if (Engine.QueryInterface(this.entity, IID_Foundation) && this.template.Foundation) 
 	{
 		return {
-			hack: applyTechs("Hack", true),
-			pierce: applyTechs("Pierce", true),
-			crush: applyTechs("Crush", true)
+			hack: applyMods("Hack", true),
+			pierce: applyMods("Pierce", true),
+			crush: applyMods("Crush", true)
 		};
 	}
 	else
 	{
 		return {
-			hack: applyTechs("Hack"),
-			pierce: applyTechs("Pierce"),
-			crush: applyTechs("Crush")
+			hack: applyMods("Hack"),
+			pierce: applyMods("Pierce"),
+			crush: applyMods("Crush")
 		};
 	}
 };
