@@ -20,7 +20,7 @@ var bonusesSchema =
 
 var preferredClassesSchema =
 	"<optional>" +
-		"<element name='PreferredClasses' a:help='Space delimited list of classes preferred for attacking. If an entity has any of theses classes, it is preferred. The classes are in decending order of preference.'>" +
+		"<element name='PreferredClasses' a:help='Space delimited list of classes preferred for attacking. If an entity has any of theses classes, it is preferred. The classes are in decending order of preference'>" +
 			"<attribute name='datatype'>" +
 				"<value>tokens</value>" +
 			"</attribute>" +
@@ -67,6 +67,7 @@ Attack.prototype.Schema =
 			"<Crush>0.0</Crush>" +
 			"<MaxRange>44.0</MaxRange>" +
 			"<MinRange>20.0</MinRange>" +
+			"<ElevationBonus>15.0</ElevationBonus>" +
 			"<PrepareTime>800</PrepareTime>" +
 			"<RepeatTime>1600</RepeatTime>" +
 			"<ProjectileSpeed>50.0</ProjectileSpeed>" +
@@ -125,6 +126,9 @@ Attack.prototype.Schema =
 				"<element name='Crush' a:help='Crush damage strength'><ref name='nonNegativeDecimal'/></element>" +
 				"<element name='MaxRange' a:help='Maximum attack range (in metres)'><ref name='nonNegativeDecimal'/></element>" +
 				"<element name='MinRange' a:help='Minimum attack range (in metres)'><ref name='nonNegativeDecimal'/></element>" +
+				"<optional>"+
+					"<element name='ElevationBonus' a:help='give an elevation advantage (in meters)'><ref name='nonNegativeDecimal'/></element>" +
+				"</optional>" +
 				"<element name='PrepareTime' a:help='Time from the start of the attack command until the attack actually occurs (in milliseconds). This value relative to RepeatTime should closely match the \"event\" point in the actor&apos;s attack animation'>" +
 					"<data type='nonNegativeInteger'/>" +
 				"</element>" +
@@ -199,7 +203,8 @@ Attack.prototype.GetAttackTypes = function()
 
 Attack.prototype.GetPreferredClasses = function(type)
 {
-	if (this.template[type] && this.template[type].PreferredClasses)
+	if (this.template[type] && this.template[type].PreferredClasses
+	    && this.template[type].PreferredClasses._string)
 	{
 		return this.template[type].PreferredClasses._string.split(/\s+/);
 	}
@@ -208,7 +213,8 @@ Attack.prototype.GetPreferredClasses = function(type)
 
 Attack.prototype.GetRestrictedClasses = function(type)
 {
-	if (this.template[type] && this.template[type].RestrictedClasses)
+	if (this.template[type] && this.template[type].RestrictedClasses
+	    && this.template[type].RestrictedClasses._string)
 	{
 		return this.template[type].RestrictedClasses._string.split(/\s+/);
 	}
@@ -255,7 +261,7 @@ Attack.prototype.GetPreference = function(target)
 		return undefined;
 
 	const targetClasses = cmpIdentity.GetClassesList();
-	
+
 	var minPref = null;
 	for each (var type in this.GetAttackTypes())
 	{
@@ -294,7 +300,7 @@ Attack.prototype.GetBestAttackAgainst = function(target)
 	const isAllowed = function (value, i, a) { return !attack.GetRestrictedClasses(value).some(isTargetClass); }
 	const isPreferred = function (value, i, a) { return attack.GetPreferredClasses(value).some(isTargetClass); }
 	const byPreference = function (a, b) { return (types.indexOf(a) + (isPreferred(a) ? types.length : 0) ) - (types.indexOf(b) + (isPreferred(b) ? types.length : 0) ); }
-	
+
 	// Always slaughter domestic animals instead of using a normal attack
 	if (isTargetClass("Domestic") && this.template.Slaughter) 
 		return "Slaughter";
@@ -316,10 +322,10 @@ Attack.prototype.CompareEntitiesByPreference = function(a, b)
 Attack.prototype.GetTimers = function(type)
 {
 	var prepare = +(this.template[type].PrepareTime || 0);
-	prepare = ApplyTechModificationsToEntity("Attack/" + type + "/PrepareTime", prepare, this.entity);
+	prepare = ApplyValueModificationsToEntity("Attack/" + type + "/PrepareTime", prepare, this.entity);
 	
 	var repeat = +(this.template[type].RepeatTime || 1000);
-	repeat = ApplyTechModificationsToEntity("Attack/" + type + "/RepeatTime", repeat, this.entity);
+	repeat = ApplyValueModificationsToEntity("Attack/" + type + "/RepeatTime", repeat, this.entity);
 
 	return { "prepare": prepare, "repeat": repeat, "recharge": repeat - prepare };
 };
@@ -328,7 +334,7 @@ Attack.prototype.GetAttackStrengths = function(type)
 {
 	// Work out the attack values with technology effects
 	var self = this;
-	
+
 	var template = this.template[type];
 	var splash = "";
 	if (!template)
@@ -337,29 +343,30 @@ Attack.prototype.GetAttackStrengths = function(type)
 		splash = "/Splash";
 	}
 	
-	var applyTechs = function(damageType)
+	var applyMods = function(damageType)
 	{
-		// All causes caching problems so disable it for now.
-		//var allComponent = ApplyTechModificationsToEntity("Attack/" + type + splash + "/All", +(template[damageType] || 0), self.entity) - self.template[type][damageType];
-		return ApplyTechModificationsToEntity("Attack/" + type + splash + "/" + damageType, +(template[damageType] || 0), self.entity);
+		return ApplyValueModificationsToEntity("Attack/" + type + splash + "/" + damageType, +(template[damageType] || 0), self.entity);
 	};
 	
 	return {
-		hack: applyTechs("Hack"),
-		pierce: applyTechs("Pierce"),
-		crush: applyTechs("Crush")
+		hack: applyMods("Hack"),
+		pierce: applyMods("Pierce"),
+		crush: applyMods("Crush")
 	};
 };
 
 Attack.prototype.GetRange = function(type)
 {
 	var max = +this.template[type].MaxRange;
-	max = ApplyTechModificationsToEntity("Attack/" + type + "/MaxRange", max, this.entity);
+	max = ApplyValueModificationsToEntity("Attack/" + type + "/MaxRange", max, this.entity);
 	
 	var min = +(this.template[type].MinRange || 0);
-	min = ApplyTechModificationsToEntity("Attack/" + type + "/MinRange", min, this.entity);
+	min = ApplyValueModificationsToEntity("Attack/" + type + "/MinRange", min, this.entity);
+
+	var elevationBonus = +(this.template[type].ElevationBonus || 0);
+	elevationBonus = ApplyValueModificationsToEntity("Attack/" + type + "/ElevationBonus", elevationBonus, this.entity);
 	
-	return { "max": max, "min": min };
+	return { "max": max, "min": min, "elevationBonus": elevationBonus};
 };
 
 // Calculate the attack damage multiplier against a target
@@ -369,18 +376,18 @@ Attack.prototype.GetAttackBonus = function(type, target)
 	var template = this.template[type];
 	if (!template)
 		template = this.template[type.split(".")[0]].Splash;
-	
+
 	if (template.Bonuses)
 	{
 		var cmpIdentity = Engine.QueryInterface(target, IID_Identity);
 		if (!cmpIdentity)
 			return 1;
-		
+
 		// Multiply the bonuses for all matching classes
 		for (var key in template.Bonuses)
 		{
 			var bonus = template.Bonuses[key];
-			
+
 			var hasClasses = true;
 			if (bonus.Classes){
 				var classes = bonus.Classes.split(/\s+/);
@@ -392,21 +399,21 @@ Attack.prototype.GetAttackBonus = function(type, target)
 				attackBonus *= bonus.Multiplier;
 		}
 	}
-	
+
 	return attackBonus;
 };
 
 // Returns a 2d random distribution scaled for a spread of scale 1.
 // The current implementation is a 2d gaussian with sigma = 1
 Attack.prototype.GetNormalDistribution = function(){
-	
+
 	// Use the Box-Muller transform to get a gaussian distribution
 	var a = Math.random();
 	var b = Math.random();
-	
+
 	var c = Math.sqrt(-2*Math.log(a)) * Math.cos(2*Math.PI*b);
 	var d = Math.sqrt(-2*Math.log(a)) * Math.sin(2*Math.PI*b);
-	
+
 	return [c, d];
 };
 
@@ -427,12 +434,12 @@ Attack.prototype.PerformAttack = function(type, target)
 		// Get some data about the entity
 		var horizSpeed = +this.template[type].ProjectileSpeed;
 		var gravity = 9.81; // this affects the shape of the curve; assume it's constant for now
-		
-		var spread = this.template.Ranged.Spread;
-		spread = ApplyTechModificationsToEntity("Attack/Ranged/Spread", spread, this.entity);
-		
+
+		var spread = +this.template.Ranged.Spread;
+		spread = ApplyValueModificationsToEntity("Attack/Ranged/Spread", spread, this.entity);
+
 		//horizSpeed /= 2; gravity /= 2; // slow it down for testing
-		
+
 		var cmpPosition = Engine.QueryInterface(this.entity, IID_Position);
 		if (!cmpPosition || !cmpPosition.IsInWorld())
 			return;
@@ -441,74 +448,57 @@ Attack.prototype.PerformAttack = function(type, target)
 		if (!cmpTargetPosition || !cmpTargetPosition.IsInWorld())
 			return;
 		var targetPosition = cmpTargetPosition.GetPosition();
-		
+
 		var relativePosition = {"x": targetPosition.x - selfPosition.x, "z": targetPosition.z - selfPosition.z}
 		var previousTargetPosition = Engine.QueryInterface(target, IID_Position).GetPreviousPosition();
-		
+
 		var targetVelocity = {"x": (targetPosition.x - previousTargetPosition.x) / this.turnLength, "z": (targetPosition.z - previousTargetPosition.z) / this.turnLength}
 		// the component of the targets velocity radially away from the archer
 		var radialSpeed = this.VectorDot(relativePosition, targetVelocity) / this.VectorLength(relativePosition);
-		
+
 		var horizDistance = this.VectorDistance(targetPosition, selfPosition);
-		
+
 		// This is an approximation of the time ot the target, it assumes that the target has a constant radial 
 		// velocity, but since units move in straight lines this is not true.  The exact value would be more 
 		// difficult to calculate and I think this is sufficiently accurate.  (I tested and for cavalry it was 
 		// about 5% of the units radius out in the worst case)
 		var timeToTarget = horizDistance / (horizSpeed - radialSpeed);
-		
+
 		// Predict where the unit is when the missile lands.
 		var predictedPosition = {"x": targetPosition.x + targetVelocity.x * timeToTarget,
 		                         "z": targetPosition.z + targetVelocity.z * timeToTarget};
-		
+
 		// Compute the real target point (based on spread and target speed)
 		var randNorm = this.GetNormalDistribution();
 		var offsetX = randNorm[0] * spread * (1 + this.VectorLength(targetVelocity) / 20);
 		var offsetZ = randNorm[1] * spread * (1 + this.VectorLength(targetVelocity) / 20);
 
 		var realTargetPosition = { "x": predictedPosition.x + offsetX, "y": targetPosition.y, "z": predictedPosition.z + offsetZ };
-		
+
 		// Calculate when the missile will hit the target position
 		var realHorizDistance = this.VectorDistance(realTargetPosition, selfPosition);
 		var timeToTarget = realHorizDistance / horizSpeed;
-		
+
 		var missileDirection = {"x": (realTargetPosition.x - selfPosition.x) / realHorizDistance, "z": (realTargetPosition.z - selfPosition.z) / realHorizDistance};
-		
+
 		// Make the arrow appear to land slightly behind the target so that arrows landing next to a guys foot don't count but arrows that go through the torso do
 		var graphicalPosition = {"x": realTargetPosition.x + 2*missileDirection.x, "y": realTargetPosition.y + 2*missileDirection.y};
 		// Launch the graphical projectile
 		var cmpProjectileManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_ProjectileManager);
 		var id = cmpProjectileManager.LaunchProjectileAtPoint(this.entity, realTargetPosition, horizSpeed, gravity);
-		
+
+		var playerId = Engine.QueryInterface(this.entity, IID_Ownership).GetOwner()
 		var cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
- 		cmpTimer.SetTimeout(this.entity, IID_Attack, "MissileHit", timeToTarget*1000, {"type": type, "target": target, "position": realTargetPosition, "direction": missileDirection, "projectileId": id});
+ 		cmpTimer.SetTimeout(this.entity, IID_Attack, "MissileHit", timeToTarget*1000, {"type": type, "target": target, "position": realTargetPosition, "direction": missileDirection, "projectileId": id, "playerId":playerId});
 	}
 	else
 	{
 		// Melee attack - hurt the target immediately
-		this.CauseDamage({"type": type, "target": target});
+		Damage.CauseDamage({"strengths":this.GetAttackStrengths(type), "target":target, "attacker":this.entity, "multiplier":this.GetAttackBonus(type, target), "type":type});
 	}
 	// TODO: charge attacks (need to design how they work)
 };
 
-/**
- * Called when some units kills something (another unit, building, animal etc)
- */
-Attack.prototype.TargetKilled = function(killerEntity, targetEntity)
-{
-	var cmpKillerPlayerStatisticsTracker = QueryOwnerInterface(killerEntity, IID_StatisticsTracker);
-	if (cmpKillerPlayerStatisticsTracker) cmpKillerPlayerStatisticsTracker.KilledEntity(targetEntity);
-	var cmpTargetPlayerStatisticsTracker = QueryOwnerInterface(targetEntity, IID_StatisticsTracker);
-	if (cmpTargetPlayerStatisticsTracker) cmpTargetPlayerStatisticsTracker.LostEntity(targetEntity);
-
-	// if unit can collect loot, lets try to collect it
-	var cmpLooter = Engine.QueryInterface(killerEntity, IID_Looter);
-	if (cmpLooter)
-	{
-		cmpLooter.Collect(targetEntity);
-	}
-};
-
 Attack.prototype.InterpolatedLocation = function(ent, lateness)
 {
 	var cmpTargetPosition = Engine.QueryInterface(ent, IID_Position);
@@ -531,11 +521,6 @@ Attack.prototype.VectorDot = function(p1, p2)
 	return (p1.x * p2.x + p1.z * p2.z);
 };
 
-Attack.prototype.VectorCross = function(p1, p2)
-{
-	return (p1.x * p2.z - p1.z * p2.x);
-};
-
 Attack.prototype.VectorLength = function(p)
 {
 	return Math.sqrt(p.x*p.x + p.z*p.z);
@@ -551,10 +536,10 @@ Attack.prototype.testCollision = function(ent, point, lateness)
 	if (!cmpFootprint)
 		return false;
 	var targetShape = cmpFootprint.GetShape();
-	
+
 	if (!targetShape || !targetPosition)
 		return false;
-	
+
 	if (targetShape.type === 'circle')
 	{
 		return (this.VectorDistance(point, targetPosition) < targetShape.radius);
@@ -562,13 +547,13 @@ Attack.prototype.testCollision = function(ent, point, lateness)
 	else
 	{
 		var targetRotation = Engine.QueryInterface(ent, IID_Position).GetRotation().y;
-		
+
 		var dx = point.x - targetPosition.x;
 		var dz = point.z - targetPosition.z;
-		
+
 		var dxr = Math.cos(targetRotation) * dx - Math.sin(targetRotation) * dz;
 		var dzr = Math.sin(targetRotation) * dx + Math.cos(targetRotation) * dz;
-		
+
 		return (-targetShape.width/2 <= dxr && dxr < targetShape.width/2 && -targetShape.depth/2 <= dzr && dzr < targetShape.depth/2);
 	}
 };
@@ -584,55 +569,25 @@ Attack.prototype.MissileHit = function(data, lateness)
 		var friendlyFire = this.template.Ranged.Splash.FriendlyFire;
 		var splashRadius = this.template.Ranged.Splash.Range;
 		var splashShape = this.template.Ranged.Splash.Shape;
-		
-		var ents = this.GetNearbyEntities(data.target, this.VectorDistance(data.position, targetPosition) * 2 + splashRadius, friendlyFire);
-		ents.push(data.target); // Add the original unit to the list of splash damage targets
-		
-		for (var i = 0; i < ents.length; i++)
+		var playersToDamage;
+		// If friendlyFire isn't enabled, get all player enemies to pass to "Damage.CauseSplashDamage".
+		if (friendlyFire == false)
 		{
-			var entityPosition = this.InterpolatedLocation(ents[i], lateness);
-			var radius = this.VectorDistance(data.position, entityPosition);
-			
-			if (radius < splashRadius)
-			{
-				var multiplier = 1;
-				if (splashShape == "Circular") // quadratic falloff
-				{
-					multiplier *= 1 - ((radius * radius) / (splashRadius * splashRadius));
-				}
-				else if (splashShape == "Linear")
-				{
-					// position of entity relative to where the missile hit
-					var relPos = {"x": entityPosition.x - data.position.x, "z": entityPosition.z - data.position.z};
-					
-					var splashWidth = splashRadius / 5;
-					var parallelDist = this.VectorDot(relPos, data.direction);
-					var perpDist = Math.abs(this.VectorCross(relPos, data.direction));
-					
-					// Check that the unit is within the distance splashWidth of the line starting at the missile's 
-					// landing point which extends in the direction of the missile for length splashRadius.
-					if (parallelDist > -splashWidth && perpDist < splashWidth)
-					{
-						// Use a quadratic falloff in both directions
-						multiplier = (splashRadius*splashRadius - parallelDist*parallelDist) / (splashRadius*splashRadius)
-						             * (splashWidth*splashWidth - perpDist*perpDist) / (splashWidth*splashWidth);
-					}
-					else
-					{
-						multiplier = 0;
-					}
-				}
-				var newData = {"type": data.type + ".Splash", "target": ents[i], "damageMultiplier": multiplier};
-				this.CauseDamage(newData);
-			}
+			var cmpPlayer = Engine.QueryInterface(Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager).GetPlayerByID(data.playerId), IID_Player)
+			playersToDamage = cmpPlayer.GetEnemies();
 		}
+		// Damage the units.
+		Damage.CauseSplashDamage({"attacker":this.entity, "origin":data.position, "radius":splashRadius, "shape":splashShape, "strengths":this.GetAttackStrengths(data.type), "direction":data.direction, "playersToDamage":playersToDamage, "type":data.type});
 	}
-	
+
 	if (this.testCollision(data.target, data.position, lateness))
 	{
+		data.attacker = this.entity
+		data.multiplier = this.GetAttackBonus(data.type, data.target)
+		data.strengths = this.GetAttackStrengths(data.type)
 		// Hit the primary target
-		this.CauseDamage(data);
-		
+		Damage.CauseDamage(data);
+
 		// Remove the projectile
 		var cmpProjectileManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_ProjectileManager);
 		cmpProjectileManager.RemoveProjectile(data.projectileId);
@@ -640,15 +595,15 @@ Attack.prototype.MissileHit = function(data, lateness)
 	else
 	{
 		// If we didn't hit the main target look for nearby units
-		var ents = this.GetNearbyEntities(data.target, this.VectorDistance(data.position, targetPosition) * 2);
-		
+		var cmpPlayer = Engine.QueryInterface(Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager).GetPlayerByID(data.playerId), IID_Player)
+		var ents = Damage.EntitiesNearPoint(data.position, this.VectorDistance(data.position, targetPosition) * 2, cmpPlayer.GetEnemies());
+
 		for (var i = 0; i < ents.length; i++)
 		{
 			if (this.testCollision(ents[i], data.position, lateness))
 			{
-				var newData = {"type": data.type, "target": ents[i]};
-				this.CauseDamage(newData);
-				
+				var newData = {"strengths":this.GetAttackStrengths(data.type), "target":ents[i], "attacker":this.entity, "multiplier":this.GetAttackBonus(data.type, ents[i]), "type":data.type};
+				Damage.CauseDamage(newData);
 				// Remove the projectile
 				var cmpProjectileManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_ProjectileManager);
 				cmpProjectileManager.RemoveProjectile(data.projectileId);
@@ -657,53 +612,6 @@ Attack.prototype.MissileHit = function(data, lateness)
 	}
 };
 
-Attack.prototype.GetNearbyEntities = function(startEnt, range, friendlyFire)
-{
-	var cmpPlayerManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
-	var cmpOwnership = Engine.QueryInterface(this.entity, IID_Ownership);
-	var owner = cmpOwnership.GetOwner();
-	var cmpPlayer = Engine.QueryInterface(cmpPlayerManager.GetPlayerByID(owner), IID_Player);
-	var numPlayers = cmpPlayerManager.GetNumPlayers();
-	var players = [];
-	
-	for (var i = 1; i < numPlayers; ++i)
-	{	
-		// Only target enemies unless friendly fire is on
-		if (cmpPlayer.IsEnemy(i) || friendlyFire)
-			players.push(i);
-	}
-	
-	var rangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
-	return rangeManager.ExecuteQuery(startEnt, 0, range, players, IID_DamageReceiver);
-}
-
-/**
- * Inflict damage on the target
- */
-Attack.prototype.CauseDamage = function(data)
-{
-	var strengths = this.GetAttackStrengths(data.type);
-	
-	var damageMultiplier = this.GetAttackBonus(data.type, data.target);
-	if (data.damageMultiplier !== undefined)
-		damageMultiplier *= data.damageMultiplier;
-	
-	var cmpDamageReceiver = Engine.QueryInterface(data.target, IID_DamageReceiver);
-	if (!cmpDamageReceiver)
-		return;
-	var targetState = cmpDamageReceiver.TakeDamage(strengths.hack * damageMultiplier, strengths.pierce * damageMultiplier, strengths.crush * damageMultiplier);
-	// if target killed pick up loot and credit experience
-	if (targetState.killed == true)
-	{
-		this.TargetKilled(this.entity, data.target);
-	}
-
-	Engine.PostMessage(data.target, MT_Attacked,
-		{ "attacker": this.entity, "target": data.target, "type": data.type, "damage": -targetState.change });
-
-	PlaySound("attack_impact", this.entity);
-};
-
 Attack.prototype.OnUpdate = function(msg)
 {
 	this.turnLength = msg.turnLength;
