@@ -8,7 +8,7 @@ BuildRestrictions.prototype.Schema =
 			"<Territory>own</Territory>" +
 			"<Category>Special</Category>" +
 			"<Distance>" +
-				"<FromCategory>CivilCentre</FromCategory>" +
+				"<FromClass>CivilCentre</FromClass>" +
 				"<MaxDistance>40</MaxDistance>" +
 			"</Distance>" +
 		"</BuildRestrictions>" +
@@ -17,6 +17,7 @@ BuildRestrictions.prototype.Schema =
 		"<choice>" +
 			"<value>land</value>" +
 			"<value>shore</value>" +
+			"<value>land-shore</value>"+
 		"</choice>" +
 	"</element>" +
 	"<element name='Territory' a:help='Specifies territory type restrictions for this building.'>" +
@@ -31,33 +32,14 @@ BuildRestrictions.prototype.Schema =
 			"</oneOrMore>" +
 		"</list>" +
 	"</element>" +
-	"<element name='Category' a:help='Specifies the category of this building, for satisfying special constraints.'>" +
-		"<choice>" +
-			"<value>CivilCentre</value>" +
-			"<value>House</value>" +
-			"<value>DefenseTower</value>" +
-			"<value>Farmstead</value>" +
-			"<value>Market</value>" +
-			"<value>Barracks</value>" +
-			"<value>Dock</value>" +
-			"<value>Fortress</value>" +
-			"<value>Field</value>" +
-			"<value>Temple</value>" +
-			"<value>Wall</value>" +
-			"<value>Fence</value>" +
-			"<value>Mill</value>" +
-			"<value>Stoa</value>" +
-			"<value>Resource</value>" +
-			"<value>Special</value>" +
-		"</choice>" +
+	"<element name='Category' a:help='Specifies the category of this building, for satisfying special constraints. Choices include: CivilCentre, House, DefenseTower, Farmstead, Market, Barracks, Dock, Fortress, Field, Temple, Wall, Fence, Storehouse, Stoa, Resource, Special, Wonder, Apadana, Embassy, Monument'>" +
+		"<text/>" +
 	"</element>" +
 	"<optional>" +
 		"<element name='Distance' a:help='Specifies distance restrictions on this building, relative to buildings from the given category.'>" +
 			"<interleave>" +
-				"<element name='FromCategory'>" +
-					"<choice>" +
-						"<value>CivilCentre</value>" +
-					"</choice>" +
+				"<element name='FromClass'>" +
+					"<text/>" +
 				"</element>" +
 				"<optional><element name='MinDistance'><data type='positiveInteger'/></element></optional>" +
 				"<optional><element name='MaxDistance'><data type='positiveInteger'/></element></optional>" +
@@ -76,7 +58,7 @@ BuildRestrictions.prototype.Init = function()
  *	2. Check foundation
  *		a. Doesn't obstruct foundation-blocking entities
  *		b. On valid terrain, based on passability class
- *	3. Territory type is allowed
+ *	3. Territory type is allowed (see note below)
  *	4. Dock is on shoreline and facing into water
  *	5. Distance constraints satisfied
  *
@@ -85,6 +67,10 @@ BuildRestrictions.prototype.Init = function()
  *		"success":	true iff the placement is valid, else false
  *		"message":	message to display in UI for invalid placement, else empty string
  *  }
+ *
+ * Note: The entity which is used to check this should be a preview entity
+ *  (template name should be "preview|"+templateName), as otherwise territory
+ *  checks for buildings with territory influence will not work as expected.
  */
 BuildRestrictions.prototype.CheckPlacement = function()
 {
@@ -123,7 +109,13 @@ BuildRestrictions.prototype.CheckPlacement = function()
 	case "shore":
 		passClassName = "building-shore";
 		break;
-		
+
+	case "land-shore":
+		// 'default' is everywhere a normal unit can go
+		// So on passable land, and not too deep in the water
+		passClassName = "default";
+		break;
+	
 	case "land":
 	default:
 		passClassName = "building-land";
@@ -132,8 +124,18 @@ BuildRestrictions.prototype.CheckPlacement = function()
 	var cmpObstruction = Engine.QueryInterface(this.entity, IID_Obstruction);
 	if (!cmpObstruction)
 		return result; // Fail
+	
+	
+	if (this.template.Category == "Wall")
+	{
+		// for walls, only test the center point
+		var ret = cmpObstruction.CheckFoundation(passClassName, true);
+	}
+	else
+	{
+		var ret = cmpObstruction.CheckFoundation(passClassName, false);
+	}
 
-	var ret = cmpObstruction.CheckFoundation(passClassName);
 	if (ret != "success")
 	{
 		switch (ret)
@@ -178,7 +180,7 @@ BuildRestrictions.prototype.CheckPlacement = function()
 	else if (isEnemy && !this.HasTerritory("enemy"))
 		territoryType = "enemy";
 	else
-		territoryFail = false
+		territoryFail = false;
 
 	if (territoryFail)
 	{
@@ -224,39 +226,35 @@ BuildRestrictions.prototype.CheckPlacement = function()
 	// Check distance restriction
 	if (this.template.Distance)
 	{
-		var nearest = 65535;
-		var ents = Engine.GetEntitiesWithInterface(IID_BuildRestrictions);
-		for each (var ent in ents)
-		{
-			// Ignore ourself
-			if (ent == this.entity)
-				continue;
+		var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
+		var cmpPlayer = QueryOwnerInterface(this.entity, IID_Player);
+		var cat = this.template.Distance.FromClass;
 
-			var cmpBuildRestrictions = Engine.QueryInterface(ent, IID_BuildRestrictions);
-			if (cmpBuildRestrictions.GetCategory() == this.template.Distance.FromCategory && IsOwnedByPlayer(cmpPlayer.GetPlayerID(), ent))
-			{	// Find nearest building matching this category
-				var cmpEntPosition = Engine.QueryInterface(ent, IID_Position);
-				if (cmpEntPosition && cmpEntPosition.IsInWorld())
-				{
-					var entPos = cmpEntPosition.GetPosition2D();
-					var dist = Math.sqrt((pos.x-entPos.x)*(pos.x-entPos.x) + (pos.y-entPos.y)*(pos.y-entPos.y));
-					if (dist < nearest)
-					{
-						nearest = dist;
-					}
-				}
+		var filter = function(id)
+		{
+			var cmpIdentity = Engine.QueryInterface(id, IID_Identity);
+			return cmpIdentity.GetClassesList().indexOf(cat) > -1;
+		}
+		
+		if (this.template.Distance.MinDistance)
+		{
+			var dist = +this.template.Distance.MinDistance
+			var nearEnts = cmpRangeManager.ExecuteQuery(this.entity, 0, dist, [cmpPlayer.GetPlayerID()], IID_BuildRestrictions).filter(filter);
+			if (nearEnts.length)
+			{
+				result.message = name+" too close to a "+cat+", must be at least "+ +this.template.Distance.MinDistance+" units away";
+				return result;	// Fail
 			}
 		}
-
-		if (this.template.Distance.MinDistance && nearest < +this.template.Distance.MinDistance)
+		if (this.template.Distance.MaxDistance)
 		{
-			result.message = name+" too close to a "+this.GetCategory()+", must be at least "+ +this.template.Distance.MinDistance+" units away";
-			return result;	// Fail
-		}
-		else if (this.template.Distance.MaxDistance && nearest > +this.template.Distance.MaxDistance)
-		{
-			result.message = name+" too far away from a "+this.GetCategory()+", must be within "+ +this.template.Distance.MaxDistance+" units";
-			return result;	// Fail
+			var dist = +this.template.Distance.MaxDistance;
+			var nearEnts = cmpRangeManager.ExecuteQuery(this.entity, 0, dist, [cmpPlayer.GetPlayerID()], IID_BuildRestrictions).filter(filter);
+			if (!nearEnts.length)
+			{
+				result.message = name+" too far away from a "+cat+", must be within "+ +this.template.Distance.MaxDistance+" units";
+				return result;	// Fail
+			}
 		}
 	}
 
@@ -273,7 +271,7 @@ BuildRestrictions.prototype.GetCategory = function()
 
 BuildRestrictions.prototype.GetTerritories = function()
 {
-	return ApplyTechModificationsToEntity("BuildRestrictions/Territory", this.territories, this.entity);
+	return ApplyValueModificationsToEntity("BuildRestrictions/Territory", this.territories, this.entity);
 };
 
 BuildRestrictions.prototype.HasTerritory = function(territory)
