@@ -1,6 +1,6 @@
 //Number of rounds of firing per 2 seconds
 const roundCount = 10;
-const timerInterval = 2000 / roundCount;
+const attackType = "Ranged";
 
 function BuildingAI() {}
 
@@ -10,8 +10,13 @@ BuildingAI.prototype.Schema =
 	"</element>" +
 	"<element name='GarrisonArrowMultiplier'>" +
 		"<ref name='nonNegativeDecimal'/>" +
+	"</element>" +
+	"<element name='GarrisonArrowClasses'>" +
+		"<text/>" +
 	"</element>";
 
+BuildingAI.prototype.MAX_PREFERENCE_BONUS = 2;
+
 /**
  * Initialize BuildingAI Component
  */
@@ -19,11 +24,9 @@ BuildingAI.prototype.Init = function()
 {
 	if (this.GetDefaultArrowCount() > 0 || this.GetGarrisonArrowMultiplier() > 0)
 	{
-		var cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
 		this.currentRound = 0;
 		//Arrows left to fire
 		this.arrowsLeft = 0;
-		this.timer = cmpTimer.SetTimeout(this.entity, IID_BuildingAI, "FireArrows", timerInterval, {});
 		this.targetUnits = [];
 	}
 };
@@ -79,29 +82,30 @@ BuildingAI.prototype.SetupRangeQuery = function(owner)
 {
 	var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
 	var cmpPlayerManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
+	var cmpAttack = Engine.QueryInterface(this.entity, IID_Attack);
+	if (!cmpAttack)
+		return;
+
 	if (this.enemyUnitsQuery)
 	{
 		cmpRangeManager.DestroyActiveQuery(this.enemyUnitsQuery);
 		this.enemyUnitsQuery = undefined;
 	}
 	var players = [];
-	
+
 	var cmpPlayer = Engine.QueryInterface(cmpPlayerManager.GetPlayerByID(owner), IID_Player);
 	var numPlayers = cmpPlayerManager.GetNumPlayers();
-		
+
 	for (var i = 1; i < numPlayers; ++i)
 	{	// Exclude gaia, allies, and self
 		// TODO: How to handle neutral players - Special query to attack military only?
 		if (cmpPlayer.IsEnemy(i))
 			players.push(i);
 	}
-	var cmpAttack = Engine.QueryInterface(this.entity, IID_Attack);
-	if (cmpAttack)
-	{
-		var range = cmpAttack.GetRange("Ranged");
-		this.enemyUnitsQuery = cmpRangeManager.CreateActiveQuery(this.entity, range.min, range.max, players, IID_DamageReceiver, cmpRangeManager.GetEntityFlagMask("normal"));
-		cmpRangeManager.EnableActiveQuery(this.enemyUnitsQuery);
-	}
+
+	var range = cmpAttack.GetRange(attackType);
+	this.enemyUnitsQuery = cmpRangeManager.CreateActiveParabolicQuery(this.entity, range.min, range.max, range.elevationBonus, players, IID_DamageReceiver, cmpRangeManager.GetEntityFlagMask("normal"));
+	cmpRangeManager.EnableActiveQuery(this.enemyUnitsQuery);
 };
 
 // Set up a range query for Gaia units within LOS range which can be attacked.
@@ -111,12 +115,15 @@ BuildingAI.prototype.SetupGaiaRangeQuery = function()
 	var cmpOwnership = Engine.QueryInterface(this.entity, IID_Ownership);
 	var owner = cmpOwnership.GetOwner();
 
-	var rangeMan = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
+	var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
 	var playerMan = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
+	var cmpAttack = Engine.QueryInterface(this.entity, IID_Attack);
+	if (!cmpAttack)
+		return;
 
 	if (this.gaiaUnitsQuery)
 	{
-		rangeMan.DestroyActiveQuery(this.gaiaUnitsQuery);
+		cmpRangeManager.DestroyActiveQuery(this.gaiaUnitsQuery);
 		this.gaiaUnitsQuery = undefined;
 	}
 
@@ -127,15 +134,11 @@ BuildingAI.prototype.SetupGaiaRangeQuery = function()
 	if (!cmpPlayer.IsEnemy(0))
 		return;
 
-	var cmpAttack = Engine.QueryInterface(this.entity, IID_Attack);
-	if (cmpAttack)
-	{
-		var range = cmpAttack.GetRange("Ranged");
+	var range = cmpAttack.GetRange(attackType);
 
-		// This query is only interested in Gaia entities that can attack.
-		this.gaiaUnitsQuery = rangeMan.CreateActiveQuery(this.entity, range.min, range.max, [0], IID_Attack, rangeMan.GetEntityFlagMask("normal"));
-		rangeMan.EnableActiveQuery(this.gaiaUnitsQuery);
-	}
+	// This query is only interested in Gaia entities that can attack.
+	this.gaiaUnitsQuery = cmpRangeManager.CreateActiveParabolicQuery(this.entity, range.min, range.max, range.elevationBonus, [0], IID_Attack, cmpRangeManager.GetEntityFlagMask("normal"));
+	cmpRangeManager.EnableActiveQuery(this.gaiaUnitsQuery);
 };
 
 /**
@@ -143,6 +146,11 @@ BuildingAI.prototype.SetupGaiaRangeQuery = function()
  */
 BuildingAI.prototype.OnRangeUpdate = function(msg)
 {
+
+	var cmpAttack = Engine.QueryInterface(this.entity, IID_Attack);
+	if (!cmpAttack)
+		return;
+
 	if (msg.tag == this.gaiaUnitsQuery)
 	{
 		const filter = function(e) {
@@ -165,28 +173,47 @@ BuildingAI.prototype.OnRangeUpdate = function(msg)
 	{
 		for each (var entity in msg.added)
 		{
-			this.targetUnits.push(entity);
+			if (cmpAttack.CanAttack(entity))
+				this.targetUnits.push(entity);
 		}
 	}
 	if (msg.removed.length > 0)
 	{
 		for each (var entity in msg.removed)
-		{
-			this.targetUnits.splice(this.targetUnits.indexOf(entity), 1);
+		{	
+			var index = this.targetUnits.indexOf(entity);
+			if (index > -1)
+				this.targetUnits.splice(index, 1);
 		}
 	}
+
+	if (!this.targetUnits.length || this.timer)
+		return;
+
+	// units entered the range, prepare to shoot
+	var cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
+	var attackTimers = cmpAttack.GetTimers(attackType);
+	this.timer = cmpTimer.SetInterval(this.entity, IID_BuildingAI, "FireArrows", attackTimers.prepare, attackTimers.repeat / roundCount, null);
 };
 
 BuildingAI.prototype.GetDefaultArrowCount = function()
 {
 	var arrowCount = +this.template.DefaultArrowCount;
-	return ApplyTechModificationsToEntity("BuildingAI/DefaultArrowCount", arrowCount, this.entity);
+	return ApplyValueModificationsToEntity("BuildingAI/DefaultArrowCount", arrowCount, this.entity);
 };
 
 BuildingAI.prototype.GetGarrisonArrowMultiplier = function()
 {
 	var arrowMult = +this.template.GarrisonArrowMultiplier;
-	return ApplyTechModificationsToEntity("BuildingAI/GarrisonArrowMultiplier", arrowMult, this.entity);
+	return ApplyValueModificationsToEntity("BuildingAI/GarrisonArrowMultiplier", arrowMult, this.entity);
+};
+
+BuildingAI.prototype.GetGarrisonArrowClasses = function()
+{
+	var string = this.template.GarrisonArrowClasses;
+	if (string)
+		return string.split(/\s+/);
+	return [];
 };
 
 /**
@@ -200,56 +227,119 @@ BuildingAI.prototype.GetArrowCount = function()
 	var cmpGarrisonHolder = Engine.QueryInterface(this.entity, IID_GarrisonHolder);
 	if (cmpGarrisonHolder)
 	{
-		count += Math.round(cmpGarrisonHolder.GetGarrisonedArcherCount() * this.GetGarrisonArrowMultiplier());
+		count += Math.round(cmpGarrisonHolder.GetGarrisonedArcherCount(this.GetGarrisonArrowClasses()) * this.GetGarrisonArrowMultiplier());
 	}
 	return count;
 };
 
 /**
- * Fires arrows. Called every N times every 2 seconds
- * where N is the number of Arrows
+ * Fires arrows. Called 'roundCount' times every 'RepeatTime' seconds when there are units in the range
  */
 BuildingAI.prototype.FireArrows = function()
 {
-	var cmpAttack = Engine.QueryInterface(this.entity, IID_Attack);
-	if (cmpAttack)
+	if (!this.targetUnits.length)
 	{
-		var cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
-		this.timer = cmpTimer.SetTimeout(this.entity, IID_BuildingAI, "FireArrows", timerInterval, {});
-		var arrowsToFire = 0;
-		if (this.currentRound > (roundCount - 1))
+		if (this.timer)
 		{
-			//Reached end of rounds. Reset count
-			this.currentRound = 0;
+			// stop the timer
+			var cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
+			cmpTimer.CancelTimer(this.timer);
+			this.timer = undefined;
 		}
-		
-		if (this.currentRound == 0)
-		{
-			//First round. Calculate arrows to fire
-			this.arrowsLeft = this.GetArrowCount();
-		}
-		
-		if (this.currentRound == (roundCount - 1))
-		{
-			//Last round. Need to fire all left-over arrows
-			arrowsToFire = this.arrowsLeft;
-		}
-		else
-		{
-			//Fire N arrows, 0 <= N <= Number of arrows left
-			arrowsToFire = Math.floor(Math.random() * this.arrowsLeft);
-		}
-		if (this.targetUnits.length > 0)
-		{
-			for (var i = 0;i < arrowsToFire;i++)
-			{
-				cmpAttack.PerformAttack("Ranged", this.targetUnits[Math.floor(Math.random() * this.targetUnits.length)]);
-				PlaySound("arrowfly", this.entity);
-			}
-			this.arrowsLeft -= arrowsToFire;
-		}
-		this.currentRound++;
+		return;
 	}
+
+	var cmpAttack = Engine.QueryInterface(this.entity, IID_Attack);
+	if (!cmpAttack)
+		return;
+
+	var arrowsToFire = 0;
+	if (this.currentRound > (roundCount - 1))
+	{
+		//Reached end of rounds. Reset count
+		this.currentRound = 0;
+	}
+	
+	if (this.currentRound == 0)
+	{
+		//First round. Calculate arrows to fire
+		this.arrowsLeft = this.GetArrowCount();
+	}
+	
+	if (this.currentRound == (roundCount - 1))
+	{
+		//Last round. Need to fire all left-over arrows
+		arrowsToFire = this.arrowsLeft;
+	}
+	else
+	{
+		//Fire N arrows, 0 <= N <= Number of arrows left
+		arrowsToFire = Math.min( 
+		    Math.round(2*Math.random() * this.GetArrowCount()/roundCount),  
+		    this.arrowsLeft 
+		);
+	}
+	if (arrowsToFire <= 0)
+	{
+		this.currentRound++;
+		return;
+	}
+	var targets = new WeightedList();
+	for (var i = 0; i < this.targetUnits.length; i++)
+	{
+		var target = this.targetUnits[i];
+		var preference = cmpAttack.GetPreference(target);
+		var weight = 1;
+		if (preference !== null && preference !== undefined)
+		{
+			// Lower preference scores indicate a higher preference so they
+			// should result in a higher weight.
+			weight = 1 + this.MAX_PREFERENCE_BONUS / (1 + preference);
+		}
+		targets.push(target, weight);
+	}
+	for (var i = 0;i < arrowsToFire;i++)
+	{
+		var selectedIndex = targets.randomIndex();
+		var selectedTarget = targets.itemAt(selectedIndex);
+		if (selectedTarget && this.CheckTargetVisible(selectedTarget))
+		{
+			cmpAttack.PerformAttack(attackType, selectedTarget);
+			PlaySound("attack", this.entity);
+		}
+		else 
+		{
+			targets.removeAt(selectedIndex);
+			i--; // one extra arrow left to fire
+			if(targets.length() < 1)
+			{
+				this.arrowsLeft += arrowsToFire;
+				// no targets found in this round, save arrows and go to next round
+				break;
+			}
+		}
+	}
+
+	this.arrowsLeft -= arrowsToFire;
+	this.currentRound++;
+};
+
+/**
+ * Returns true if the target entity is visible through the FoW/SoD.
+ */
+BuildingAI.prototype.CheckTargetVisible = function(target)
+{
+	var cmpOwnership = Engine.QueryInterface(this.entity, IID_Ownership);
+	if (!cmpOwnership)
+		return false;
+
+	var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
+
+	if (cmpRangeManager.GetLosVisibility(target, cmpOwnership.GetOwner(), false) == "hidden")
+		return false;
+
+	// Either visible directly, or visible in fog
+	return true;
 };
 
 Engine.RegisterComponentType(IID_BuildingAI, "BuildingAI", BuildingAI);
