@@ -12,6 +12,15 @@ Formation.prototype.Init = function()
 	this.columnar = false; // whether we're travelling in column (vs box) formation
 	this.formationName = "Line Closed";
 	this.rearrange = true; // whether we should rearrange all formation members
+	this.formationMembersWithAura = []; // Members with a formation aura
+	this.width = 0;
+	this.depth = 0;
+	this.oldOrientation = {"sin": 0, "cos": 0};
+};
+
+Formation.prototype.GetSize = function()
+{
+	return {"width": this.width, "depth": this.depth};
 };
 
 Formation.prototype.GetMemberCount = function()
@@ -86,12 +95,21 @@ Formation.prototype.SetMembers = function(ents)
 	{
 		var cmpUnitAI = Engine.QueryInterface(ent, IID_UnitAI);
 		cmpUnitAI.SetFormationController(this.entity);
+		
+		var cmpAuras = Engine.QueryInterface(ent, IID_Auras);
+		if (cmpAuras && cmpAuras.HasFormationAura())
+		{
+			this.formationMembersWithAura.push(ent);
+			cmpAuras.ApplyFormationBonus(ents);
+		}
 	}
 
+	this.offsets = undefined;
 	// Locate this formation controller in the middle of its members
 	this.MoveToMembersCenter();
 
 	this.ComputeMotionParameters();
+
 };
 
 /**
@@ -100,15 +118,29 @@ Formation.prototype.SetMembers = function(ents)
  */
 Formation.prototype.RemoveMembers = function(ents)
 {
+	this.offsets = undefined;
 	this.members = this.members.filter(function(e) { return ents.indexOf(e) == -1; });
 	this.inPosition = this.inPosition.filter(function(e) { return ents.indexOf(e) == -1; });
 
 	for each (var ent in ents)
 	{
 		var cmpUnitAI = Engine.QueryInterface(ent, IID_UnitAI);
+		cmpUnitAI.UpdateWorkOrders();
 		cmpUnitAI.SetFormationController(INVALID_ENTITY);
 	}
 
+	for each (var ent in this.formationMembersWithAura)
+	{
+		var cmpAuras = Engine.QueryInterface(ent, IID_Auras);
+		cmpAuras.RemoveFormationBonus(ents);
+
+		// the unit with the aura is also removed from the formation
+		if (ents.indexOf(ent) !== -1)
+			cmpAuras.RemoveFormationBonus(this.members);
+	}
+
+	this.formationMembersWithAura = this.formationMembersWithAura.filter(function(e) { return ents.indexOf(e) == -1; });
+
 	// If there's nobody left, destroy the formation
 	if (this.members.length == 0)
 	{
@@ -155,8 +187,17 @@ Formation.prototype.Disband = function()
 		cmpUnitAI.SetFormationController(INVALID_ENTITY);
 	}
 
+	for each (var ent in this.formationMembersWithAura)
+	{
+		var cmpAuras = Engine.QueryInterface(ent, IID_Auras);
+		cmpAuras.RemoveFormationBonus(this.members);
+	}
+
+
 	this.members = [];
 	this.inPosition = [];
+	this.formationMembersWithAura = [];
+	this.offsets = undefined;
 
 	Engine.DestroyEntity(this.entity);
 };
@@ -228,47 +269,71 @@ Formation.prototype.MoveMembersIntoFormation = function(moveCenter, force)
 			continue;
 
 		active.push(ent);
-		positions.push(cmpPosition.GetPosition());
+		// query the 2D position as exact hight calculation isn't needed
+		// but bring the position to the right coordinates
+		var pos = cmpPosition.GetPosition2D();
+		pos.z = pos.y;
+		pos.y = undefined;
+		positions.push(pos);
 	}
 
-	// Work out whether this should be a column or box formation
-	var cmpUnitAI = Engine.QueryInterface(this.entity, IID_UnitAI);
-	var walkingDistance = cmpUnitAI.ComputeWalkingDistance();
-	this.columnar = (walkingDistance > g_ColumnDistanceThreshold) && this.formationName != "Column Open";
-
-	var offsets = this.ComputeFormationOffsets(active, this.columnar);
-
 	var avgpos = this.ComputeAveragePosition(positions);
-	var avgoffset = this.ComputeAveragePosition(offsets);
 
 	// Reposition the formation if we're told to or if we don't already have a position
 	var cmpPosition = Engine.QueryInterface(this.entity, IID_Position);
-	if (moveCenter || !cmpPosition.IsInWorld())
-		cmpPosition.JumpTo(avgpos.x, avgpos.z);
-
-	for (var i = 0; i < offsets.length; ++i)
+	var inWorld = cmpPosition.IsInWorld();
+	if (moveCenter || !inWorld)
 	{
-		var offset = offsets[i];
+		cmpPosition.JumpTo(avgpos.x, avgpos.z);
+		// Don't make the formation controller entity show up in range queries
+		if (!inWorld)
+		{
+			var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
+			cmpRangeManager.SetEntityFlag(this.entity, "normal", false);
+		}
+	}
+
+	var newOrientation = this.GetTargetOrientation(avgpos);
+	var dSin = Math.abs(newOrientation.sin - this.oldOrientation.sin);
+	var dCos = Math.abs(newOrientation.cos - this.oldOrientation.cos);
+	// If the formation existed, only recalculate positions if the turning agle is somewhat biggish
+	if (!this.offsets || dSin > 1 || dCos > 1)
+		this.offsets = this.ComputeFormationOffsets(active, positions, this.columnar);
+
+	this.oldOrientation = newOrientation;
+
+	var xMax = 0;
+	var zMax = 0;
+
+	for (var i = 0; i < this.offsets.length; ++i)
+	{
+		var offset = this.offsets[i];
 
 		var cmpUnitAI = Engine.QueryInterface(offset.ent, IID_UnitAI);
+		if (!cmpUnitAI)
+			continue;
 		
 		if (force)
 		{
 			cmpUnitAI.ReplaceOrder("FormationWalk", {
 				"target": this.entity,
-				"x": offset.x - avgoffset.x,
-				"z": offset.z - avgoffset.z
+				"x": offset.x,
+				"z": offset.z
 			});
 		}
 		else
 		{
 			cmpUnitAI.PushOrderFront("FormationWalk", {
 				"target": this.entity,
-				"x": offset.x - avgoffset.x,
-				"z": offset.z - avgoffset.z
+				"x": offset.x,
+				"z": offset.z
 			});
 		}
+		xMax = Math.max(xMax, offset.x);
+		zMax = Math.max(zMax, offset.z);
 	}
+	this.width = xMax * 2;
+	this.depth = zMax * 2;
 };
 
 Formation.prototype.MoveToMembersCenter = function()
@@ -287,13 +352,38 @@ Formation.prototype.MoveToMembersCenter = function()
 	var avgpos = this.ComputeAveragePosition(positions);
 
 	var cmpPosition = Engine.QueryInterface(this.entity, IID_Position);
+	var inWorld = cmpPosition.IsInWorld();
 	cmpPosition.JumpTo(avgpos.x, avgpos.z);
+
+	// Don't make the formation controller show up in range queries
+	if (!inWorld)
+	{
+		var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
+		cmpRangeManager.SetEntityFlag(this.entity, "normal", false);
+	}
 };
 
-Formation.prototype.ComputeFormationOffsets = function(active, columnar)
+Formation.prototype.GetAvgObstructionRange = function(active)
 {
-	var separation = 4; // TODO: don't hardcode this
+	var obstructions = [];
+	for each (var ent in active)
+	{
+		var cmpObstruction = Engine.QueryInterface(ent, IID_Obstruction);
+		if (cmpObstruction)
+			obstructions.push(cmpObstruction.GetUnitRadius());
+	}
+	if (!obstructions.length)
+		return 1;
+	return obstructions.reduce(function(m,v) {return m + v;}, 0) / obstructions.length;
+};
 
+Formation.prototype.ComputeFormationOffsets = function(active, positions, columnar)
+{
+	// TODO give some sense to this number
+	var separation = this.GetAvgObstructionRange(active) * 4; 
+
+	// the entities will be assigned to positions in the formation in 
+	// the same order as the types list is ordered
 	var types = {
 		"Cavalry" : [],
 		"Hero" : [],
@@ -301,32 +391,32 @@ Formation.prototype.ComputeFormationOffsets = function(active, columnar)
 		"Ranged" : [],
 		"Support" : [],
 		"Unknown": []
-	}; // TODO: make this work so we put ranged behind infantry etc
+	}; 
 
-	for each (var ent in active)
+	for (var i in active)
 	{
-		var cmpIdentity = Engine.QueryInterface(ent, IID_Identity);
+		var cmpIdentity = Engine.QueryInterface(active[i], IID_Identity);
 		var classes = cmpIdentity.GetClassesList();
 		var done = false;
 		for each (var cla in classes)
 		{
 			if (cla in types)
 			{
-				types[cla].push(ent);
+				types[cla].push({"ent": active[i], "pos": positions[i]});
 				done = true;
 				break;
 			}
 		}
 		if (!done)
 		{
-			types["Unknown"].push(ent);
+			types["Unknown"].push({"ent": active[i], "pos": positions[i]});
 		}
 	}
 
 	var count = active.length;
 
 	var shape = undefined;
-	var ordering = "default";
+	var ordering = [];
 
 	var offsets = [];
 
@@ -334,9 +424,11 @@ Formation.prototype.ComputeFormationOffsets = function(active, columnar)
 	var cols;
 
 	if (columnar)
-		this.formationName = "Column Closed";
+		var formationName = "Column Closed";
+	else
+		var formationName = this.formationName;
 
-	switch(this.formationName)
+	switch(formationName)
 	{
 	case "Column Closed":
 		// Have at most 3 files
@@ -369,6 +461,7 @@ Formation.prototype.ComputeFormationOffsets = function(active, columnar)
 		else
 			cols = Math.ceil(count/3);
 		shape = "square";
+		ordering = ["FillFromTheCenter", "FillFromTheFront"];
 		break;
 	case "Testudo":
 		cols = Math.ceil(Math.sqrt(count));
@@ -388,6 +481,7 @@ Formation.prototype.ComputeFormationOffsets = function(active, columnar)
 		else
 			cols = 6;
 		shape = "opensquare";
+		ordering = ["FillFromTheCenter", "FillFromTheFront"];
 		break;
 	case "Scatter":
 		var width = Math.sqrt(count) * separation * 5;
@@ -526,6 +620,7 @@ Formation.prototype.ComputeFormationOffsets = function(active, columnar)
 				left -= n;
 			}
 		}
+		ordering.push("FillFromTheCenter");
 		break;
 	case "Syntagma":
 		cols = Math.ceil(Math.sqrt(count));
@@ -544,10 +639,10 @@ Formation.prototype.ComputeFormationOffsets = function(active, columnar)
 			cols = Math.ceil(count/6);
 		shape = "opensquare";
 		separation /= 1.5;
-		ordering = "cavalryOnTheSides";
+		ordering.push("FillFromTheSides");
 		break;
 	default:
-		warn("Unknown formation: " + this.formationName);
+		warn("Unknown formation: " + formationName);
 		break;
 	}
 
@@ -583,77 +678,120 @@ Formation.prototype.ComputeFormationOffsets = function(active, columnar)
 			left -= n;
 		}
 	}
-
-	// TODO: assign to minimise worst-case distances or whatever
-	if (ordering == "default")
+	// make sure the average offset is zero, as the formation is centered around that
+	// calculating offset distances without a zero average makes no sense, as the formation
+	// will jump to a different position any time
+	var avgoffset = this.ComputeAveragePosition(offsets);
+	for each (var offset in offsets)
 	{
-		for each (var offset in offsets)
-		{
-			var ent = undefined;
-			for (var t in types)
-			{
-				if (types[t].length)
-				{
-					ent = types[t].pop();
-					offset.ent = ent;
-					break;
-				}
-			}
-		}
-	}
-	else if (ordering == "cavalryOnTheSides")
-	{
-		var noffset = [];
-		var cavalrycount = types["Cavalry"].length;
-		offsets.sort(function (a, b) {
-			if (a.x < b.x) return -1;
-			else if (a.x == b.x && a.z < b.z) return -1;
-			return 1;
-		});
-
-		while (offsets.length && types["Cavalry"].length && types["Cavalry"].length > cavalrycount/2)
-		{
-			var offset = offsets.pop();
-			offset.ent = types["Cavalry"].pop();
-			noffset.push(offset);
-		}
-
-		offsets.sort(function (a, b) {
-			if (a.x > b.x) return -1;
-			else if (a.x == b.x && a.z < b.z) return -1;
-			return 1;
-		});
-
-		while (offsets.length && types["Cavalry"].length)
-		{
-			var offset = offsets.pop();
-			offset.ent = types["Cavalry"].pop();
-			noffset.push(offset);
-		}
-
-		offsets.sort(function (a, b) {
-			if (a.z < b.z) return -1;
-			else if (a.z == b.z && a.x < b.x) return -1;
-			return 1;
-		});
-
-		while (offsets.length)
-		{
-			var offset = offsets.pop();
-			for (var t in types)
-			{
-				if (types[t].length)
-				{
-					offset.ent = types[t].pop();
-					break;
-				}
-			}
-			noffset.push(offset);
-		}
-		offsets = noffset;
+		offset.x -= avgoffset.x;
+		offset.z -= avgoffset.z;
 	}
 
-	return offsets;
+	// sort the available places in certain ways
+	// the places first in the list will contain the heaviest units as defined by the order
+	// of the types list
+	for each (var order in ordering)
+	{
+		if (order == "FillFromTheSides")
+			offsets.sort(function(o1, o2) { return Math.abs(o1.x) < Math.abs(o2.x);});
+		else if (order == "FillFromTheCenter")
+			offsets.sort(function(o1, o2) { return Math.abs(o1.x) > Math.abs(o2.x);});
+		else if (order == "FillFromTheFront")
+			offsets.sort(function(o1, o2) { return o1.z < o2.z;});
+	}
+
+	// query the 2D position of the formation, and bring to the right coordinate system
+	var cmpPosition = Engine.QueryInterface(this.entity, IID_Position);
+	var formationPos = cmpPosition.GetPosition2D();
+	formationPos.z = formationPos.y;
+	formationPos.y = undefined;
+
+	// use realistic place assignment,
+	// every soldier searches the closest available place in the formation
+	var newOffsets = [];
+	var realPositions = this.GetRealOffsetPositions(offsets, formationPos);
+	for each (var t in types)
+	{
+		var usedOffsets = offsets.splice(0,t.length);
+		var usedRealPositions = realPositions.splice(0, t.length);
+		for each (var entPos in t)
+		{
+			var closestOffsetId = this.TakeClosestOffset(entPos, usedRealPositions);
+			usedRealPositions.splice(closestOffsetId, 1);
+			newOffsets.push(usedOffsets.splice(closestOffsetId, 1)[0]);
+			newOffsets[newOffsets.length - 1].ent = entPos.ent;
+		}
+	}
+
+	return newOffsets;
+};
+
+/**
+ * Search the closest position in the realPositions list to the given entity
+ * @param ent, the queried entity
+ * @param realPositions, the world coordinates of the available offsets
+ * @return the index of the closest offset position
+ */
+Formation.prototype.TakeClosestOffset = function(entPos, realPositions)
+{
+	var pos = entPos.pos;
+	var closestOffsetId = -1;
+	var offsetDistanceSq = Infinity;
+	for (var i = 0; i < realPositions.length; i++)
+	{
+		var dx = realPositions[i].x - pos.x;
+		var dz = realPositions[i].z - pos.z;
+		var distSq = dx * dx + dz * dz;
+		if (distSq < offsetDistanceSq)
+		{
+			offsetDistanceSq = distSq;
+			closestOffsetId = i;
+		}
+	}
+	return closestOffsetId;
+};
+
+/**
+ * Get the world positions for a list of offsets in this formation
+ */
+Formation.prototype.GetRealOffsetPositions = function(offsets, pos)
+{
+	var offsetPositions = [];
+	var {sin, cos} = this.GetTargetOrientation(pos);
+	// calculate the world positions
+	for each (var o in offsets)
+		offsetPositions.push({
+			"x" : pos.x + o.z * sin + o.x * cos, 
+			"z" : pos.z + o.z * cos - o.x * sin
+		});
+
+	return offsetPositions;
+};
+
+/**
+ * calculate the estimated rotation of the formation 
+ * based on the first unitAI target position
+ * Return the sine and cosine of the angle
+ */
+Formation.prototype.GetTargetOrientation = function(pos)
+{
+	var cmpUnitAI = Engine.QueryInterface(this.entity, IID_UnitAI);
+	var targetPos = cmpUnitAI.GetTargetPositions();
+	var sin = 1;
+	var cos = 0;
+	if (targetPos.length)
+	{
+		var dx = targetPos[0].x - pos.x;
+		var dz = targetPos[0].z - pos.z;
+		if (dx || dz)
+		{
+			var dist = Math.sqrt(dx * dx + dz * dz);
+			cos = dz / dist;
+			sin = dx / dist;
+		}
+	}
+	return {"sin": sin, "cos": cos};
 };
 
 Formation.prototype.ComputeAveragePosition = function(positions)
@@ -698,12 +836,17 @@ Formation.prototype.OnUpdate_Final = function(msg)
 {
 	// Switch between column and box if necessary
 	var cmpUnitAI = Engine.QueryInterface(this.entity, IID_UnitAI);
+	// TODO do we really need to calculate the distance every turn?
 	var walkingDistance = cmpUnitAI.ComputeWalkingDistance();
-	var columnar = (walkingDistance > g_ColumnDistanceThreshold);
+	var columnar = walkingDistance > g_ColumnDistanceThreshold;
 	if (columnar != this.columnar)
+	{
+		this.offsets = undefined;
+		this.columnar = columnar;
 		this.MoveMembersIntoFormation(false, true);
 		// (disable moveCenter so we can't get stuck in a loop of switching
 		// shape causing center to change causing shape to switch back)
+	}
 };
 
 Formation.prototype.OnGlobalOwnershipChanged = function(msg)
@@ -719,6 +862,7 @@ Formation.prototype.OnGlobalEntityRenamed = function(msg)
 {
 	if (this.members.indexOf(msg.entity) != -1)
 	{
+		this.offsets = undefined;
 		var cmpNewUnitAI = Engine.QueryInterface(msg.newentity, IID_UnitAI);
 		if (cmpNewUnitAI)
 			this.members[this.members.indexOf(msg.entity)] = msg.newentity;
@@ -743,6 +887,7 @@ Formation.prototype.LoadFormation = function(formationName)
 		var cmpUnitAI = Engine.QueryInterface(ent, IID_UnitAI);
 		cmpUnitAI.SetLastFormationName(this.formationName);
 	}
+	this.offsets = undefined;
 };
 
 Engine.RegisterComponentType(IID_Formation, "Formation", Formation);
