@@ -12,13 +12,21 @@ GarrisonHolder.prototype.Schema =
 	"</element>" +
 	"<element name='EjectHealth' a:help='Percentage of maximum health below which this holder no longer allows garrisoning'>" +
 		"<ref name='nonNegativeDecimal'/>" +
-	"</element>" + 
+	"</element>" +
+	"<element name='EjectEntitiesOnDestroy' a:help='Whether the entity should eject or kill all garrisoned entities on destroy'>" +
+		"<data type='boolean'/>" +
+	"</element>" +
 	"<element name='BuffHeal' a:help='Number of hit points that will be restored to this holder&apos;s garrisoned units each second'>" +
 		"<ref name='nonNegativeDecimal'/>" +
 	"</element>" +
 	"<element name='LoadingRange' a:help='The maximum distance from this holder at which entities are allowed to garrison. Should be about 2.0 for land entities and preferably greater for ships'>" +
 		"<ref name='nonNegativeDecimal'/>" +
-	"</element>";
+	"</element>" +
+	"<optional>" +
+		"<element name='Pickup' a:help='This garrisonHolder will move to pick up units to be garrisoned'>" +
+			"<data type='boolean'/>" +
+		"</element>" +
+	"</optional>";
 
 /**
  * Initialize GarrisonHolder Component
@@ -27,8 +35,8 @@ GarrisonHolder.prototype.Init = function()
 {
 	// Garrisoned Units
 	this.entities = [];
-	this.spaceOccupied = 0;
 	this.timer = undefined;
+	this.allowGarrisoning = {};
 };
 
 /**
@@ -40,6 +48,21 @@ GarrisonHolder.prototype.GetLoadingRange = function()
 	return { "max": max, "min": 0 };
 };
 
+/**
+ * Return true if this garrisonHolder can pickup ent
+ */
+GarrisonHolder.prototype.CanPickup = function(ent)
+{
+	if (!this.template.Pickup || this.IsFull())
+		return false;
+	var cmpOwner = Engine.QueryInterface(this.entity, IID_Ownership);
+	if (!cmpOwner)
+		return false;
+	var player = cmpOwner.GetOwner();
+	return IsOwnedByPlayer(player, ent);
+};
+
+
 /**
  * Return the list of entities garrisoned inside
  */
@@ -54,8 +77,8 @@ GarrisonHolder.prototype.GetEntities = function()
  */
 GarrisonHolder.prototype.GetAllowedClassesList = function()
 {
-	var string = this.template.List._string;
-	return string.split(/\s+/);
+	var classes = this.template.List._string;
+	return classes ? classes.split(/\s+/) : [];
 };
 
 /**
@@ -63,7 +86,15 @@ GarrisonHolder.prototype.GetAllowedClassesList = function()
  */
 GarrisonHolder.prototype.GetCapacity = function()
 {
-	return ApplyTechModificationsToEntity("GarrisonHolder/Max", +this.template.Max, this.entity);
+	return ApplyValueModificationsToEntity("GarrisonHolder/Max", +this.template.Max, this.entity);
+};
+
+/**
+ * Return true if this garrisonHolder is full
+ */
+GarrisonHolder.prototype.IsFull = function()
+{
+	return this.GetGarrisonedEntitiesCount() >= this.GetCapacity();
 };
 
 /**
@@ -71,21 +102,71 @@ GarrisonHolder.prototype.GetCapacity = function()
  */
 GarrisonHolder.prototype.GetHealRate = function()
 {
-	return ApplyTechModificationsToEntity("GarrisonHolder/BuffHeal", +this.template.BuffHeal, this.entity);
+	return ApplyValueModificationsToEntity("GarrisonHolder/BuffHeal", +this.template.BuffHeal, this.entity);
+};
+
+GarrisonHolder.prototype.EjectEntitiesOnDestroy = function()
+{
+	return this.template.EjectEntitiesOnDestroy == "true";
+};
+
+/**
+ * Set this entity to allow or disallow garrisoning in
+ * Every component calling this function should do it with its own ID, and as long as one
+ * component doesn't allow this entity to garrison, it can't be garrisoned
+ * When this entity already contains garrisoned soldiers, 
+ * these will not be able to ungarrison until the flag is set to true again.
+ *
+ * This more useful for modern-day features. For example you can't garrison or ungarrison
+ * a driving vehicle or plane.
+ */
+GarrisonHolder.prototype.AllowGarrisoning = function(allow, callerID)
+{
+	this.allowGarrisoning[callerID] = allow;
+};
+
+/**
+ * Check if no component of this entity blocks garrisoning 
+ * (f.e. because the vehicle is moving too fast)
+ */
+GarrisonHolder.prototype.IsGarrisoningAllowed = function()
+{
+	for each (var allow in this.allowGarrisoning)
+	{
+		if (!allow)
+			return false;
+	}
+	return true;
+};
+
+/**
+ * Return the number of recursively garrisoned units
+ */
+GarrisonHolder.prototype.GetGarrisonedEntitiesCount = function()
+{
+	var count = 0;
+	for each (var ent in this.entities)
+	{
+		count++;
+		var cmpGarrisonHolder = Engine.QueryInterface(ent, IID_GarrisonHolder);
+		if (cmpGarrisonHolder)
+			count += cmpGarrisonHolder.GetGarrisonedEntitiesCount();
+	}
+	return count;
 };
 
 /**
  * Get number of garrisoned units capable of shooting arrows
  * Not necessarily archers
  */
-GarrisonHolder.prototype.GetGarrisonedArcherCount = function()
+GarrisonHolder.prototype.GetGarrisonedArcherCount = function(garrisonArrowClasses)
 {
 	var count = 0;
 	for each (var entity in this.entities)
 	{
 		var cmpIdentity = Engine.QueryInterface(entity, IID_Identity);
 		var classes = cmpIdentity.GetClassesList();
-		if (classes.indexOf("Infantry") != -1 || classes.indexOf("Ranged") != -1)
+		if (classes.some(function(c){return garrisonArrowClasses.indexOf(c) > -1;}))
 			count++;
 	}
 	return count;
@@ -97,6 +178,9 @@ GarrisonHolder.prototype.GetGarrisonedArcherCount = function()
  */
 GarrisonHolder.prototype.AllowedToGarrison = function(entity)
 {
+	if (!this.IsGarrisoningAllowed())
+		return false;
+
 	var allowedClasses = this.GetAllowedClassesList();
 	var entityClasses = (Engine.QueryInterface(entity, IID_Identity)).GetClassesList();
 	// Check if the unit is allowed to be garrisoned inside the building
@@ -117,9 +201,19 @@ GarrisonHolder.prototype.AllowedToGarrison = function(entity)
  */
 GarrisonHolder.prototype.Garrison = function(entity)
 {
-	var entityPopCost = (Engine.QueryInterface(entity, IID_Cost)).GetPopCost();
-	var entityClasses = (Engine.QueryInterface(entity, IID_Identity)).GetClassesList();
+	var cmpPosition = Engine.QueryInterface(entity, IID_Position);
+	if (!cmpPosition)
+		return false;
 
+	if (!this.PerformGarrison(entity))
+		return false;
+
+	cmpPosition.MoveOutOfWorld();
+	return true;
+};
+
+GarrisonHolder.prototype.PerformGarrison = function(entity)
+{
 	if (!this.HasEnoughHealth())
 		return false;
 
@@ -127,7 +221,12 @@ GarrisonHolder.prototype.Garrison = function(entity)
 	if(!this.AllowedToGarrison(entity))
 		return false;
 
-	if (this.GetCapacity() < this.spaceOccupied + 1)
+	// check the capacity
+	var extraCount = 0;
+	var cmpGarrisonHolder = Engine.QueryInterface(entity, IID_GarrisonHolder);
+	if (cmpGarrisonHolder)
+		extraCount += cmpGarrisonHolder.GetGarrisonedEntitiesCount();
+	if (this.GetGarrisonedEntitiesCount() + extraCount >= this.GetCapacity())
 		return false;
 
 	if (!this.timer && this.GetHealRate() > 0)
@@ -136,18 +235,19 @@ GarrisonHolder.prototype.Garrison = function(entity)
 		this.timer = cmpTimer.SetTimeout(this.entity, IID_GarrisonHolder, "HealTimeout", 1000, {});
 	}
 
-	var cmpPosition = Engine.QueryInterface(entity, IID_Position);
-	if (cmpPosition)
-	{
-		// Actual garrisoning happens here
-		this.entities.push(entity);
-		this.spaceOccupied += 1;
-		cmpPosition.MoveOutOfWorld();
-		this.UpdateGarrisonFlag();
-		Engine.PostMessage(this.entity, MT_GarrisonedUnitsChanged, {});
-		return true;
-	}
-	return false;
+	// Actual garrisoning happens here
+	this.entities.push(entity);
+	this.UpdateGarrisonFlag();
+	var cmpProductionQueue = Engine.QueryInterface(entity, IID_ProductionQueue);
+	if (cmpProductionQueue)
+		cmpProductionQueue.PauseProduction();
+
+	var cmpAura = Engine.QueryInterface(entity, IID_Auras);
+	if (cmpAura && cmpAura.HasGarrisonAura())
+		cmpAura.ApplyGarrisonBonus(this.entity);	
+
+	Engine.PostMessage(this.entity, MT_GarrisonedUnitsChanged, {});
+	return true;
 };
 
 /**
@@ -157,11 +257,11 @@ GarrisonHolder.prototype.Garrison = function(entity)
  */
 GarrisonHolder.prototype.Eject = function(entity, forced)
 {
+
 	var entityIndex = this.entities.indexOf(entity);
+	// Error: invalid entity ID, usually it's already been ejected
 	if (entityIndex == -1)
-	{	// Error: invalid entity ID, usually it's already been ejected
 		return false; // Fail
-	}
 	
 	// Find spawning location
 	var cmpFootprint = Engine.QueryInterface(this.entity, IID_Footprint);
@@ -180,14 +280,20 @@ GarrisonHolder.prototype.Eject = function(entity, forced)
 		}
 	}
 	
-	this.spaceOccupied -= 1;
 	this.entities.splice(entityIndex, 1);
 	
 	var cmpUnitAI = Engine.QueryInterface(entity, IID_UnitAI);
 	if (cmpUnitAI)
-	{
 		cmpUnitAI.Ungarrison();
-	}
+
+	var cmpProductionQueue = Engine.QueryInterface(entity, IID_ProductionQueue);
+	if (cmpProductionQueue)
+		cmpProductionQueue.UnpauseProduction();
+
+	var cmpAura = Engine.QueryInterface(entity, IID_Auras);
+	if (cmpAura && cmpAura.HasGarrisonAura())
+		cmpAura.RemoveGarrisonBonus(this.entity);	
+
 	
 	var cmpNewPosition = Engine.QueryInterface(entity, IID_Position);
 	cmpNewPosition.JumpTo(pos.x, pos.z);
@@ -211,6 +317,9 @@ GarrisonHolder.prototype.OrderWalkToRallyPoint = function(entities)
 		if (rallyPos)
 		{
 			var commands = GetRallyPointCommands(cmpRallyPoint, entities);
+			// ignore the rally point if it is autogarrison
+			if (commands[0].type == "garrison" && commands[0].target == this.entity)
+				return;
 			for each (var com in commands)
 			{
 				ProcessCommand(cmpOwnership.GetOwner(), com);
@@ -220,132 +329,131 @@ GarrisonHolder.prototype.OrderWalkToRallyPoint = function(entities)
 };
 
 /**
- * Unload units from the garrisoning entity and order them
- * to move to the Rally Point
+ * Ejects units and orders them to move to the Rally Point.
  * Returns true if successful, false if not
  */
-GarrisonHolder.prototype.Unload = function(entity, forced)
+GarrisonHolder.prototype.PerformEject = function(entities, forced)
 {
-	if (this.Eject(entity, forced))
-	{
-		this.OrderWalkToRallyPoint([entity]);
-		this.UpdateGarrisonFlag();
-		return true;
-	}
-	
-	return false;
-};
+	if (!this.IsGarrisoningAllowed() && !forced)
+		return false;
 
-/**
- * Unload one or all units that match a template from the
- * garrisoning entity and order them to move to the Rally Point
- * Returns true if successful, false if not
- */
-GarrisonHolder.prototype.UnloadTemplate = function(template, all, forced)
-{
-	var ejectedEntities = [];
-	var success = true;
-	for (var i = 0; i < this.entities.length; ++i)
-	{
-		var entity = this.entities[i];
-		var cmpIdentity = Engine.QueryInterface(entity, IID_Identity);
-
-		// Units with multiple ranks are grouped together.
-		var name = cmpIdentity.GetSelectionGroupName();
-		if (!name)
-		{
-			var cmpTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager);
-			name = cmpTemplateManager.GetCurrentTemplateName(entity);
-		}
-		
-		if (name != template)
-			continue;
-
-		if (this.Eject(entity, forced))
-		{
-			--i; // Decrement 'i' as Eject() shortens the array.
-			ejectedEntities.push(entity);
-
-			// If 'all' is false, only ungarrison the first matched unit.
-			if (!all)
-				break;
-		}
-		else
-			success = false;
-	}
-
-	this.OrderWalkToRallyPoint(ejectedEntities);
-	this.UpdateGarrisonFlag();
-
-	return success;
-};
-
-/**
- * Unload all units from the entity
- * Returns true if all successful, false if not
- */
-GarrisonHolder.prototype.UnloadAll = function(forced)
-{
-	// Make copy of entity list
-	var entities = [];
-	for each (var entity in this.entities)
-	{
-		entities.push(entity);
-	}
-	
 	var ejectedEntities = [];
 	var success = true;
 	for each (var entity in entities)
 	{
 		if (this.Eject(entity, forced))
 		{
-			ejectedEntities.push(entity);
+			var cmpOwnership = Engine.QueryInterface(this.entity, IID_Ownership);
+			var cmpEntOwnership = Engine.QueryInterface(entity, IID_Ownership);
+			if (cmpOwnership && cmpEntOwnership && cmpOwnership.GetOwner() == cmpEntOwnership.GetOwner())
+				ejectedEntities.push(entity);
 		}
 		else
-		{
 			success = false;
-		}
 	}
-	
+
 	this.OrderWalkToRallyPoint(ejectedEntities);
 	this.UpdateGarrisonFlag();
-	
+
 	return success;
 };
 
+/**
+ * Unload unit from the garrisoning entity and order them
+ * to move to the Rally Point
+ * Returns true if successful, false if not
+ */
+GarrisonHolder.prototype.Unload = function(entity, forced)
+{
+	return this.PerformEject([entity], forced);
+};
+
+/**
+ * Unload one or all units that match a template and owner from
+ * the garrisoning entity and order them to move to the Rally Point
+ * Returns true if successful, false if not
+ * 
+ * extendedTemplate has the format "p"+ownerid+"&"+template
+ */
+GarrisonHolder.prototype.UnloadTemplate = function(extendedTemplate, all, forced)
+{
+	var index = extendedTemplate.indexOf("&");
+	if (index == -1)
+		return false;
+
+	var owner = +extendedTemplate.slice(1,index);
+	var template = extendedTemplate.slice(index+1);
+
+	var entities = [];
+	var cmpTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager);
+	for each (var entity in this.entities)
+	{
+		var cmpIdentity = Engine.QueryInterface(entity, IID_Identity);
+
+		// Units with multiple ranks are grouped together.
+		var name = cmpIdentity.GetSelectionGroupName()
+		           || cmpTemplateManager.GetCurrentTemplateName(entity);
+
+		if (name != template)
+			continue;
+		if (owner != Engine.QueryInterface(entity, IID_Ownership).GetOwner())
+			continue;
+
+		entities.push(entity);
+
+		// If 'all' is false, only ungarrison the first matched unit.
+		if (!all)
+			break;
+	}
+
+	return this.PerformEject(entities, forced);
+};
+
+/**
+ * Unload all units with same owner as the entity
+ * and order them to move to the Rally Point
+ * Returns true if all successful, false if not
+ */
+GarrisonHolder.prototype.UnloadAllOwn = function(forced)
+{
+	var cmpOwnership = Engine.QueryInterface(this.entity, IID_Ownership);
+	if (!cmpOwnership)
+		return false;
+	var owner = cmpOwnership.GetOwner();
+
+	// Make copy of entity list
+	var entities = [];
+	for each (var entity in this.entities)
+	{
+		var cmpOwnership = Engine.QueryInterface(entity, IID_Ownership);
+		if (cmpOwnership && cmpOwnership.GetOwner() == owner)
+			entities.push(entity);
+	}
+	
+	return this.PerformEject(entities, forced);
+};
+
+/**
+ * Unload all units from the entity
+ * and order them to move to the Rally Point
+ * Returns true if all successful, false if not
+ */
+GarrisonHolder.prototype.UnloadAll = function(forced)
+{
+	var entities = this.entities.slice();
+	return this.PerformEject(entities, forced);
+};
+
 /**
  * Used to check if the garrisoning entity's health has fallen below
  * a certain limit after which all garrisoned units are unloaded
  */
 GarrisonHolder.prototype.OnHealthChanged = function(msg)
 {
-	if (!this.HasEnoughHealth())
+	if (!this.HasEnoughHealth() && this.entities.length)
 	{
-		// We have to be careful of our passability
-		//	ships: not land passable, so assume units have drowned in a shipwreck
-		//  building: land passable, so units can be ejected freely
-		var classes = (Engine.QueryInterface(this.entity, IID_Identity)).GetClassesList();
-		var cmpPosition = Engine.QueryInterface(this.entity, IID_Position);
-
-		// Destroy the garrisoned units if the holder is a ship or is not in the
-		// world (generally means this holder is inside a ship which has sunk).
-		if (classes.indexOf("Ship") != -1 || !cmpPosition.IsInWorld())
-		{
-			for each (var entity in this.entities)
-			{
-				var cmpHealth = Engine.QueryInterface(entity, IID_Health);
-				if (cmpHealth)
-				{
-					cmpHealth.Kill();
-				}
-			}
-			this.entities = [];
-			Engine.PostMessage(this.entity, MT_GarrisonedUnitsChanged, {});
-		}
-		else
-		{	// Building - force ejection
-			this.UnloadAll(true);
-		}
+		var entities = this.entities.slice();
+		this.EjectOrKill(entities);
 	}
 };
 
@@ -422,6 +530,20 @@ GarrisonHolder.prototype.OnDestroy = function()
  */
 GarrisonHolder.prototype.OnGlobalOwnershipChanged = function(msg)
 {
+	// the ownership change may be on the garrisonholder
+	if (this.entity == msg.entity)
+	{
+		var entities = [];
+		for each (var entity in this.entities)
+		{
+			if (msg.to == -1 || !IsOwnedByMutualAllyOfEntity(this.entity, entity))
+				entities.push(entity);
+		}
+		this.EjectOrKill(entities);
+		return;
+	}
+
+	// or on some of its garrisoned units
 	var entityIndex = this.entities.indexOf(msg.entity);
 	if (entityIndex != -1)
 	{
@@ -431,28 +553,10 @@ GarrisonHolder.prototype.OnGlobalOwnershipChanged = function(msg)
 		{
 			this.entities.splice(entityIndex, 1);
 			Engine.PostMessage(this.entity, MT_GarrisonedUnitsChanged, {});
+			this.UpdateGarrisonFlag();
 		}
-		else
-		{
-			// We have to be careful of our passability
-			//	ships: not land passable, assume unit was thrown overboard or something
-			//  building: land passable, unit can be ejected freely
-			var classes = (Engine.QueryInterface(this.entity, IID_Identity)).GetClassesList();
-			if (classes.indexOf("Ship") != -1)
-			{	// Ship - kill unit
-				var cmpHealth = Engine.QueryInterface(msg.entity, IID_Health);
-				if (cmpHealth)
-				{
-					cmpHealth.Kill();
-				}
-				this.entities.splice(entityIndex, 1);
-				Engine.PostMessage(this.entity, MT_GarrisonedUnitsChanged, {});
-			}
-			else
-			{	// Building - force ejection
-				this.Eject(msg.entity, true);
-			}
-		}
+		else if(!IsOwnedByMutualAllyOfEntity(this.entity, this.entities[entityIndex]))
+			this.EjectOrKill([this.entities[entityIndex]]);
 	}
 };
 
@@ -469,5 +573,48 @@ GarrisonHolder.prototype.OnGlobalEntityRenamed = function(msg)
 	}
 };
 
+
+/**
+ * Eject all foreign garrisoned entities which are no more allied
+ */
+GarrisonHolder.prototype.OnDiplomacyChanged = function()
+{
+	var entities = []
+	for each (var entity in this.entities)
+	{
+		if (!IsOwnedByMutualAllyOfEntity(this.entity, entity))
+			entities.push(entity);
+	}
+	this.EjectOrKill(entities);
+};
+
+/**
+ * Eject or kill a garrisoned unit which can no more be garrisoned
+ * (garrisonholder's health too small or ownership changed)
+ */
+GarrisonHolder.prototype.EjectOrKill = function(entities)
+{
+	var cmpPosition = Engine.QueryInterface(this.entity, IID_Position);
+	// Eject the units which can be ejected (if not in world, it generally means this holder
+	// is inside a holder which kills its entities, so do not eject)
+	if (cmpPosition.IsInWorld() && this.EjectEntitiesOnDestroy())
+		this.PerformEject(entities, true);
+
+	// And destroy all remaining entities
+	for each (var entity in entities)
+	{
+		var entityIndex = this.entities.indexOf(entity);
+		if (entityIndex == -1)
+			continue;
+		var cmpHealth = Engine.QueryInterface(entity, IID_Health);
+		if (cmpHealth)
+			cmpHealth.Kill();
+		this.entities.splice(entityIndex, 1);
+	}
+
+	Engine.PostMessage(this.entity, MT_GarrisonedUnitsChanged, {});
+	this.UpdateGarrisonFlag();
+};
+
 Engine.RegisterComponentType(IID_GarrisonHolder, "GarrisonHolder", GarrisonHolder);
 
