@@ -20,7 +20,6 @@ GuiInterface.prototype.Init = function()
 	this.placementEntity = undefined; // = undefined or [templateName, entityID]
 	this.placementWallEntities = undefined;
 	this.placementWallLastAngle = 0;
-	this.rallyPoints = undefined;
 	this.notifications = [];
 	this.renamedEntities = [];
 };
@@ -64,11 +63,13 @@ GuiInterface.prototype.GetSimulationState = function(player)
 		
 		// store player ally/neutral/enemy data as arrays
 		var allies = [];
+		var mutualAllies = [];
 		var neutrals = [];
 		var enemies = [];
 		for (var j = 0; j < n; ++j)
 		{
 			allies[j] = cmpPlayer.IsAlly(j);
+			mutualAllies[j] = cmpPlayer.IsMutualAlly(j);
 			neutrals[j] = cmpPlayer.IsNeutral(j);
 			enemies[j] = cmpPlayer.IsEnemy(j);
 		}
@@ -79,13 +80,16 @@ GuiInterface.prototype.GetSimulationState = function(player)
 			"popCount": cmpPlayer.GetPopulationCount(),
 			"popLimit": cmpPlayer.GetPopulationLimit(),
 			"popMax": cmpPlayer.GetMaxPopulation(),
+			"heroes": cmpPlayer.GetHeroes(),
 			"resourceCounts": cmpPlayer.GetResourceCounts(),
 			"trainingBlocked": cmpPlayer.IsTrainingBlocked(),
 			"state": cmpPlayer.GetState(),
 			"team": cmpPlayer.GetTeam(),
 			"teamsLocked": cmpPlayer.GetLockTeams(),
+			"cheatsEnabled": cmpPlayer.GetCheatsEnabled(),
 			"phase": phase,
 			"isAlly": allies,
+			"isMutualAlly": mutualAllies,
 			"isNeutral": neutrals,
 			"isEnemy": enemies,
 			"entityLimits": cmpPlayerEntityLimits.GetLimits(),
@@ -141,6 +145,9 @@ GuiInterface.prototype.ClearRenamedEntities = function(player)
 	this.renamedEntities = [];
 };
 
+/**
+ * Get common entity info, often used in the gui
+ */
 GuiInterface.prototype.GetEntityState = function(player, ent)
 {
 	var cmpTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager);
@@ -169,6 +176,7 @@ GuiInterface.prototype.GetEntityState = function(player, ent)
 	if (cmpPosition && cmpPosition.IsInWorld())
 	{
 		ret.position = cmpPosition.GetPosition();
+		ret.rotation = cmpPosition.GetRotation();
 	}
 
 	var cmpHealth = Engine.QueryInterface(ent, IID_Health);
@@ -180,23 +188,6 @@ GuiInterface.prototype.GetEntityState = function(player, ent)
 		ret.needsHeal = !cmpHealth.IsUnhealable();
 	}
 
-	var cmpAttack = Engine.QueryInterface(ent, IID_Attack);
-	if (cmpAttack)
-	{
-		var type = cmpAttack.GetBestAttack(); // TODO: how should we decide which attack to show? show all?
-		ret.attack = cmpAttack.GetAttackStrengths(type);
-		var range = cmpAttack.GetRange(type);
-		ret.attack.type = type;
-		ret.attack.minRange = range.min;
-		ret.attack.maxRange = range.max;
-	}
-
-	var cmpArmour = Engine.QueryInterface(ent, IID_DamageReceiver);
-	if (cmpArmour)
-	{
-		ret.armour = cmpArmour.GetArmourStrengths();
-	}
-
 	var cmpBuilder = Engine.QueryInterface(ent, IID_Builder);
 	if (cmpBuilder)
 	{
@@ -235,10 +226,126 @@ GuiInterface.prototype.GetEntityState = function(player, ent)
 	if (cmpFoundation)
 	{
 		ret.foundation = {
-			"progress": cmpFoundation.GetBuildPercentage()
+			"progress": cmpFoundation.GetBuildPercentage(),
+			"numBuilders": cmpFoundation.GetNumBuilders()
 		};
 	}
 
+	var cmpOwnership = Engine.QueryInterface(ent, IID_Ownership);
+	if (cmpOwnership)
+	{
+		ret.player = cmpOwnership.GetOwner();
+	}
+
+	var cmpRallyPoint = Engine.QueryInterface(ent, IID_RallyPoint);
+	if (cmpRallyPoint)
+	{
+		ret.rallyPoint = {'position': cmpRallyPoint.GetPositions()[0]}; // undefined or {x,z} object
+	}
+
+	var cmpGarrisonHolder = Engine.QueryInterface(ent, IID_GarrisonHolder);
+	if (cmpGarrisonHolder)
+	{
+		ret.garrisonHolder = {
+			"entities": cmpGarrisonHolder.GetEntities(),
+			"allowedClasses": cmpGarrisonHolder.GetAllowedClassesList(),
+			"capacity": cmpGarrisonHolder.GetCapacity(),
+			"garrisonedEntitiesCount": cmpGarrisonHolder.GetGarrisonedEntitiesCount()
+		};
+	}
+	
+	var cmpUnitAI = Engine.QueryInterface(ent, IID_UnitAI);
+	if (cmpUnitAI)
+	{
+		ret.unitAI = {
+			"state": cmpUnitAI.GetCurrentState(),
+			"orders": cmpUnitAI.GetOrders(),
+			"hasWorkOrders": cmpUnitAI.HasWorkOrders(),
+			"canGuard": cmpUnitAI.CanGuard(),
+			"isGuarding": cmpUnitAI.IsGuardOf(),
+		};
+		// Add some information needed for ungarrisoning
+		if (cmpUnitAI.isGarrisoned && ret.player !== undefined)
+			ret.template = "p" + ret.player + "&" + ret.template;
+	}
+
+	var cmpGuard = Engine.QueryInterface(ent, IID_Guard);
+	if (cmpGuard)
+	{
+		ret.guard = {
+			"entities": cmpGuard.GetEntities(),
+		};
+	}
+
+	var cmpGate = Engine.QueryInterface(ent, IID_Gate);
+	if (cmpGate)
+	{
+		ret.gate = {
+			"locked": cmpGate.IsLocked(),
+		};
+	}
+
+	var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
+	ret.visibility = cmpRangeManager.GetLosVisibility(ent, player, false);
+
+	return ret;
+};
+
+/**
+ * Get additionnal entity info, rarely used in the gui
+ */
+GuiInterface.prototype.GetExtendedEntityState = function(player, ent)
+{
+	var ret = {};
+
+	var cmpIdentity = Engine.QueryInterface(ent, IID_Identity);
+
+	var cmpAttack = Engine.QueryInterface(ent, IID_Attack);
+	if (cmpAttack)
+	{
+		var type = cmpAttack.GetBestAttack(); // TODO: how should we decide which attack to show? show all?
+		ret.attack = cmpAttack.GetAttackStrengths(type);
+		var range = cmpAttack.GetRange(type);
+		ret.attack.type = type;
+		ret.attack.minRange = range.min;
+		ret.attack.maxRange = range.max;
+		if (type == "Ranged")
+		{
+			ret.attack.elevationBonus = range.elevationBonus;
+			var cmpPosition = Engine.QueryInterface(ent, IID_Position);
+			var cmpUnitAI = Engine.QueryInterface(ent, IID_UnitAI);
+			var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
+			if (cmpUnitAI && cmpPosition && cmpPosition.IsInWorld())
+			{
+				// For units, take the rage in front of it, no spread. So angle = 0
+				ret.attack.elevationAdaptedRange = cmpRangeManager.GetElevationAdaptedRange(cmpPosition.GetPosition(), cmpPosition.GetRotation(), range.max, range.elevationBonus, 0);
+			}
+			else if(cmpPosition && cmpPosition.IsInWorld())
+			{
+				// For buildings, take the average elevation around it. So angle = 2*pi
+				ret.attack.elevationAdaptedRange = cmpRangeManager.GetElevationAdaptedRange(cmpPosition.GetPosition(), cmpPosition.GetRotation(), range.max, range.elevationBonus, 2*Math.PI);
+			}
+			else
+			{
+				// not in world, set a default?
+				ret.attack.elevationAdaptedRange = ret.attack.maxRange;
+			}
+			
+		}
+		else
+		{
+			// not a ranged attack, set some defaults
+			ret.attack.elevationBonus = 0;
+			ret.attack.elevationAdaptedRange = ret.attack.maxRange;
+		}
+	}
+
+	var cmpArmour = Engine.QueryInterface(ent, IID_DamageReceiver);
+	if (cmpArmour)
+	{
+		ret.armour = cmpArmour.GetArmourStrengths();
+	}
+
 	var cmpObstruction = Engine.QueryInterface(ent, IID_Obstruction);
 	if (cmpObstruction)
 	{
@@ -248,16 +355,11 @@ GuiInterface.prototype.GetEntityState = function(player, ent)
 		};
 	}
 
-	var cmpOwnership = Engine.QueryInterface(ent, IID_Ownership);
-	if (cmpOwnership)
-	{
-		ret.player = cmpOwnership.GetOwner();
-	}
-
 	var cmpResourceSupply = Engine.QueryInterface(ent, IID_ResourceSupply);
 	if (cmpResourceSupply)
 	{
 		ret.resourceSupply = {
+			"isInfinite": cmpResourceSupply.IsInfinite(),
 			"max": cmpResourceSupply.GetMaxAmount(),
 			"amount": cmpResourceSupply.GetCurrentAmount(),
 			"type": cmpResourceSupply.GetType(),
@@ -281,21 +383,6 @@ GuiInterface.prototype.GetEntityState = function(player, ent)
 			"types": cmpResourceDropsite.GetTypes()
 		};
 	}
-
-	var cmpRallyPoint = Engine.QueryInterface(ent, IID_RallyPoint);
-	if (cmpRallyPoint)
-	{
-		ret.rallyPoint = {'position': cmpRallyPoint.GetPositions()[0]}; // undefined or {x,z} object
-	}
-
-	var cmpGarrisonHolder = Engine.QueryInterface(ent, IID_GarrisonHolder);
-	if (cmpGarrisonHolder)
-	{
-		ret.garrisonHolder = {
-			"entities": cmpGarrisonHolder.GetEntities(),
-			"allowedClasses": cmpGarrisonHolder.GetAllowedClassesList()
-		};
-	}
 	
 	var cmpPromotion = Engine.QueryInterface(ent, IID_Promotion);
 	if (cmpPromotion)
@@ -304,25 +391,9 @@ GuiInterface.prototype.GetEntityState = function(player, ent)
 			"curr": cmpPromotion.GetCurrentXp(),
 			"req": cmpPromotion.GetRequiredXp()
 		};
-	}
-	
-	var cmpUnitAI = Engine.QueryInterface(ent, IID_UnitAI);
-	if (cmpUnitAI)
-	{
-		ret.unitAI = {
-			"state": cmpUnitAI.GetCurrentState(),
-			"orders": cmpUnitAI.GetOrders(),
-		};
-	}
-	
-	var cmpGate = Engine.QueryInterface(ent, IID_Gate);
-	if (cmpGate)
-	{
-		ret.gate = {
-			"locked": cmpGate.IsLocked(),
-		};
 	}	
 
+	var cmpFoundation = Engine.QueryInterface(ent, IID_Foundation);
 	if (!cmpFoundation && cmpIdentity && cmpIdentity.HasClass("BarterMarket"))
 	{
 		var cmpBarter = Engine.QueryInterface(SYSTEM_ENTITY, IID_Barter);
@@ -332,20 +403,35 @@ GuiInterface.prototype.GetEntityState = function(player, ent)
 	var cmpHeal = Engine.QueryInterface(ent, IID_Heal);
 	if (cmpHeal)
 	{
-		ret.Healer = { 
+		ret.healer = { 
 			"unhealableClasses": cmpHeal.GetUnhealableClasses(),
 			"healableClasses": cmpHeal.GetHealableClasses(),
 		};
 	}
 
-	var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
-	ret.visibility = cmpRangeManager.GetLosVisibility(ent, player, false);
-
 	return ret;
 };
 
-GuiInterface.prototype.GetTemplateData = function(player, name)
+GuiInterface.prototype.GetAverageRangeForBuildings = function(player, cmd)
 {
+	var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
+	var cmpTerrain = Engine.QueryInterface(SYSTEM_ENTITY, IID_Terrain);
+	var rot = {x:0, y:0, z:0};
+	var pos = {x:cmd.x,z:cmd.z};
+	pos.y = cmpTerrain.GetGroundLevel(cmd.x, cmd.z);
+	var elevationBonus = cmd.elevationBonus || 0;
+	var range = cmd.range;
+
+	return cmpRangeManager.GetElevationAdaptedRange(pos, rot, range, elevationBonus, 2*Math.PI);
+};
+
+GuiInterface.prototype.GetTemplateData = function(player, extendedName)
+{
+	var name = extendedName;
+	// Special case for garrisoned units which have a extended template
+	if (extendedName.indexOf("&") != -1)
+		name = extendedName.slice(extendedName.indexOf("&")+1);
+
 	var cmpTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager);
 	var template = cmpTemplateManager.GetTemplate(name);
 
@@ -354,15 +440,12 @@ GuiInterface.prototype.GetTemplateData = function(player, name)
 
 	var ret = {};
 
-	var cmpTechnologyManager = QueryPlayerIDInterface(player, IID_TechnologyManager);
-	var techMods = cmpTechnologyManager.GetTechModifications();
-
 	if (template.Armour)
 	{
 		ret.armour = {
-			"hack": GetTechModifiedProperty(techMods, template, "Armour/Hack", +template.Armour.Hack),
-			"pierce": GetTechModifiedProperty(techMods, template, "Armour/Pierce", +template.Armour.Pierce),
-			"crush": GetTechModifiedProperty(techMods, template, "Armour/Crush", +template.Armour.Crush),
+			"hack": ApplyValueModificationsToTemplate("Armour/Hack", +template.Armour.Hack, player, template),
+			"pierce": ApplyValueModificationsToTemplate("Armour/Pierce", +template.Armour.Hack, player, template),
+			"crush": ApplyValueModificationsToTemplate("Armour/Crush", +template.Armour.Hack, player, template),
 		};
 	}
 	
@@ -372,11 +455,12 @@ GuiInterface.prototype.GetTemplateData = function(player, name)
 		for (var type in template.Attack)
 		{
 			ret.attack[type] = {
-				"hack": GetTechModifiedProperty(techMods, template, "Attack/"+type+"/Hack", +(template.Attack[type].Hack || 0)),
-				"pierce": GetTechModifiedProperty(techMods, template, "Attack/"+type+"/Pierce", +(template.Attack[type].Pierce || 0)),
-				"crush": GetTechModifiedProperty(techMods, template, "Attack/"+type+"/Crush", +(template.Attack[type].Crush || 0)),
-				"minRange": GetTechModifiedProperty(techMods, template, "Attack/"+type+"/MinRange", +(template.Attack[type].MinRange || 0)),
-				"maxRange": GetTechModifiedProperty(techMods, template, "Attack/"+type+"/MaxRange", +template.Attack[type].MaxRange),
+				"hack": ApplyValueModificationsToTemplate("Attack/"+type+"/Hack", +(template.Attack[type].Hack || 0), player, template),
+				"pierce": ApplyValueModificationsToTemplate("Attack/"+type+"/Pierce", +(template.Attack[type].Pierce || 0), player, template),
+				"crush": ApplyValueModificationsToTemplate("Attack/"+type+"/Crush", +(template.Attack[type].Crush || 0), player, template),
+				"minRange": ApplyValueModificationsToTemplate("Attack/"+type+"/MinRange", +(template.Attack[type].MinRange || 0), player, template),
+				"maxRange": ApplyValueModificationsToTemplate("Attack/"+type+"/MaxRange", +template.Attack[type].MaxRange, player, template),
+				"elevationBonus": ApplyValueModificationsToTemplate("Attack/"+type+"/ElevationBonus", +(template.Attack[type].ElevationBonus || 0), player, template),
 			};
 		}
 	}
@@ -411,13 +495,13 @@ GuiInterface.prototype.GetTemplateData = function(player, name)
 	if (template.Cost)
 	{
 		ret.cost = {};
-		if (template.Cost.Resources.food) ret.cost.food = GetTechModifiedProperty(techMods, template, "Cost/Resources/food", +template.Cost.Resources.food);
-		if (template.Cost.Resources.wood) ret.cost.wood = GetTechModifiedProperty(techMods, template, "Cost/Resources/wood", +template.Cost.Resources.wood);
-		if (template.Cost.Resources.stone) ret.cost.stone = GetTechModifiedProperty(techMods, template, "Cost/Resources/stone", +template.Cost.Resources.stone);
-		if (template.Cost.Resources.metal) ret.cost.metal = GetTechModifiedProperty(techMods, template, "Cost/Resources/metal", +template.Cost.Resources.metal);
-		if (template.Cost.Population) ret.cost.population = GetTechModifiedProperty(techMods, template, "Cost/Population", +template.Cost.Population);
-		if (template.Cost.PopulationBonus) ret.cost.populationBonus = GetTechModifiedProperty(techMods, template, "Cost/PopulationBonus", +template.Cost.PopulationBonus);
-		if (template.Cost.BuildTime) ret.cost.time = GetTechModifiedProperty(techMods, template, "Cost/BuildTime", +template.Cost.BuildTime);
+		if (template.Cost.Resources.food) ret.cost.food = ApplyValueModificationsToTemplate("Cost/Resources/food", +template.Cost.Resources.food, player, template);
+		if (template.Cost.Resources.wood) ret.cost.wood = ApplyValueModificationsToTemplate("Cost/Resources/wood", +template.Cost.Resources.wood, player, template);
+		if (template.Cost.Resources.stone) ret.cost.stone = ApplyValueModificationsToTemplate("Cost/Resources/stone", +template.Cost.Resources.stone, player, template);
+		if (template.Cost.Resources.metal) ret.cost.metal = ApplyValueModificationsToTemplate("Cost/Resources/metal", +template.Cost.Resources.metal, player, template);
+		if (template.Cost.Population) ret.cost.population = ApplyValueModificationsToTemplate("Cost/Population", +template.Cost.Population, player, template);
+		if (template.Cost.PopulationBonus) ret.cost.populationBonus = ApplyValueModificationsToTemplate("Cost/PopulationBonus", +template.Cost.PopulationBonus, player, template);
+		if (template.Cost.BuildTime) ret.cost.time = ApplyValueModificationsToTemplate("Cost/BuildTime", +template.Cost.BuildTime, player, template);
 	}
 	
 	if (template.Footprint)
@@ -466,13 +550,13 @@ GuiInterface.prototype.GetTemplateData = function(player, name)
 	{
 		ret.pack = {
 			"state": template.Pack.State,
-			"time": GetTechModifiedProperty(techMods, template, "Pack/Time", +template.Pack.Time),
+			"time": ApplyValueModificationsToTemplate("Pack/Time", +template.Pack.Time, player, template),
 		};
 	}
 
 	if (template.Health)
 	{
-		ret.health = Math.round(GetTechModifiedProperty(techMods, template, "Health/Max", +template.Health.Max));
+		ret.health = Math.round(ApplyValueModificationsToTemplate("Health/Max", +template.Health.Max, player, template));
 	}
 
 	if (template.Identity)
@@ -491,9 +575,9 @@ GuiInterface.prototype.GetTemplateData = function(player, name)
 	if (template.UnitMotion)
 	{
 		ret.speed = {
-			"walk": +template.UnitMotion.WalkSpeed,
+			"walk": ApplyValueModificationsToTemplate("UnitMotion/WalkSpeed", +template.UnitMotion.WalkSpeed, player, template),
 		};
-		if (template.UnitMotion.Run) ret.speed.run = +template.UnitMotion.Run.Speed;
+		if (template.UnitMotion.Run) ret.speed.run = ApplyValueModificationsToTemplate("UnitMotion/Run/Speed", +template.UnitMotion.Run.Speed, player, template);
 	}
 
 	if (template.Trader)
@@ -619,6 +703,13 @@ GuiInterface.prototype.GetBattleState = function(player)
 	return cmpBattleDetection.GetState();
 };
 
+// Returns a list of ongoing attacks against the player.
+GuiInterface.prototype.GetIncomingAttacks = function(player)
+{
+	var cmpAttackDetection = QueryPlayerIDInterface(player, IID_AttackDetection);
+	return cmpAttackDetection.GetIncomingAttacks();
+};
+
 // Used to show a red square over GUI elements you can't yet afford.
 GuiInterface.prototype.GetNeededResources = function(player, amounts)
 {
@@ -687,7 +778,7 @@ GuiInterface.prototype.IsStanceSelected = function(player, data)
 	return false;
 };
 
-GuiInterface.prototype.SetSelectionHighlight = function(player, cmd, selected)
+GuiInterface.prototype.SetSelectionHighlight = function(player, cmd)
 {
 	var cmpPlayerMan = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
 	var playerColours = {}; // cache of owner -> colour map
@@ -792,6 +883,11 @@ GuiInterface.prototype.DisplayRallyPoint = function(player, cmd)
 				cmpRallyPointRenderer.AddPosition({'x': pos.x, 'y': pos.z}); // AddPosition takes a CFixedVector2D which has X/Y components, not X/Z
 			else if (cmd.queued == false)
 				cmpRallyPointRenderer.SetPosition({'x': pos.x, 'y': pos.z}); // SetPosition takes a CFixedVector2D which has X/Y components, not X/Z
+			// rebuild the renderer when not set (when reading saved game or in case of building update)
+			else if (!cmpRallyPointRenderer.IsSet())
+				for each (var posi in cmpRallyPoint.GetPositions())
+					cmpRallyPointRenderer.AddPosition({'x': posi.x, 'y': posi.z});
+
 			cmpRallyPointRenderer.SetDisplayed(true);
 			
 			// remember which entities have their rally points displayed so we can hide them again
@@ -1434,7 +1530,7 @@ GuiInterface.prototype.GetFoundationSnapData = function(player, data)
 		var minDistEntitySnapData = null;
 		var radius2 = data.snapRadius * data.snapRadius;
 		
-		for each (ent in data.snapEntities)
+		for each (var ent in data.snapEntities)
 		{
 			var cmpPosition = Engine.QueryInterface(ent, IID_Position);
 			if (!cmpPosition || !cmpPosition.IsInWorld())
@@ -1668,6 +1764,12 @@ GuiInterface.prototype.GetBatchTime = function(player, data)
 	return cmpProductionQueue.GetBatchTime(data.batchSize);
 };
 
+GuiInterface.prototype.IsMapRevealed = function(player)
+{
+	var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
+	return cmpRangeManager.GetLosRevealAll(-1);
+};
+
 GuiInterface.prototype.SetPathfinderDebugOverlay = function(player, enabled)
 {
 	var cmpPathfinder = Engine.QueryInterface(SYSTEM_ENTITY, IID_Pathfinder);
@@ -1713,12 +1815,15 @@ var exposedFunctions = {
 	"GetRenamedEntities": 1,
 	"ClearRenamedEntities": 1,
 	"GetEntityState": 1,
+	"GetExtendedEntityState": 1,
+	"GetAverageRangeForBuildings": 1,
 	"GetTemplateData": 1,
 	"GetTechnologyData": 1,
 	"IsTechnologyResearched": 1,
 	"CheckTechnologyRequirements": 1,
 	"GetStartedResearch": 1,
 	"GetBattleState": 1,
+	"GetIncomingAttacks": 1,
 	"GetNeededResources": 1,
 	"GetNextNotification": 1,
 
@@ -1742,6 +1847,7 @@ var exposedFunctions = {
 	"CanAttack": 1,
 	"GetBatchTime": 1,
 
+	"IsMapRevealed": 1,
 	"SetPathfinderDebugOverlay": 1,
 	"SetObstructionDebugOverlay": 1,
 	"SetMotionDebugOverlay": 1,
