@@ -42,7 +42,7 @@ Heal.prototype.GetTimers = function()
 	var prepare = 1000;
 	var repeat = +this.template.Rate;
 
-	repeat = ApplyTechModificationsToEntity("Heal/Rate", repeat, this.entity);
+	repeat = ApplyValueModificationsToEntity("Heal/Rate", repeat, this.entity);
 	
 	return { "prepare": prepare, "repeat": repeat };
 };
@@ -52,7 +52,7 @@ Heal.prototype.GetRange = function()
 	var min = 0;
 	var max = +this.template.Range;
 	
-	max = ApplyTechModificationsToEntity("Heal/Range", max, this.entity);
+	max = ApplyValueModificationsToEntity("Heal/Range", max, this.entity);
 
 	return { "max": max, "min": min };
 };
@@ -60,14 +60,13 @@ Heal.prototype.GetRange = function()
 Heal.prototype.GetUnhealableClasses = function()
 {
 	var classes = this.template.UnhealableClasses._string;
-	// If we have no unhealable classes defined classes is undefined
 	return classes ? classes.split(/\s+/) : [];
 };
 
 Heal.prototype.GetHealableClasses = function()
 {
 	var classes = this.template.HealableClasses._string;
-	return classes.split(/\s+/);
+	return classes ? classes.split(/\s+/) : [];
 };
 
 /**
@@ -80,16 +79,13 @@ Heal.prototype.PerformHeal = function(target)
 	var cmpHealth = Engine.QueryInterface(target, IID_Health);
 	if (!cmpHealth)
 		return;
-	
-	var hp = +this.template.HP;
-	hp = ApplyTechModificationsToEntity("Heal/HP", hp, this.entity);
-	
-	var targetState = cmpHealth.Increase(hp);
+
+	var targetState = cmpHealth.Increase(ApplyValueModificationsToEntity("Heal/HP", +this.template.HP, this.entity));
 
 	// Add XP
 	var cmpLoot = Engine.QueryInterface(target, IID_Loot);
 	var cmpPromotion = Engine.QueryInterface(this.entity, IID_Promotion);
-	if (targetState!==undefined && cmpLoot && cmpPromotion)
+	if (targetState !== undefined && cmpLoot && cmpPromotion)
 	{
 		// HP healed * XP per HP
 		cmpPromotion.IncreaseXp((targetState.new-targetState.old)*(cmpLoot.GetXp()/cmpHealth.GetMaxHitpoints()));
