@@ -19,7 +19,7 @@ Player.prototype.Init = function()
 		"metal": 300,
 		"stone": 300
 	};
-
+	
 	this.team = -1;	// team number of the player, players on the same team will always have ally diplomatic status - also this is useful for team emblems, scoring, etc.
 	this.teamsLocked = false;
 	this.state = "active"; // game state - one of "active", "defeated", "won"
@@ -31,8 +31,10 @@ Player.prototype.Init = function()
 	this.controlAllUnits = false;
 	this.isAI = false;
 	this.gatherRateMultiplier = 1;
-	this.cheatsEnabled = true;
+	this.cheatsEnabled = false;
 	this.cheatTimeMultiplier = 1;
+	this.heroes = [];
+	Engine.QueryInterface(SYSTEM_ENTITY, IID_EndGameManager).CheckPlayers();
 };
 
 Player.prototype.SetPlayerID = function(id)
@@ -95,6 +97,11 @@ Player.prototype.GetPopulationCount = function()
 	return this.popUsed;
 };
 
+Player.prototype.SetPopulationBonuses = function(num)
+{
+	this.popBonuses = num;
+};
+
 Player.prototype.GetPopulationLimit = function()
 {
 	return Math.min(this.GetMaxPopulation(), this.popBonuses);
@@ -107,7 +114,7 @@ Player.prototype.SetMaxPopulation = function(max)
 
 Player.prototype.GetMaxPopulation = function()
 {
-	return Math.round(ApplyTechModificationsToPlayer("Player/MaxPopulation", this.maxPop, this.entity));
+	return Math.round(ApplyValueModificationsToPlayer("Player/MaxPopulation", this.maxPop, this.entity));
 };
 
 Player.prototype.SetGatherRateMultiplier = function(value)
@@ -120,6 +127,11 @@ Player.prototype.GetGatherRateMultiplier = function()
 	return this.gatherRateMultiplier;
 };
 
+Player.prototype.GetHeroes = function()
+{
+	return this.heroes;
+};
+
 Player.prototype.IsTrainingBlocked = function()
 {
 	return this.trainingBlocked;
@@ -351,12 +363,8 @@ Player.prototype.UpdateSharedLos = function()
 
 	var sharedLos = [];
 	for (var i = 0; i < cmpPlayerManager.GetNumPlayers(); ++i)
-		if (this.IsAlly(i))
-		{
-			var cmpPlayer = Engine.QueryInterface(cmpPlayerManager.GetPlayerByID(i), IID_Player);
-			if (cmpPlayer && cmpPlayer.IsAlly(this.playerID))
-				sharedLos.push(i);
-		}
+		if (this.IsMutualAlly(i))
+			sharedLos.push(i);
 
 	cmpRangeManager.SetSharedLos(this.playerID, sharedLos);
 };
@@ -424,11 +432,36 @@ Player.prototype.IsAlly = function(id)
 	return this.diplomacy[id] > 0;
 };
 
+/**
+ * Check if given player is our ally, and we are its ally
+ */
+Player.prototype.IsMutualAlly = function(id)
+{
+	var cmpPlayerManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
+	if (!cmpPlayerManager)
+		return false;
+
+	var cmpPlayer = Engine.QueryInterface(cmpPlayerManager.GetPlayerByID(id), IID_Player);
+	return this.IsAlly(id) && cmpPlayer && cmpPlayer.IsAlly(this.playerID);
+};
+
 Player.prototype.SetEnemy = function(id)
 {
 	this.SetDiplomacyIndex(id, -1);
 };
 
+/**
+ * Get all enemies of a given player.
+ */
+Player.prototype.GetEnemies = function()
+{
+	var enemies = [];
+	for (var i = 0; i < this.diplomacy.length; i++)
+		if (this.diplomacy[i] < 0)
+			enemies.push(i);
+	return enemies;
+};
+
 /**
  * Check if given player is our enemy
  */
@@ -456,37 +489,47 @@ Player.prototype.IsNeutral = function(id)
  */
 Player.prototype.OnGlobalOwnershipChanged = function(msg)
 {
-	var isConquestCritical = false;
-	// Load class list only if we're going to need it
-	if (msg.from == this.playerID || msg.to == this.playerID)
-	{
-		var cmpIdentity = Engine.QueryInterface(msg.entity, IID_Identity);
-		if (cmpIdentity)
-		{
-			isConquestCritical = cmpIdentity.HasClass("ConquestCritical");
-		}
-	}
+	if (msg.from != this.playerID && msg.to != this.playerID)
+		return;
+
+	var cmpIdentity = Engine.QueryInterface(msg.entity, IID_Identity);
+	var cmpCost = Engine.QueryInterface(msg.entity, IID_Cost);
+
 	if (msg.from == this.playerID)
 	{
-		if (isConquestCritical)
+		if (cmpIdentity && cmpIdentity.HasClass("ConquestCritical"))
 			this.conquestCriticalEntitiesCount--;
-		var cost = Engine.QueryInterface(msg.entity, IID_Cost);
-		if (cost)
+
+		if (this.conquestCriticalEntitiesCount == 0) // end game when needed
+			Engine.QueryInterface(SYSTEM_ENTITY, IID_EndGameManager).CheckPlayers();
+
+		if (cmpCost)
 		{
-			this.popUsed -= cost.GetPopCost();
-			this.popBonuses -= cost.GetPopBonus();
+			this.popUsed -= cmpCost.GetPopCost();
+			this.popBonuses -= cmpCost.GetPopBonus();
+		}
+
+		if (cmpIdentity && cmpIdentity.HasClass("Hero"))
+		{
+			//Remove from Heroes list
+			var index = this.heroes.indexOf(msg.entity);
+			if (index >= 0)
+				this.heroes.splice(index, 1);
 		}
 	}
 	if (msg.to == this.playerID)
 	{
-		if (isConquestCritical)
+		if (cmpIdentity && cmpIdentity.HasClass("ConquestCritical"))
 			this.conquestCriticalEntitiesCount++;
-		var cost = Engine.QueryInterface(msg.entity, IID_Cost);
-		if (cost)
+
+		if (cmpCost)
 		{
-			this.popUsed += cost.GetPopCost();
-			this.popBonuses += cost.GetPopBonus();
+			this.popUsed += cmpCost.GetPopCost();
+			this.popBonuses += cmpCost.GetPopBonus();
 		}
+
+		if (cmpIdentity && cmpIdentity.HasClass("Hero"))
+			this.heroes.push(msg.entity);
 	}
 };
 
@@ -528,16 +571,26 @@ Player.prototype.OnDiplomacyChanged = function()
 	this.UpdateSharedLos();
 };
 
-Player.prototype.SetCheatEnabled = function(flag)
+Player.prototype.SetCheatsEnabled = function(flag)
 {
 	this.cheatsEnabled = flag;
 };
 
-Player.prototype.GetCheatEnabled = function(flag)
+Player.prototype.GetCheatsEnabled = function()
 {
 	return this.cheatsEnabled;
 };
 
+Player.prototype.SetCheatTimeMultiplier = function(time)
+{
+	this.cheatTimeMultiplier = time;
+};
+
+Player.prototype.GetCheatTimeMultiplier = function()
+{
+	return this.cheatTimeMultiplier;
+};
+
 Player.prototype.TributeResource = function(player, amounts)
 {
 	var cmpPlayerManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
