@@ -39,11 +39,15 @@ PlayerManager.prototype.GetNumPlayers = function()
 PlayerManager.prototype.RemoveAllPlayers = function()
 {
 	// Destroy existing player entities
-	for each (id in this.playerEntities)
+	for each (var id in this.playerEntities)
 	{
 		Engine.DestroyEntity(id);
 	}
 	this.playerEntities = [];
 };
 
+PlayerManager.prototype.GetAllPlayerEntities = function()
+{
+	return this.playerEntities;
+};
 Engine.RegisterComponentType(IID_PlayerManager, "PlayerManager", PlayerManager);
