@@ -61,7 +61,8 @@ ProductionQueue.prototype.Init = function()
 	//   }
 	
 	this.timer = undefined; // g_ProgressInterval msec timer, active while the queue is non-empty
-	
+	this.paused = false;
+
 	this.entityCache = [];
 	this.spawnNotified = false;
 };
@@ -75,6 +76,8 @@ ProductionQueue.prototype.GetEntitiesList = function()
 		return [];
 	
 	var string = this.template.Entities._string;
+	if (!string)
+		return [];
 	
 	// Replace the "{civ}" codes with this entity's civ ID
 	var cmpIdentity = Engine.QueryInterface(this.entity, IID_Identity);
@@ -93,6 +96,8 @@ ProductionQueue.prototype.GetTechnologiesList = function()
 		return [];
 	
 	var string = this.template.Technologies._string;
+	if (!string)
+		return [];
 	
 	var cmpTechnologyManager = QueryOwnerInterface(this.entity, IID_TechnologyManager);
 	if (!cmpTechnologyManager)
@@ -195,12 +200,12 @@ ProductionQueue.prototype.AddBatch = function(templateName, type, count, metadat
 			// Obviously we don't have the entities yet, so we must use template data
 			var costs = {};
 			var totalCosts = {};
-			var buildTime = ApplyTechModificationsToTemplate("Cost/BuildTime", +template.Cost.BuildTime, this.entity, template);
+			var buildTime = ApplyValueModificationsToTemplate("Cost/BuildTime", +template.Cost.BuildTime, cmpPlayer.GetPlayerID(), template);
 			var time = timeMult * buildTime;
 
 			for (var r in template.Cost.Resources)
 			{
-				costs[r] = ApplyTechModificationsToTemplate("Cost/Resources/"+r, +template.Cost.Resources[r], this.entity, template);
+				costs[r] = ApplyValueModificationsToTemplate("Cost/Resources/"+r, +template.Cost.Resources[r], cmpPlayer.GetPlayerID(), template);
 				totalCosts[r] = Math.floor(count * costs[r]);
 			}
 
@@ -239,7 +244,7 @@ ProductionQueue.prototype.AddBatch = function(templateName, type, count, metadat
 			if (!template)
 				return;
 			var cmpPlayer = QueryOwnerInterface(this.entity, IID_Player);
-			var time = template.researchTime * cmpPlayer.cheatTimeMultiplier;
+			var time = template.researchTime * cmpPlayer.GetCheatTimeMultiplier();
 
 			var cost = {};
 			for each (var r in ["food", "wood", "stone", "metal"])
@@ -400,10 +405,10 @@ ProductionQueue.prototype.GetBatchTime = function(batchSize)
 {
 	var cmpPlayer = QueryOwnerInterface(this.entity, IID_Player);
 
-	var batchTimeModifier = ApplyTechModificationsToEntity("ProductionQueue/BatchTimeModifier", +this.template.BatchTimeModifier, this.entity);
+	var batchTimeModifier = ApplyValueModificationsToEntity("ProductionQueue/BatchTimeModifier", +this.template.BatchTimeModifier, this.entity);
 
 	// TODO: work out what equation we should use here.
-	return Math.pow(batchSize, batchTimeModifier) * cmpPlayer.cheatTimeMultiplier;
+	return Math.pow(batchSize, batchTimeModifier) * cmpPlayer.GetCheatTimeMultiplier();
 };
 
 ProductionQueue.prototype.OnOwnershipChanged = function(msg)
@@ -437,8 +442,9 @@ ProductionQueue.prototype.OnDestroy = function()
 };
 
 /*
- * This function creates the entities and places them in world if possible.
- * returns the number of successfully spawned entities.
+ * This function creates the entities and places them in world if possible
+ * and returns the number of successfully created entities.
+ * (some of these entities may be garrisoned directly if autogarrison, the others are spawned).
  */
 ProductionQueue.prototype.SpawnUnits = function(templateName, count, metadata)
 {
@@ -447,6 +453,7 @@ ProductionQueue.prototype.SpawnUnits = function(templateName, count, metadata)
 	var cmpOwnership = Engine.QueryInterface(this.entity, IID_Ownership);
 	var cmpRallyPoint = Engine.QueryInterface(this.entity, IID_RallyPoint);
 	
+	var createdEnts = [];
 	var spawnedEnts = [];
 	
 	if (this.entityCache.length == 0)
@@ -471,38 +478,55 @@ ProductionQueue.prototype.SpawnUnits = function(templateName, count, metadata)
 		}
 	}
 
+	var cmpAutoGarrison = undefined;
+	if (cmpRallyPoint)
+	{
+		var data = cmpRallyPoint.GetData()[0];
+		if (data && data.target == this.entity && data.command == "garrison")
+			cmpAutoGarrison = Engine.QueryInterface(this.entity, IID_GarrisonHolder);
+	}
+
 	for (var i = 0; i < count; ++i)
 	{
 		var ent = this.entityCache[0];
-		var pos = cmpFootprint.PickSpawnPoint(ent);
-		if (pos.y < 0)
+		var cmpNewOwnership = Engine.QueryInterface(ent, IID_Ownership);
+		cmpNewOwnership.SetOwner(cmpOwnership.GetOwner());
+
+		if (cmpAutoGarrison && cmpAutoGarrison.PerformGarrison(ent))
 		{
-			// Fail: there wasn't any space to spawn the unit
-			break;
+			var cmpUnitAI = Engine.QueryInterface(ent, IID_UnitAI);
+			cmpUnitAI.Autogarrison();
 		}
 		else
 		{
-			// Successfully spawned
-			var cmpNewPosition = Engine.QueryInterface(ent, IID_Position);
-			cmpNewPosition.JumpTo(pos.x, pos.z);
-			// TODO: what direction should they face in?
-
-			var cmpNewOwnership = Engine.QueryInterface(ent, IID_Ownership);
-			cmpNewOwnership.SetOwner(cmpOwnership.GetOwner());
-			
-			var cmpPlayerStatisticsTracker = QueryOwnerInterface(this.entity, IID_StatisticsTracker);
-			cmpPlayerStatisticsTracker.IncreaseTrainedUnitsCounter();
-
-			// Play a sound, but only for the first in the batch (to avoid nasty phasing effects)
-			if (spawnedEnts.length == 0)
-				PlaySound("trained", ent);
-			
-			this.entityCache.shift();
-			spawnedEnts.push(ent);
+			var pos = cmpFootprint.PickSpawnPoint(ent);
+			if (pos.y < 0)
+			{
+				// Fail: there wasn't any space to spawn the unit
+				break;
+			}
+			else
+			{
+				// Successfully spawned
+				var cmpNewPosition = Engine.QueryInterface(ent, IID_Position);
+				cmpNewPosition.JumpTo(pos.x, pos.z);
+				// TODO: what direction should they face in?
+				spawnedEnts.push(ent);
+			}
 		}
+
+		var cmpPlayerStatisticsTracker = QueryOwnerInterface(this.entity, IID_StatisticsTracker);
+		cmpPlayerStatisticsTracker.IncreaseTrainedUnitsCounter();
+
+		// Play a sound, but only for the first in the batch (to avoid nasty phasing effects)
+		if (createdEnts.length == 0)
+			PlaySound("trained", ent);
+			
+		this.entityCache.shift();
+		createdEnts.push(ent);
 	}
 
-	if (spawnedEnts.length > 0)
+	if (spawnedEnts.length > 0 && !cmpAutoGarrison)
 	{
 		// If a rally point is set, walk towards it (in formation) using a suitable command based on where the 
 		// rally point is placed.
@@ -513,20 +537,21 @@ ProductionQueue.prototype.SpawnUnits = function(templateName, count, metadata)
 			{
 				var commands = GetRallyPointCommands(cmpRallyPoint, spawnedEnts);
 				for each(var com in commands)
-				{
 					ProcessCommand(cmpOwnership.GetOwner(), com);
-				}
 			}
 		}
+	}
 
+	if (createdEnts.length > 0)
+	{
 		Engine.PostMessage(this.entity, MT_TrainingFinished, {
-			"entities": spawnedEnts,
+			"entities": createdEnts,
 			"owner": cmpOwnership.GetOwner(),
 			"metadata": metadata,
 		});
 	}
 	
-	return spawnedEnts.length;
+	return createdEnts.length;
 };
 
 /*
@@ -535,6 +560,9 @@ ProductionQueue.prototype.SpawnUnits = function(templateName, count, metadata)
  */
 ProductionQueue.prototype.ProgressTimeout = function(data)
 {
+	// Check if the production is paused (eg the entity is garrisoned)
+	if (this.paused)
+		return;
 	// Allocate the 1000msecs to as many queue items as it takes
 	// until we've used up all the time (so that we work accurately
 	// with items that take fractions of a second)
@@ -629,6 +657,16 @@ ProductionQueue.prototype.ProgressTimeout = function(data)
 			var cmpTechnologyManager = QueryOwnerInterface(this.entity, IID_TechnologyManager);
 			cmpTechnologyManager.ResearchTechnology(item.technologyTemplate);
 			
+			var template = cmpTechnologyManager.GetTechnologyTemplate(item.technologyTemplate);
+			
+			if (template && template.soundComplete)
+			{
+				var cmpSoundManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_SoundManager);
+				
+				if (cmpSoundManager)
+					cmpSoundManager.PlaySoundGroup(template.soundComplete, this.entity);
+			}
+			
 			time -= item.timeRemaining;
 			
 			this.queue.shift();
@@ -650,6 +688,19 @@ ProductionQueue.prototype.ProgressTimeout = function(data)
 		var cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
 		this.timer = cmpTimer.SetTimeout(this.entity, IID_ProductionQueue, "ProgressTimeout", g_ProgressInterval, data);
 	}
-}
+};
+
+ProductionQueue.prototype.PauseProduction = function()
+{
+	this.timer = undefined;
+	this.paused = true;
+};
+
+ProductionQueue.prototype.UnpauseProduction = function()
+{
+	this.paused = false;
+	var cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
+	this.timer = cmpTimer.SetTimeout(this.entity, IID_ProductionQueue, "ProgressTimeout", g_ProgressInterval, {});
+};
 
 Engine.RegisterComponentType(IID_ProductionQueue, "ProductionQueue", ProductionQueue);
