@@ -15,7 +15,7 @@ Promotion.prototype.Init = function()
 
 Promotion.prototype.GetRequiredXp = function()
 {
-	return ApplyTechModificationsToEntity("Promotion/RequiredXp", +this.template.RequiredXp, this.entity);
+	return ApplyValueModificationsToEntity("Promotion/RequiredXp", +this.template.RequiredXp, this.entity);
 };
 
 Promotion.prototype.GetCurrentXp = function()
@@ -78,6 +78,14 @@ Promotion.prototype.Promote = function(promotedTemplateName)
 	cmpPromotedUnitAI.Cheer();
 	var orders = cmpCurrentUnitAI.GetOrders();
 	cmpPromotedUnitAI.AddOrders(orders);
+	var workOrders = cmpCurrentUnitAI.GetWorkOrders();
+	cmpPromotedUnitAI.SetWorkOrders(workOrders);
+	cmpPromotedUnitAI.SetGuardOf(cmpCurrentUnitAI.IsGuardOf());
+
+	var cmpCurrentUnitGuard = Engine.QueryInterface(this.entity, IID_Guard);
+	var cmpPromotedUnitGuard = Engine.QueryInterface(promotedUnitEntity, IID_Guard);
+	if (cmpCurrentUnitGuard && cmpPromotedUnitGuard)
+		cmpPromotedUnitGuard.SetEntities(cmpCurrentUnitGuard.GetEntities());
 
 	Engine.BroadcastMessage(MT_EntityRenamed, { entity: this.entity, newentity: promotedUnitEntity });
 
