@@ -95,7 +95,7 @@ ResourceGatherer.prototype.GiveResources = function(resources)
 	{
 		this.carrying[resource.type] = +(resource.amount);
 	}
-	
+
 	Engine.PostMessage(this.entity, MT_ResourceCarryingChanged, { "to": this.GetCarryingStatus() });
 };
 
@@ -129,12 +129,12 @@ ResourceGatherer.prototype.GetGatherRates = function()
 {
 	var ret = {};
 	var cmpPlayer = QueryOwnerInterface(this.entity, IID_Player);
-	
-	var baseSpeed = ApplyTechModificationsToEntity("ResourceGatherer/BaseSpeed", +this.template.BaseSpeed, this.entity) * cmpPlayer.GetGatherRateMultiplier();
+
+	var baseSpeed = ApplyValueModificationsToEntity("ResourceGatherer/BaseSpeed", +this.template.BaseSpeed, this.entity) * cmpPlayer.GetGatherRateMultiplier();
 
 	for (var r in this.template.Rates)
 	{
-		var rate = ApplyTechModificationsToEntity("ResourceGatherer/Rates/" + r, +this.template.Rates[r], this.entity);
+		var rate = ApplyValueModificationsToEntity("ResourceGatherer/Rates/" + r, +this.template.Rates[r], this.entity);
 		ret[r] = rate * baseSpeed;
 	}
 
@@ -147,7 +147,7 @@ ResourceGatherer.prototype.GetCapacities = function()
 
 	for (var r in this.template.Capacities)
 	{
-		ret[r] = ApplyTechModificationsToEntity("ResourceGatherer/Capacities/" + r, +this.template.Capacities[r], this.entity);
+		ret[r] = ApplyValueModificationsToEntity("ResourceGatherer/Capacities/" + r, +this.template.Capacities[r], this.entity);
 	}
 
 	return ret;
@@ -167,14 +167,14 @@ ResourceGatherer.prototype.TryInstantGather = function(target)
 {
 	var cmpResourceSupply = Engine.QueryInterface(target, IID_ResourceSupply);
 	var type = cmpResourceSupply.GetType();
-	
+
 	if (type.generic != "treasure") return false;
-	
+
 	var status = cmpResourceSupply.TakeResources(cmpResourceSupply.GetCurrentAmount());
 
 	var cmpPlayer = QueryOwnerInterface(this.entity, IID_Player);
 	cmpPlayer.AddResource(type.specific, status.amount);
-	
+
 	var cmpStatisticsTracker = QueryOwnerInterface(this.entity, IID_StatisticsTracker);
 	if (cmpStatisticsTracker)
 		cmpStatisticsTracker.IncreaseTreasuresCollectedCounter();
@@ -216,7 +216,7 @@ ResourceGatherer.prototype.PerformGather = function(target)
 	var cmpStatisticsTracker = QueryOwnerInterface(this.entity, IID_StatisticsTracker);
 	if (cmpStatisticsTracker)
 		cmpStatisticsTracker.IncreaseResourceGatheredCounter(type.generic, status.amount, type.specific);
-	
+
 	Engine.PostMessage(this.entity, MT_ResourceCarryingChanged, { "to": this.GetCarryingStatus() });
 
 	// Tell the target we're gathering from it
@@ -250,14 +250,35 @@ ResourceGatherer.prototype.GetTargetGatherRate = function(target)
 	var rate;
 	if (type.specific && rates[type.generic+"."+type.specific])
 	{
-		rate = rates[type.generic+"."+type.specific] / cmpPlayer.cheatTimeMultiplier;
+		rate = rates[type.generic+"."+type.specific] / cmpPlayer.GetCheatTimeMultiplier();
 	}
 	else if (type.generic && rates[type.generic])
 	{
-		rate = rates[type.generic] / cmpPlayer.cheatTimeMultiplier;
+		rate = rates[type.generic] / cmpPlayer.GetCheatTimeMultiplier();
 	}
-	
-	return (rate || 0);
+
+	// Apply diminishing returns with more gatherers, for e.g. infinite farms. For most resources this has no effect. (GetDiminishingReturns will return null.)
+	// Note to people looking to change <DiminishingReturns> in a template: This is a bit complicated. Basically, the lower that number is
+	// the steeper diminishing returns will be. I suggest playing around with Wolfram Alpha or a graphing calculator a bit.
+	// In each of the following links, replace 0.65 with the gather rate of your worker for the resource with diminishing returns and
+	// 14 with the constant you wish to use to control the diminishing returns.
+	// (In this case 0.65 is the women farming rate, in resources/second, and 14 is a good constant for farming.)
+	// This is the gather rate in resources/second of each individual worker as the total number of workers goes up:
+	// http://www.wolframalpha.com/input/?i=plot+%281%2F2+cos%28%28x-1%29*pi%2F14%29+%2B+1%2F2%29+*+0.65+from+1+to+5
+	// This is the total output of the resource in resources/second:
+	// http://www.wolframalpha.com/input/?i=plot+x%281%2F2+cos%28%28x-1%29*pi%2F14%29+%2B+1%2F2%29+*+0.65+from+1+to+5
+	// This is the fraction of a worker each new worker is worth (the 5th worker in this example is only producing about half as much as the first one):
+	// http://www.wolframalpha.com/input/?i=plot+x%281%2F2+cos%28%28x-1%29*pi%2F14%29+%2B+1%2F2%29+-++%28x-1%29%281%2F2+cos%28%28x-2%29*pi%2F14%29+%2B+1%2F2%29+from+x%3D1+to+5+and+y%3D0+to+1
+	// Here's how this technically works:
+	// The cosine function is an oscillating curve, normally between -1 and 1. Multiplying by 0.5 squishes that down to
+	// between -0.5 and 0.5. Adding 0.5 to that changes the range to 0 to 1. The diminishingReturns constant
+	// adjusts the period of the curve.
+	// Alternatively, just find scythetwirler (who came up with the math here) or alpha123 (who wrote the code) on IRC.
+	var diminishingReturns = cmpResourceSupply.GetDiminishingReturns();
+	if (diminishingReturns)
+		rate = (0.5 * Math.cos((cmpResourceSupply.GetGatherers().length - 1) * Math.PI / diminishingReturns) + 0.5) * rate;
+
+	return rate || 0;
 };
 
 /**
@@ -302,7 +323,7 @@ ResourceGatherer.prototype.CommitResources = function(types)
 			delete this.carrying[type];
 		}
 	}
-	
+
 	Engine.PostMessage(this.entity, MT_ResourceCarryingChanged, { "to": this.GetCarryingStatus() });
 };
 
@@ -314,7 +335,7 @@ ResourceGatherer.prototype.CommitResources = function(types)
 ResourceGatherer.prototype.DropResources = function()
 {
 	this.carrying = {};
-	
+
 	Engine.PostMessage(this.entity, MT_ResourceCarryingChanged, { "to": this.GetCarryingStatus() });
 };
 
