@@ -28,12 +28,12 @@ TechnologyManager.prototype.Init = function ()
 	
 	// This stores the modifications to unit stats from researched technologies
 	// Example data: {"ResourceGatherer/Rates/food.grain": [ 
-	//                     {"multiplier": 1.15, "affects": ["Female", "Infantry Swordsman"]},
+	//                     {"multiply": 1.15, "affects": ["Female", "Infantry Swordsman"]},
 	//                     {"add": 2}
 	//                 ]}
 	this.modifications = {};
 	this.modificationCache = {}; // Caches the values after technologies have been applied
-	                             // e.g. { "Attack/Melee/Hack" : {5: 10, 7: 12, ...}, ...}
+	                             // e.g. { "Attack/Melee/Hack" : {5: {"origValue": 8, "newValue": 10}, 7: {"origValue": 9, "newValue": 12}, ...}, ...}
 	                             // where 5 and 7 are entity id's
 	
 	this.typeCounts = {}; // stores the number of entities of each type 
@@ -110,9 +110,13 @@ TechnologyManager.prototype.CanResearch = function (tech)
 	if (template.supersedes && !this.IsTechnologyResearched(template.supersedes))
 		return false;
 	
+	if (template.top && this.IsInProgress(template.top) ||
+	    template.bottom && this.IsInProgress(template.bottom))
+		return false;
+	
 	if (template.pair && !this.CanResearch(template.pair))
 		return false;
-		
+	
 	if (this.IsInProgress(tech))
 		return false;
 	
@@ -215,8 +219,6 @@ TechnologyManager.prototype.OnGlobalOwnershipChanged = function (msg)
 		//	we want it to maintain whatever technologies previously applied)
 		if (msg.from == -1)
 		{
-			var cmpPlayer = Engine.QueryInterface(this.entity, IID_Player);
-			var playerID = cmpPlayer.GetPlayerID();
 			var modifiedComponents = {};
 			for (var name in this.modifications)
 			{
@@ -230,7 +232,7 @@ TechnologyManager.prototype.OnGlobalOwnershipChanged = function (msg)
 
 			// Send mesage(s) to the entity so it knows about researched techs
 			for (var component in modifiedComponents)
-				Engine.PostMessage(msg.entity, MT_TechnologyModification, { "component": component, "player": playerID });
+				Engine.PostMessage(msg.entity, MT_ValueModification, { "component": component });
 		}
 	}
 	if (msg.from == playerID)
@@ -327,15 +329,9 @@ TechnologyManager.prototype.ResearchTechnology = function (tech)
 	
 	this.UpdateAutoResearch();
 	
-	var cmpPlayer = Engine.QueryInterface(this.entity, IID_Player);
-	var player = cmpPlayer.GetPlayerID();
 	// TODO: Handle technology broadcasting for autoresearch properly (some components might not be initialized currently)
-	if (player === undefined)
-		return;
-	
-	for (var component in modifiedComponents){
-		Engine.BroadcastMessage(MT_TechnologyModification, { "component": component, "player": player });
-	}
+	for (var component in modifiedComponents)
+		Engine.BroadcastMessage(MT_ValueModification, { "component": component });
 };
 
 // Clears the cached data for an entity from the modifications cache
@@ -355,17 +351,18 @@ TechnologyManager.prototype.ApplyModifications = function(valueName, curValue, e
 	if (!this.modificationCache[valueName])
 		this.modificationCache[valueName] = {};
 	
-	if (!this.modificationCache[valueName][ent])
+	if (!this.modificationCache[valueName][ent] || this.modificationCache[valueName][ent].origValue != curValue)
 	{
+		this.modificationCache[valueName][ent] = {"origValue": curValue};
 		var cmpTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager);
 		var templateName = cmpTemplateManager.GetCurrentTemplateName(ent);
 		// Ensure that preview entites have the same properties as the final building
 		if (templateName.indexOf("preview|") != -1)
 			templateName = templateName.slice(8);
-		this.modificationCache[valueName][ent] = GetTechModifiedProperty(this.modifications, cmpTemplateManager.GetTemplate(templateName), valueName, curValue);
+		this.modificationCache[valueName][ent].newValue = GetTechModifiedProperty(this.modifications, cmpTemplateManager.GetTemplate(templateName), valueName, curValue);
 	}
 	
-	return this.modificationCache[valueName][ent];
+	return this.modificationCache[valueName][ent].newValue;
 };
 
 // Alternative version of ApplyModifications, applies to templates instead of entities
