@@ -9,8 +9,9 @@ TechnologyTemplateManager.prototype.Schema =
 TechnologyTemplateManager.prototype.Init = function()
 {
 	this.allTechs = {};
+	this.allAuras = {};
 	var techNames = this.ListAllTechs();
-	for (i in techNames)
+	for (var i in techNames)
 		this.GetTemplate(techNames[i]);
 };
 
@@ -26,6 +27,18 @@ TechnologyTemplateManager.prototype.GetTemplate = function(template)
 	return this.allTechs[template];
 };
 
+TechnologyTemplateManager.prototype.GetAuraTemplate = function(template)
+{
+	if (!this.allAuras[template])
+	{
+		this.allAuras[template] = Engine.ReadJSONFile("auras/" + template + ".json");
+		if (! this.allAuras[template])
+			error("Failed to load aura \"" + template + "\"");
+	}
+	
+	return this.allAuras[template];
+};
+
 TechnologyTemplateManager.prototype.ListAllTechs = function()
 {
     return Engine.FindJSONFiles("technologies", true);
