@@ -31,20 +31,22 @@ Trader.prototype.Init = function()
 	// Selected resource for trading
 	this.preferredGoods = "metal";
 	// Currently carried goods
-	this.goods = { "type": null, "amount": 0 };
-}
+	this.goods = { "type": null, "amount": null, "origin": null };
+};
 
-Trader.prototype.CalculateGain = function(firstMarket, secondMarket, template)
+Trader.prototype.CalculateGain = function(firstMarket, secondMarket)
 {
+	var gain = CalculateTraderGain(firstMarket, secondMarket, this.template, this.entity);
+
 	// For ship increase gain for each garrisoned trader
-	// Calculate this here to save passing unnecessary stuff into the CalculatetraderGain function
-	var garrisonMultiplier = 1;
+	// Calculate this here to save passing unnecessary stuff into the CalculateTraderGain function
 	var cmpIdentity = Engine.QueryInterface(this.entity, IID_Identity);
 	if (cmpIdentity && cmpIdentity.HasClass("Ship"))
 	{
 		var cmpGarrisonHolder = Engine.QueryInterface(this.entity, IID_GarrisonHolder);
 		if (cmpGarrisonHolder)
 		{
+			var garrisonMultiplier = 1;
 			var garrisonedTradersCount = 0;
 			for each (var entity in cmpGarrisonHolder.GetEntities())
 			{
@@ -53,16 +55,23 @@ Trader.prototype.CalculateGain = function(firstMarket, secondMarket, template)
 					garrisonedTradersCount++;
 			}
 			garrisonMultiplier *= 1 + GARRISONED_TRADER_ADDITION * garrisonedTradersCount / 100;
+
+			if (gain.traderGain)
+				gain.traderGain = Math.round(garrisonMultiplier * gain.traderGain);
+			if (gain.market1Gain)
+				gain.market1Gain = Math.round(garrisonMultiplier * gain.market1Gain);
+			if (gain.market2Gain)
+				gain.market2Gain = Math.round(garrisonMultiplier * gain.market2Gain);
 		}
 	}
 	
-	return garrisonMultiplier * CalculateTraderGain(firstMarket, secondMarket, this.template);
-}
+	return gain;
+};
 
 Trader.prototype.GetGain = function()
 {
 	return this.gain;
-}
+};
 
 // Set target as target market.
 // Return true if at least one of markets was changed.
@@ -116,30 +125,30 @@ Trader.prototype.SetTargetMarket = function(target, source)
 	if (marketsChanged)
 	{
 		// Drop carried goods
-		this.goods.amount = 0;
+		this.goods.amount = null;
 	}
 	return marketsChanged;
-}
+};
 
 Trader.prototype.GetFirstMarket = function()
 {
 	return this.firstMarket;
-}
+};
 
 Trader.prototype.GetSecondMarket = function()
 {
 	return this.secondMarket;
-}
+};
 
 Trader.prototype.HasBothMarkets = function()
 {
 	return this.firstMarket && this.secondMarket;
-}
+};
 
 Trader.prototype.GetPreferredGoods = function()
 {
 	return this.preferredGoods;
-}
+};
 
 Trader.prototype.SetPreferredGoods = function(preferredGoods)
 {
@@ -147,7 +156,7 @@ Trader.prototype.SetPreferredGoods = function(preferredGoods)
 	if (RESOURCES.indexOf(preferredGoods) == -1)
 		return;
 	this.preferredGoods = preferredGoods;
-}
+};
 
 Trader.prototype.CanTrade = function(target)
 {
@@ -173,36 +182,68 @@ Trader.prototype.CanTrade = function(target)
 	if (!ownershipSuitableForTrading)
 		return false;
 	return true;
-}
+};
 
-Trader.prototype.PerformTrade = function()
+Trader.prototype.PerformTrade = function(currentMarket)
 {
-	if (this.goods.amount > 0)
+	if (this.goods.amount && this.goods.amount.traderGain)
 	{
 		var cmpPlayer = QueryOwnerInterface(this.entity, IID_Player);
-		cmpPlayer.AddResource(this.goods.type, this.goods.amount);
+		if (cmpPlayer)
+			cmpPlayer.AddResource(this.goods.type, this.goods.amount.traderGain);
 
 		var cmpStatisticsTracker = QueryOwnerInterface(this.entity, IID_StatisticsTracker);
 		if (cmpStatisticsTracker)
-			cmpStatisticsTracker.IncreaseTradeIncomeCounter(this.goods.amount);
+			cmpStatisticsTracker.IncreaseTradeIncomeCounter(this.goods.amount.traderGain);
+
+		if (this.goods.amount.market1Gain)
+		{
+			var cmpPlayer = QueryOwnerInterface(this.firstMarket, IID_Player);
+			if (cmpPlayer)
+				cmpPlayer.AddResource(this.goods.type, this.goods.amount.market1Gain);
+
+			var cmpStatisticsTracker = QueryOwnerInterface(this.firstMarket, IID_StatisticsTracker);
+			if (cmpStatisticsTracker)
+				cmpStatisticsTracker.IncreaseTradeIncomeCounter(this.goods.amount.market1Gain);
+		}
+
+		if (this.goods.amount.market2Gain)
+		{
+			var cmpPlayer = QueryOwnerInterface(this.secondMarket, IID_Player);
+			if (cmpPlayer)
+				cmpPlayer.AddResource(this.goods.type, this.goods.amount.market2Gain);
+
+			var cmpStatisticsTracker = QueryOwnerInterface(this.secondMarket, IID_StatisticsTracker);
+			if (cmpStatisticsTracker)
+				cmpStatisticsTracker.IncreaseTradeIncomeCounter(this.goods.amount.market2Gain);
+		}
 	}
 	this.goods.type = this.preferredGoods;
 	this.goods.amount = this.gain;
-}
+	this.goods.origin = currentMarket;
+};
 
 Trader.prototype.GetGoods = function()
 {
 	return this.goods;
-}
+};
+
+Trader.prototype.GetNextMarket = function()
+{
+	if (this.goods.amount && this.goods.origin == this.firstMarket)
+		return this.secondMarket;
+	else
+		return this.firstMarket;
+};
 
 Trader.prototype.StopTrading = function()
 {
 	// Drop carried goods
-	this.goods.amount = 0;
+	this.goods.amount = null;
 	// Reset markets
 	this.firstMarket = INVALID_ENTITY;
 	this.secondMarket = INVALID_ENTITY;
-}
+};
 
 // Get range in which deals with market are available,
 // i.e. trader should be in no more than MaxDistance from market
@@ -210,7 +251,12 @@ Trader.prototype.StopTrading = function()
 Trader.prototype.GetRange = function()
 {
 	return { "min": 0, "max": +this.template.MaxDistance };
-}
+};
+
+Trader.prototype.OnGarrisonedUnitsChanged = function()
+{
+	if (this.HasBothMarkets())
+		this.gain = this.CalculateGain(this.firstMarket, this.secondMarket);
+};
 
 Engine.RegisterComponentType(IID_Trader, "Trader", Trader);
-
