@@ -8,17 +8,22 @@ function ProcessCommand(player, cmd)
 	var cmpPlayerMan = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
 	if (!cmpPlayerMan || player < 0)
 		return;
-	
+
 	var playerEnt = cmpPlayerMan.GetPlayerByID(player);
 	if (playerEnt == INVALID_ENTITY)
 		return;
-	
+
 	var cmpPlayer = Engine.QueryInterface(playerEnt, IID_Player);
 	if (!cmpPlayer)
 		return;
-	
+
 	var controlAllUnits = cmpPlayer.CanControlAllUnits();
 
+	var entities;
+	if (cmd.entities)
+		entities = FilterEntityList(cmd.entities, player, controlAllUnits);
+
+
 	// Note: checks of UnitAI targets are not robust enough here, as ownership
 	//	can change after the order is issued, they should be checked by UnitAI
 	//	when the specific behavior (e.g. attack, garrison) is performed.
@@ -82,14 +87,12 @@ function ProcessCommand(player, cmd)
 		break;
 
 	case "walk":
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		GetFormationUnitAIs(entities, player).forEach(function(cmpUnitAI) {
 			cmpUnitAI.Walk(cmd.x, cmd.z, cmd.queued);
 		});
 		break;
 
 	case "attack-walk":
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		GetFormationUnitAIs(entities, player).forEach(function(cmpUnitAI) {
 			cmpUnitAI.WalkAndFight(cmd.x, cmd.z, cmd.queued);
 		});
@@ -103,7 +106,6 @@ function ProcessCommand(player, cmd)
 		}
 
 		// See UnitAI.CanAttack for target checks
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		GetFormationUnitAIs(entities, player).forEach(function(cmpUnitAI) {
 			cmpUnitAI.Attack(cmd.target, cmd.queued);
 		});
@@ -117,7 +119,6 @@ function ProcessCommand(player, cmd)
 		}
 
 		// See UnitAI.CanHeal for target checks
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		GetFormationUnitAIs(entities, player).forEach(function(cmpUnitAI) {
 			cmpUnitAI.Heal(cmd.target, cmd.queued);
 		});
@@ -132,7 +133,6 @@ function ProcessCommand(player, cmd)
 		}
 
 		// See UnitAI.CanRepair for target checks
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		GetFormationUnitAIs(entities, player).forEach(function(cmpUnitAI) {
 			cmpUnitAI.Repair(cmd.target, cmd.autocontinue, cmd.queued);
 		});
@@ -146,14 +146,12 @@ function ProcessCommand(player, cmd)
 		}
 
 		// See UnitAI.CanGather for target checks
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		GetFormationUnitAIs(entities, player).forEach(function(cmpUnitAI) {
 			cmpUnitAI.Gather(cmd.target, cmd.queued);
 		});
 		break;
 		
 	case "gather-near-position":
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		GetFormationUnitAIs(entities, player).forEach(function(cmpUnitAI) {
 			cmpUnitAI.GatherNearPosition(cmd.x, cmd.z, cmd.resourceType, cmd.resourceTemplate, cmd.queued);
 		});
@@ -168,15 +166,30 @@ function ProcessCommand(player, cmd)
 		}
 
 		// See UnitAI.CanReturnResource for target checks
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		GetFormationUnitAIs(entities, player).forEach(function(cmpUnitAI) {
 			cmpUnitAI.ReturnResource(cmd.target, cmd.queued);
 		});
 		break;
+		
+	case "back-to-work":
+		for each (var ent in entities)
+		{
+			var cmpUnitAI = Engine.QueryInterface(ent, IID_UnitAI);
+			if(!cmpUnitAI || !cmpUnitAI.BackToWork())
+				notifyBackToWorkFailure(player);
+		}
+		break;
+
+	case "remove-guard":
+		for each (var ent in entities)
+		{
+			var cmpUnitAI = Engine.QueryInterface(ent, IID_UnitAI);
+			if(cmpUnitAI)
+				cmpUnitAI.RemoveGuard();
+		}
+		break;
 
 	case "train":
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
-		
 		// Check entity limits
 		var cmpTempMan = Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager);
 		var template = cmpTempMan.GetTemplate(cmd.template);
@@ -202,14 +215,14 @@ function ProcessCommand(player, cmd)
 
 				var cmpTechnologyManager = QueryOwnerInterface(ent, IID_TechnologyManager);
 				// TODO: Enable this check once the AI gets technology support
-				if (cmpTechnologyManager.CanProduce(cmd.template) || true)
+				if (cmpTechnologyManager.CanProduce(cmd.template) || cmpPlayer.IsAI())
 				{
 					var queue = Engine.QueryInterface(ent, IID_ProductionQueue);
 					// Check if the building can train the unit
 					if (queue && queue.GetEntitiesList().indexOf(cmd.template) != -1)
 						queue.AddBatch(cmd.template, "unit", +cmd.count, cmd.metadata);
 				}
-				else
+				else if (g_DebugCommands)
 				{
 					warn("Invalid command: training requires unresearched technology: " + uneval(cmd));
 				}
@@ -267,7 +280,6 @@ function ProcessCommand(player, cmd)
 		break;
 
 	case "delete-entities":
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		for each (var ent in entities)
 		{
 			var cmpHealth = Engine.QueryInterface(ent, IID_Health);
@@ -283,7 +295,6 @@ function ProcessCommand(player, cmd)
 		break;
 
 	case "set-rallypoint":
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		for each (var ent in entities)
 		{
 			var cmpRallyPoint = Engine.QueryInterface(ent, IID_RallyPoint);
@@ -299,12 +310,11 @@ function ProcessCommand(player, cmd)
 		break;
 
 	case "unset-rallypoint":
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		for each (var ent in entities)
 		{
 			var cmpRallyPoint = Engine.QueryInterface(ent, IID_RallyPoint);
 			if (cmpRallyPoint)
-				cmpRallyPoint.Unset();
+				cmpRallyPoint.Reset();
 		}
 		break;
 
@@ -314,34 +324,51 @@ function ProcessCommand(player, cmd)
 		break;
 
 	case "garrison":
-		// Verify that the building can be controlled by the player
-		if (CanControlUnit(cmd.target, player, controlAllUnits))
+		// Verify that the building can be controlled by the player or is mutualAlly
+		if (CanControlUnitOrIsAlly(cmd.target, player, controlAllUnits))
 		{
-			var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 			GetFormationUnitAIs(entities, player).forEach(function(cmpUnitAI) {
 				cmpUnitAI.Garrison(cmd.target, cmd.queued);
 			});
 		}
 		else if (g_DebugCommands)
 		{
-			warn("Invalid command: garrison target cannot be controlled by player "+player+": "+uneval(cmd));
+			warn("Invalid command: garrison target cannot be controlled by player "+player+" (or ally): "+uneval(cmd));
+		}
+		break;
+
+	case "guard":
+		// Verify that the target can be controlled by the player or is mutualAlly
+		if (CanControlUnitOrIsAlly(cmd.target, player, controlAllUnits))
+		{
+			GetFormationUnitAIs(entities, player).forEach(function(cmpUnitAI) {
+				cmpUnitAI.Guard(cmd.target, cmd.queued);
+			});
+		}
+		else if (g_DebugCommands)
+		{
+			warn("Invalid command: guard/escort target cannot be controlled by player "+player+": "+uneval(cmd));
 		}
 		break;
 
 	case "stop":
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		GetFormationUnitAIs(entities, player).forEach(function(cmpUnitAI) {
 			cmpUnitAI.Stop(cmd.queued);
 		});
 		break;
 
 	case "unload":
-		// Verify that the building can be controlled by the player
-		if (CanControlUnit(cmd.garrisonHolder, player, controlAllUnits))
+		// Verify that the building can be controlled by the player or is mutualAlly
+		if (CanControlUnitOrIsAlly(cmd.garrisonHolder, player, controlAllUnits))
 		{
 			var cmpGarrisonHolder = Engine.QueryInterface(cmd.garrisonHolder, IID_GarrisonHolder);
 			var notUngarrisoned = 0;
-			for each (ent in cmd.entities)
+
+			// The owner can ungarrison every garrisoned unit
+			if (IsOwnedByPlayer(player, cmd.garrisonHolder))
+				entities = cmd.entities;
+
+			for each (var ent in entities)
 				if (!cmpGarrisonHolder || !cmpGarrisonHolder.Unload(ent))
 					notUngarrisoned++;
 
@@ -350,23 +377,45 @@ function ProcessCommand(player, cmd)
 		}
 		else if (g_DebugCommands)
 		{
-			warn("Invalid command: unload target cannot be controlled by player "+player+": "+uneval(cmd));
+			warn("Invalid command: unload target cannot be controlled by player "+player+" (or ally): "+uneval(cmd));
 		}
 		break;
 
 	case "unload-template":
-		var selected = FilterEntityList(cmd.garrisonHolders, player, controlAllUnits);
-		for each (var garrisonHolder in selected)
+		var index = cmd.template.indexOf("&");  // Templates for garrisoned units are extended
+		if (index == -1)
+			break;
+
+		var entities = FilterEntityListWithAllies(cmd.garrisonHolders, player, controlAllUnits);
+		for each (var garrisonHolder in entities)
 		{
 			var cmpGarrisonHolder = Engine.QueryInterface(garrisonHolder, IID_GarrisonHolder);
-			if (!cmpGarrisonHolder || !cmpGarrisonHolder.UnloadTemplate(cmd.template, cmd.all))
+			if (cmpGarrisonHolder)
+			{
+				// Only the owner of the garrisonHolder may unload entities from any owners
+				if (!IsOwnedByPlayer(player, garrisonHolder) && !controlAllUnits
+				    && player != +cmd.template.slice(1,index))
+						continue;
+
+				if (!cmpGarrisonHolder.UnloadTemplate(cmd.template, cmd.all))
+					notifyUnloadFailure(player, garrisonHolder);
+			}
+		}
+		break;
+
+	case "unload-all-own":
+		var entities = FilterEntityList(cmd.garrisonHolders, player, controlAllUnits);
+		for each (var garrisonHolder in entities)
+		{
+			var cmpGarrisonHolder = Engine.QueryInterface(garrisonHolder, IID_GarrisonHolder);
+			if (!cmpGarrisonHolder || !cmpGarrisonHolder.UnloadAllOwn())
 				notifyUnloadFailure(player, garrisonHolder)
 		}
 		break;
 
 	case "unload-all":
-		var selected = FilterEntityList(cmd.garrisonHolders, player, controlAllUnits);
-		for each (var garrisonHolder in selected)
+		var entities = FilterEntityList(cmd.garrisonHolders, player, controlAllUnits);
+		for each (var garrisonHolder in entities)
 		{
 			var cmpGarrisonHolder = Engine.QueryInterface(garrisonHolder, IID_GarrisonHolder);
 			if (!cmpGarrisonHolder || !cmpGarrisonHolder.UnloadAll())
@@ -375,7 +424,6 @@ function ProcessCommand(player, cmd)
 		break;
 
 	case "formation":
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		GetFormationUnitAIs(entities, player, cmd.name).forEach(function(cmpUnitAI) {
 			cmpUnitAI.MoveIntoFormation(cmd);
 		});
@@ -395,7 +443,6 @@ function ProcessCommand(player, cmd)
 		break;
 
 	case "stance":
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		for each (var ent in entities)
 		{
 			var cmpUnitAI = Engine.QueryInterface(ent, IID_UnitAI);
@@ -405,7 +452,6 @@ function ProcessCommand(player, cmd)
 		break;
 
 	case "wall-to-gate":
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		for each (var ent in entities)
 		{
 			TryTransformWallToGate(ent, cmpPlayer, cmd.template);
@@ -413,7 +459,6 @@ function ProcessCommand(player, cmd)
 		break;
 
 	case "lock-gate":
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		for each (var ent in entities)
 		{
 			var cmpGate = Engine.QueryInterface(ent, IID_Gate);
@@ -428,7 +473,7 @@ function ProcessCommand(player, cmd)
 		break;
 
 	case "setup-trade-route":
-		for each (var ent in cmd.entities)
+		for each (var ent in entities)
 		{
 			var cmpUnitAI = Engine.QueryInterface(ent, IID_UnitAI);
 			if (cmpUnitAI)
@@ -437,7 +482,7 @@ function ProcessCommand(player, cmd)
 		break;
 
 	case "select-trading-goods":
-		for each (var ent in cmd.entities)
+		for each (var ent in entities)
 		{
 			var cmpTrader = Engine.QueryInterface(ent, IID_Trader);
 			if (cmpTrader)
@@ -461,7 +506,6 @@ function ProcessCommand(player, cmd)
 		break;
 
 	case "pack":
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		for each (var ent in entities)
 		{
 			var cmpUnitAI = Engine.QueryInterface(ent, IID_UnitAI);
@@ -476,7 +520,6 @@ function ProcessCommand(player, cmd)
 		break;
 
 	case "cancel-pack":
-		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		for each (var ent in entities)
 		{
 			var cmpUnitAI = Engine.QueryInterface(ent, IID_UnitAI);
@@ -506,6 +549,17 @@ function notifyUnloadFailure(player, garrisonHolder)
 	cmpGUIInterface.PushNotification(notification);
 }
 
+/**
+ * Sends a GUI notification about worker(s) that failed to go back to work.
+ */
+function notifyBackToWorkFailure(player)
+{
+	var cmpPlayer = QueryPlayerIDInterface(player, IID_Player);
+	var notification = {"player": cmpPlayer.GetPlayerID(), "message": "Some unit(s) can't go back to work" };
+	var cmpGUIInterface = Engine.QueryInterface(SYSTEM_ENTITY, IID_GuiInterface);
+	cmpGUIInterface.PushNotification(notification);
+}
+
 /**
  * Get some information about the formations used by entities.
  * The entities must have a UnitAI component.
@@ -639,6 +693,7 @@ function TryConstructBuilding(player, cmpPlayer, controlAllUnits, cmd)
 	//   "x": ...,
 	//   "z": ...,
 	//   "angle": ...,
+	//   "metadata": "...",                 // AI metadata of the building
 	//   "actorSeed": ...,
 	//   "autorepair": true,                // whether to automatically start constructing/repairing the new foundation
 	//   "autocontinue": true,              // whether to automatically gather/build/etc after finishing this
@@ -715,7 +770,7 @@ function TryConstructBuilding(player, cmpPlayer, controlAllUnits, cmd)
 		{
 			if (g_DebugCommands)
 			{
-				warn("Invalid command: build restrictions check failed for player "+player+": "+uneval(cmd));
+				warn("Invalid command: build restrictions check failed with '"+ret.message+"' for player "+player+": "+uneval(cmd));
 			}
 
 			var cmpGuiInterface = Engine.QueryInterface(SYSTEM_ENTITY, IID_GuiInterface);
@@ -789,6 +844,10 @@ function TryConstructBuilding(player, cmpPlayer, controlAllUnits, cmd)
 	var cmpFoundation = Engine.QueryInterface(ent, IID_Foundation);
 	cmpFoundation.InitialiseConstruction(player, cmd.template);
 
+	// send Metadata info if any
+	if (cmd.metadata)
+		Engine.PostMessage(ent, MT_AIMetadata, { "id": ent, "metadata" : cmd.metadata, "owner" : player } );
+	
 	// Tell the units to start building this new entity
 	if (cmd.autorepair)
 	{
@@ -1233,38 +1292,31 @@ function GetFormationRequirements(formationName)
 
 function CanMoveEntsIntoFormation(ents, formationName)
 {
-	var count = ents.length;
-
 	// TODO: should check the player's civ is allowed to use this formation
 	// See simulation/components/Player.js GetFormations() for a list of all allowed formations
 
 	var requirements = GetFormationRequirements(formationName);
 	if (!requirements)
 		return false;
-	
-	if (count < requirements.count)
-		return false;
 
-	var scatterOnlyUnits = true;
+	formationName = formationName.replace(/\s+/g,"");
+
+	var count = 0;
+	var reqClasses = requirements.classesRequired || [];
 	for each (var ent in ents)
 	{
 		var cmpIdentity = Engine.QueryInterface(ent, IID_Identity);
-		if (cmpIdentity)
-		{
-			var classes = cmpIdentity.GetClassesList();
-			if (scatterOnlyUnits && (classes.indexOf("Worker") == -1 || classes.indexOf("Support") == -1))
-				scatterOnlyUnits = false;
-			for each (var classRequired in requirements.classesRequired)
-			{
-				if (classes.indexOf(classRequired) == -1)
-				{
-					return false;
-				}
-			}
-		}
+		if (!cmpIdentity || !cmpIdentity.CanUseFormation(formationName))
+			continue;
+
+		var classes = cmpIdentity.GetClassesList();
+		if (reqClasses.some(function(c){return classes.indexOf(c) == -1;}))
+			return false;
+
+		count++;
 	}
 
-	if (scatterOnlyUnits)
+	if (count < requirements.count)
 		return false;
 
 	return true;
@@ -1272,14 +1324,25 @@ function CanMoveEntsIntoFormation(ents, formationName)
 
 /**
  * Check if player can control this entity
- * returns: true if the entity is valid and owned by the player if
- *		or control all units is activated for the player, else false
+ * returns: true if the entity is valid and owned by the player
+ *          or control all units is activated, else false
  */
 function CanControlUnit(entity, player, controlAll)
 {
 	return (IsOwnedByPlayer(player, entity) || controlAll);
 }
 
+/**
+ * Check if player can control this entity
+ * returns: true if the entity is valid and owned by the player
+ *          or the entity is owned by an mutualAlly
+ *          or control all units is activated, else false
+ */
+function CanControlUnitOrIsAlly(entity, player, controlAll)
+{
+	return (IsOwnedByPlayer(player, entity) || IsOwnedByMutualAllyOfPlayer(player, entity) || controlAll);
+}
+
 /**
  * Filter entities which the player can control
  */
@@ -1288,6 +1351,14 @@ function FilterEntityList(entities, player, controlAll)
 	return entities.filter(function(ent) { return CanControlUnit(ent, player, controlAll);} );
 }
 
+/**
+ * Filter entities which the player can control or are mutualAlly
+ */
+function FilterEntityListWithAllies(entities, player, controlAll)
+{
+	return entities.filter(function(ent) { return CanControlUnitOrIsAlly(ent, player, controlAll);} );
+}
+
 /**
  * Try to transform a wall to a gate 
  */
