@@ -1,40 +1,38 @@
 RMS.LoadLibrary("rmgen");
 
-var tGrass = ["steppe_grass_a", "steppe_grass_b", "steppe_grass_c", "steppe_grass_d"];
-var tGrassPForest = "steppe_grass_c";
-var tGrassDForest = "steppe_grass_c";
-var tGrassA = "steppe_grass_b";
-var tGrassB = "steppe_grass_c";
-var tGrassC = ["steppe_grass_b", "steppe_grass_c", "steppe_grass_d"];
-var tDirt = ["steppe_dirt_a", "steppe_dirt_b"];
-var tRoad = "road_stones";
-var tRoadWild = "road_stones";
-var tShoreBlend = "desert_shore_stones";
-var tShore = "dirta";
-var tWater = "desert_sand_wet";
+const tGrass = ["steppe_grass_a", "steppe_grass_b", "steppe_grass_c", "steppe_grass_d"];
+const tForestFloor = "steppe_grass_c";
+const tGrassA = "steppe_grass_b";
+const tGrassB = "steppe_grass_c";
+const tGrassC = ["steppe_grass_b", "steppe_grass_c", "steppe_grass_d"];
+const tGrassD = "steppe_grass_a";
+const tDirt = ["steppe_dirt_a", "steppe_dirt_b"];
+const tRoad = "road_stones";
+const tRoadWild = "road_stones";
+const tShoreBlend = "desert_shore_stones";
+const tShore = "dirta";
+const tWater = "desert_sand_wet";
 
 // gaia entities
-var oBeech = "gaia/flora_tree_poplar_lombardy";
-var oBush = "gaia/flora_bush_temperate";
-var oBerryBush = "gaia/flora_bush_berry";
-var oChicken = "gaia/fauna_chicken";
-var oDeer = "gaia/fauna_rabbit";
-var oFish = "gaia/fauna_fish";
-var oSheep = "gaia/fauna_sheep";
-var oStoneLarge = "gaia/geology_stonemine_medit_quarry";
-var oStoneSmall = "gaia/geology_stone_mediterranean";
-var oMetalLarge = "gaia/geology_metal_mediterranean_slabs";
+const oPoplar = "gaia/flora_tree_poplar_lombardy";
+const oBush = "gaia/flora_bush_temperate";
+const oBerryBush = "gaia/flora_bush_berry";
+const oChicken = "gaia/fauna_chicken";
+const oRabbid = "gaia/fauna_rabbit";
+const oSheep = "gaia/fauna_sheep";
+const oStoneLarge = "gaia/geology_stonemine_medit_quarry";
+const oStoneSmall = "gaia/geology_stone_mediterranean";
+const oMetalLarge = "gaia/geology_metal_mediterranean_slabs";
 
 // decorative props
-var aGrass = "actor|props/flora/grass_soft_small_tall.xml";
-var aGrassShort = "actor|props/flora/grass_soft_large.xml";
-var aRockLarge = "actor|geology/stone_granite_med.xml";
-var aRockMedium = "actor|geology/stone_granite_med.xml";
-var aBushMedium = "actor|props/flora/bush_medit_me.xml";
-var aBushSmall = "actor|props/flora/bush_medit_sm.xml";
+const aGrass = "actor|props/flora/grass_soft_small_tall.xml";
+const aGrassShort = "actor|props/flora/grass_soft_large.xml";
+const aRockLarge = "actor|geology/stone_granite_med.xml";
+const aRockMedium = "actor|geology/stone_granite_med.xml";
+const aBushMedium = "actor|props/flora/bush_medit_me.xml";
+const aBushSmall = "actor|props/flora/bush_medit_sm.xml";
 
-var pForestD = [tGrassDForest + TERRAIN_SEPARATOR + oBeech, tGrassDForest];
-var pForestP = [tGrassPForest + TERRAIN_SEPARATOR + oBeech, tGrassPForest];
+const pForest = [tForestFloor + TERRAIN_SEPARATOR + oPoplar, tForestFloor];
 const BUILDING_ANGlE = -PI/4;
 
 // initialize map
@@ -48,7 +46,6 @@ var mapSize = getMapSize();
 var mapArea = mapSize*mapSize;
 
 // create tile classes
-
 var clPlayer = createTileClass();
 var clHill = createTileClass();
 var clForest = createTileClass();
@@ -60,7 +57,6 @@ var clFood = createTileClass();
 var clBaseResource = createTileClass();
 var clSettlement = createTileClass();
 
-
 // randomize player order
 var playerIDs = [];
 for (var i = 0; i < numPlayers; i++)
@@ -170,7 +166,7 @@ for (var i = 0; i < numPlayers; i++)
 	var tX = round(fx + tDist * cos(tAngle));
 	var tZ = round(fz + tDist * sin(tAngle));
 	group = new SimpleGroup(
-		[new SimpleObject(oBeech, num, num, 0,5)],
+		[new SimpleObject(oPoplar, num, num, 0,5)],
 		false, clBaseResource, tX, tZ
 	);
 	createObjectGroup(group, 0, avoidClasses(clBaseResource,2));
@@ -216,10 +212,7 @@ var numStragglers = totalTrees * (1.0 - P_FOREST);
 
 // create forests
 log("Creating forests...");
-var types = [
-	[[tGrassDForest, tGrass, pForestD], [tGrassDForest, pForestD]],
-	[[tGrassPForest, tGrass, pForestP], [tGrassPForest, pForestP]]
-];	// some variation
+var types = [[[tForestFloor, tGrass, pForest], [tForestFloor, pForest]]];	// some variation
 
 var size = numForest / (scaleByMapSize(2,8) * numPlayers);
 
@@ -267,7 +260,7 @@ for (var i = 0; i < sizes.length; i++)
 {
 	placer = new ClumpPlacer(sizes[i], 0.3, 0.06, 0.5);
 	painter = new LayeredPainter(
-		[tGrassB ,tDirt], 		// terrains
+		[tGrassD ,tDirt], 		// terrains
 		[1]															// widths
 	);
 	createAreas(
@@ -302,14 +295,14 @@ log("Creating stone mines...");
 // create large stone quarries
 group = new SimpleGroup([new SimpleObject(oStoneSmall, 0,2, 0,4), new SimpleObject(oStoneLarge, 1,1, 0,4)], true, clRock);
 createObjectGroups(group, 0,
-	avoidClasses(clForest, 1, clPlayer, 10, clRock, 10, clHill, 1),
+	avoidClasses(clForest, 1, clPlayer, 20, clRock, 10, clHill, 1),
 	scaleByMapSize(1,4), 100
 );
 
 // create small stone quarries
 group = new SimpleGroup([new SimpleObject(oStoneSmall, 2,5, 1,3)], true, clRock);
 createObjectGroups(group, 0,
-	avoidClasses(clForest, 1, clPlayer, 10, clRock, 10, clHill, 1),
+	avoidClasses(clForest, 1, clPlayer, 20, clRock, 10, clHill, 1),
 	scaleByMapSize(1,4), 100
 );
 
@@ -317,7 +310,7 @@ log("Creating metal mines...");
 // create large metal quarries
 group = new SimpleGroup([new SimpleObject(oMetalLarge, 1,1, 0,4)], true, clMetal);
 createObjectGroups(group, 0,
-	avoidClasses(clForest, 1, clPlayer, 10, clMetal, 10, clRock, 5, clHill, 1),
+	avoidClasses(clForest, 1, clPlayer, 20, clMetal, 10, clRock, 5, clHill, 1),
 	scaleByMapSize(2,8), 100
 );
 
@@ -350,10 +343,10 @@ createObjectGroups(
 
 RMS.SetProgress(70);
 
-// create deer
-log("Creating deer...");
+// create rabbid
+log("Creating rabbid...");
 group = new SimpleGroup(
-	[new SimpleObject(oDeer, 5,7, 0,4)],
+	[new SimpleObject(oRabbid, 5,7, 0,4)],
 	true, clFood
 );
 createObjectGroups(group, 0,
@@ -361,6 +354,17 @@ createObjectGroups(group, 0,
 	6 * numPlayers, 50
 );
 
+// create berry bush
+log("Creating berry bush...");
+group = new SimpleGroup(
+	[new SimpleObject(oBerryBush, 5,7, 0,4)],
+	true, clFood
+);
+createObjectGroups(group, 0,
+	avoidClasses(clWater, 3, clForest, 0, clPlayer, 20, clHill, 1, clFood, 20),
+	randInt(1, 4) * numPlayers + 2, 50
+);
+
 RMS.SetProgress(75);
 
 // create sheep
@@ -379,7 +383,7 @@ RMS.SetProgress(85);
 
 // create straggler trees
 log("Creating straggler trees...");
-var types = [oBush, oBeech];	// some variation
+var types = [oBush, oPoplar];	// some variation
 var num = floor(numStragglers / types.length);
 for (var i = 0; i < types.length; ++i)
 {
