@@ -1,19 +1,36 @@
 RMS.LoadLibrary("rmgen");
 
-const tCity = "desert_city_tile_plaza";
-const tSand = ["desert_dirt_persia_1", "desert_dirt_persia_2", "grass_field_dry"];
-const tDunes = ["desert_lakebed_dry_b", "desert_dirt_persia_1", "desert_dirt_persia_2", "desert_lakebed_dry"];
-const tDunes2 = ["desert_lakebed_dry_b", "desert_dirt_persia_1", "desert_dirt_persia_2", "desert_lakebed_dry", "desert_dirt_persia_2", "desert_dirt_persia_1"];
-const tFineSand = "desert_pebbles_rough";
-const tCliff = ["desert_cliff_persia_1", "desert_cliff_persia_2"];
-const tForestFloor = "medit_grass_field_dry";
-const tRocky = "desert_dirt_persia_rocky";
-const tRocks = "desert_dirt_persia_rocks";
-const tDirt = ["desert_pebbles_rough", "grass_field_brown"];
-const tHill = "desert_cliff_persia_base";
+const tCity = "desert_city_tile_pers_dirt";
+var random_season = randInt(0,1);
+if (random_season) //summer
+{
+	var tDirtMain = ["desert_dirt_persia_1", "desert_dirt_persia_2", "grass_field_dry"];
+	var tLakebed1 = ["desert_lakebed_dry_b", "desert_lakebed_dry"];
+	var tLakebed2 = ["desert_lakebed_dry_b", "desert_lakebed_dry", "desert_shore_stones", "desert_shore_stones"];
+	var tPebbles = "desert_pebbles_rough";
+	var tCliff = ["desert_cliff_persia_1", "desert_cliff_persia_crumbling"];
+	var tForestFloor = "medit_grass_field_dry";
+	var tRocky = "desert_dirt_persia_rocky";
+	var tRocks = "desert_dirt_persia_rocks";
+	var tGrass = "grass_field_dry";
+	var tHill = "desert_cliff_persia_base";
+}
+else //spring
+{
+	var tDirtMain = ["desert_grass_a", "desert_grass_a", "desert_grass_a", "desert_plants_a"];
+	var tLakebed1 = ["desert_lakebed_dry_b", "desert_lakebed_dry"];
+	var tLakebed2 = "desert_grass_a_sand";
+	var tPebbles = "desert_pebbles_rough";
+	var tCliff = ["desert_cliff_persia_1", "desert_cliff_persia_crumbling"];
+	var tForestFloor = "desert_plants_b_persia";
+	var tRocky = "desert_plants_b_persia";
+	var tRocks = "desert_plants_a";
+	var tGrass = "desert_dirt_persia_rocky";
+	var tHill = "desert_cliff_persia_base";
+}
 
 // gaia entities
-const oBerryBush = "gaia/flora_bush_grapes";
+const oGrapesBush = "gaia/flora_bush_grapes";
 const oChicken = "gaia/fauna_chicken";
 const oCamel = "gaia/fauna_camel";
 const oFish = "gaia/fauna_fish";
@@ -23,7 +40,7 @@ const oLion = "gaia/fauna_lioness";
 const oStoneLarge = "gaia/geology_stonemine_desert_badlands_quarry";
 const oStoneSmall = "gaia/geology_stone_desert_small";
 const oMetalLarge = "gaia/geology_metal_desert_slabs";
-const oDead = "gaia/flora_tree_tamarix";
+const oTamarix = "gaia/flora_tree_tamarix";
 const oOak = "gaia/flora_tree_oak";
 
 // decorative props
@@ -35,8 +52,7 @@ const aBushes = [aBush1, aBush2, aBush3, aBush4];
 const aDecorativeRock = "actor|geology/stone_desert_med.xml";
 
 // terrain + entity (for painting)
-const pForestO = [tForestFloor + TERRAIN_SEPARATOR + oOak, tForestFloor + TERRAIN_SEPARATOR + oOak, tForestFloor, tSand, tSand];
-const pForestD = [tForestFloor + TERRAIN_SEPARATOR + oDead, tForestFloor + TERRAIN_SEPARATOR + oDead, tForestFloor, tSand, tSand];
+const pForestO = [tForestFloor + TERRAIN_SEPARATOR + oOak, tForestFloor + TERRAIN_SEPARATOR + oOak, tForestFloor, tDirtMain, tDirtMain];
 
 const BUILDING_ANGlE = -PI/4;
 
@@ -44,9 +60,9 @@ log("Initializing map...");
 
 InitMap();
 
-var numPlayers = getNumPlayers();
-var mapSize = getMapSize();
-var mapArea = mapSize*mapSize;
+const numPlayers = getNumPlayers();
+const mapSize = getMapSize();
+const mapArea = mapSize*mapSize;
 
 // create tile classes
 
@@ -61,6 +77,15 @@ var clFood = createTileClass();
 var clBaseResource = createTileClass();
 var clCP = createTileClass();
 
+for (var ix = 0; ix < mapSize; ix++)
+{
+	for (var iz = 0; iz < mapSize; iz++)
+	{
+		var x = ix / (mapSize + 1.0);
+		var z = iz / (mapSize + 1.0);
+			placeTerrain(ix, iz, tDirtMain);
+	}
+}
 
 var playerIDs = [];
 for (var i = 0; i < numPlayers; i++)
@@ -133,7 +158,7 @@ for (var i = 0; i < numPlayers; i++)
 	var bbX = round(fx + bbDist * cos(bbAngle));
 	var bbZ = round(fz + bbDist * sin(bbAngle));
 	group = new SimpleGroup(
-		[new SimpleObject(oBerryBush, 5,5, 0,3)],
+		[new SimpleObject(oGrapesBush, 5,5, 0,3)],
 		true, clBaseResource, bbX, bbZ
 	);
 	createObjectGroup(group, 0);
@@ -180,7 +205,7 @@ RMS.SetProgress(10);
 
 // create patches
 log("Creating rock patches...");
-placer = new ClumpPlacer(scaleByMapSize(40, 150), 0.2, 0.1, 0);
+placer = new ChainPlacer(1, floor(scaleByMapSize(3, 6)), floor(scaleByMapSize(20, 45)), 0);
 painter = new TerrainPainter(tRocky);
 createAreas(placer, [painter, paintClass(clPatch)], 
 	avoidClasses(clPatch, 2, clPlayer, 0),
@@ -189,20 +214,20 @@ createAreas(placer, [painter, paintClass(clPatch)],
 
 RMS.SetProgress(15);
 
-var placer = new ClumpPlacer(scaleByMapSize(25, 100), 0.2, 0.1, 0);
+var placer = new ChainPlacer(1, floor(scaleByMapSize(3, 5)), floor(scaleByMapSize(15, 40)), 0);
 var painter = new TerrainPainter([tRocky, tRocks]);
 createAreas(placer, [painter, paintClass(clPatch)], 
-	avoidClasses(clPatch, 2, clPlayer, 0),
+	avoidClasses(clPatch, 2, clPlayer, 4),
 	scaleByMapSize(15, 50)
 );
 
 RMS.SetProgress(20);
 
 log("Creating dirt patches...");
-placer = new ClumpPlacer(scaleByMapSize(25, 100), 0.2, 0.1, 0);
-painter = new TerrainPainter([tDirt]);
+placer = new ChainPlacer(1, floor(scaleByMapSize(3, 5)), floor(scaleByMapSize(15, 40)), 0);
+painter = new TerrainPainter([tGrass]);
 createAreas(placer, [painter, paintClass(clPatch)], 
-	avoidClasses(clPatch, 2, clPlayer, 0),
+	avoidClasses(clPatch, 2, clPlayer, 4),
 	scaleByMapSize(15, 50)
 );
 
@@ -210,30 +235,35 @@ RMS.SetProgress(25);
 
 // create centeral plateau
 log("Creating centeral plateau...");
+var halfSize = mapSize / 2;
 var oRadius = scaleByMapSize(18, 68);
-placer = new ClumpPlacer(PI*oRadius*oRadius, 0.6, 0.15, 0, mapSize/2, mapSize/2);
-painter = new LayeredPainter([tDunes2, tDunes], [8]);
+placer = new ChainPlacer(2, floor(scaleByMapSize(5, 13)), floor(scaleByMapSize(35, 200)), 1, halfSize, halfSize, 0, [floor(oRadius)]);
+painter = new LayeredPainter([tLakebed2, tLakebed1], [6]);
 var elevationPainter = new SmoothElevationPainter(ELEVATION_MODIFY, -10, 8);
-createArea(placer, [painter, elevationPainter, paintClass(clCP)], null);
+createArea(placer, [painter, elevationPainter, paintClass(clCP)], avoidClasses(clPlayer, 18));
 
 
 RMS.SetProgress(30);
 
-
 // create hills
 log("Creating hills...");
-placer = new ClumpPlacer(scaleByMapSize(20, 150), 0.2, 0.1, 1);
-var terrainPainter = new LayeredPainter(
-	[tCliff, tHill],		// terrains
-	[2]								// widths
-);
-var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, 22, 2);
-createAreas(
-	placer,
-	[terrainPainter, elevationPainter, paintClass(clHill)], 
-	avoidClasses(clPlayer, 3, clCP, 5, clHill, 10),
-	scaleByMapSize(1, 4) * numPlayers * 3
-);
+var numHills = scaleByMapSize(20, 80)
+for (var i = 0; i < numHills; ++i)
+{
+	
+	createMountain(
+		floor(scaleByMapSize(40, 60)),
+		floor(scaleByMapSize(3, 4)),
+		floor(scaleByMapSize(6, 12)),
+		floor(scaleByMapSize(4, 10)),
+		avoidClasses(clPlayer, 7, clCP, 5, clHill, floor(scaleByMapSize(18, 25))),
+		randInt(mapSize),
+		randInt(mapSize),
+		tCliff,
+		clHill,
+		14
+	);
+}
 
 RMS.SetProgress(35);
 
@@ -249,14 +279,14 @@ var numStragglers = totalTrees * (1.0 - P_FOREST);
 // create forests
 log("Creating forests...");
 var types = [
-	[[tSand, tForestFloor, pForestO], [tForestFloor, pForestO]],
-	[[tSand, tForestFloor, pForestO], [tForestFloor, pForestO]]
+	[[tDirtMain, tForestFloor, pForestO], [tForestFloor, pForestO]],
+	[[tDirtMain, tForestFloor, pForestO], [tForestFloor, pForestO]]
 ];	// some variation
-var size = numForest / (scaleByMapSize(2,8) * numPlayers);
+var size = numForest / (scaleByMapSize(3,6) * numPlayers);
 var num = floor(size / types.length);
 for (var i = 0; i < types.length; ++i)
 {
-	placer = new ClumpPlacer(numForest / num, 0.1, 0.1, 1);
+	placer = new ChainPlacer(floor(scaleByMapSize(1, 2)), floor(scaleByMapSize(2, 5)), floor(size / floor(scaleByMapSize(8, 3))), 1);
 	painter = new LayeredPainter(
 		types[i],		// terrains
 		[2]											// widths
@@ -264,7 +294,7 @@ for (var i = 0; i < types.length; ++i)
 	createAreas(
 		placer,
 		[painter, paintClass(clForest)], 
-		avoidClasses(clPlayer, 1, clWater, 3, clForest, 10, clHill, 1, clCP, 1),
+		avoidClasses(clPlayer, 6, clWater, 3, clForest, 10, clHill, 1, clCP, 1),
 		num
 	);
 }
@@ -300,23 +330,23 @@ log("Creating centeral stone mines...");
 // create large stone quarries
 group = new SimpleGroup([new SimpleObject(oStoneSmall, 0,2, 0,4), new SimpleObject(oStoneLarge, 1,1, 0,4), new RandomObject(aBushes, 2,4, 0,2)], true, clRock);
 createObjectGroups(group, 0,
-	stayClasses(clCP, 3),
-	5*scaleByMapSize(10,30), 100
+	stayClasses(clCP, 6),
+	5*scaleByMapSize(5,30), 50
 );
 
 // create small stone quarries
 group = new SimpleGroup([new SimpleObject(oStoneSmall, 2,5, 1,3), new RandomObject(aBushes, 2,4, 0,2)], true, clRock);
 createObjectGroups(group, 0,
-	stayClasses(clCP, 3),
-	5*scaleByMapSize(10,30), 100
+	stayClasses(clCP, 6),
+	5*scaleByMapSize(5,30), 50
 );
 
 log("Creating centeral metal mines...");
 // create large metal quarries
 group = new SimpleGroup([new SimpleObject(oMetalLarge, 1,1, 0,4), new RandomObject(aBushes, 2,4, 0,2)], true, clMetal);
 createObjectGroups(group, 0,
-	stayClasses(clCP, 3),
-	5*scaleByMapSize(10,30), 100
+	stayClasses(clCP, 6),
+	5*scaleByMapSize(5,30), 50
 );
 
 RMS.SetProgress(60);
@@ -371,6 +401,17 @@ createObjectGroups(group, 0,
 	3 * numPlayers, 50
 );
 
+// create grape bush
+log("Creating grape bush...");
+group = new SimpleGroup(
+	[new SimpleObject(oGrapesBush, 5,7, 0,4)],
+	true, clFood
+);
+createObjectGroups(group, 0,
+	avoidClasses(clForest, 0, clPlayer, 20, clHill, 1, clFood, 10, clCP, 2),
+	randInt(1, 4) * numPlayers + 2, 50
+);
+
 // create camels
 log("Creating camels...");
 group = new SimpleGroup(
@@ -382,23 +423,6 @@ createObjectGroups(group, 0,
 	3 * numPlayers, 50
 );
 
-RMS.SetProgress(85);
-
-// create dead trees
-log("Creating dead trees...");
-var types = [oDead];	// some variation
-var num = floor(numStragglers / types.length);
-for (var i = 0; i < types.length; ++i)
-{
-	group = new SimpleGroup(
-		[new SimpleObject(types[i], 1,1, 0,3)],
-		true, clForest
-	);
-	createObjectGroups(group, 0,
-		[avoidClasses(clMetal, 1, clRock, 1), stayClasses(clCP, 2)],
-		num
-	);
-}
 
 RMS.SetProgress(90);
 
@@ -418,6 +442,20 @@ for (var i = 0; i < types.length; ++i)
 	);
 }
 
+if (!random_season)
+	setTerrainAmbientColour(0.329412, 0.419608, 0.501961);
+
+setSunColour(1.0, 0.796, 0.374);	
+setSunElevation(PI / 6);
+setSunRotation(-1.86532);
+
+setFogFactor(0.2);
+setFogThickness(0.0);
+setFogColor(0.852, 0.746, 0.493);
+
+setPPEffect("hdr");
+setPPContrast(0.75);
+setPPSaturation(0.45);
+setPPBloom(0.3);
 
-setSunColour(0.733, 0.746, 0.574);	
 ExportMap();
\ No newline at end of file
