@@ -52,6 +52,10 @@ var rba9 = "actor|flora/trees/oak.xml";
 
 function randomizeBiome()
 {
+
+	setUnitsAmbientColour(0.57, 0.58, 0.55);
+	setTerrainAmbientColour(0.447059, 0.509804, 0.54902);
+	
 	biomeID = randInt(1,8);
 	//temperate
 	if (biomeID == 1){
@@ -65,6 +69,14 @@ function randomizeBiome()
 		setWaterMurkiness(0.83);
 		setWaterReflectionTintStrength(0.05);
 		
+		setFogThickness(0.25);
+		setFogFactor(0.4);
+
+		setPPEffect("hdr");
+		setPPSaturation(0.62);
+		setPPContrast(0.62);
+		setPPBloom(0.3);
+		
 		rbt1 = ["temp_grass_long_b"];
 		rbt2 = "temp_forestfloor_pine";
 		rbt3 = "temp_plants_bog";
@@ -95,9 +107,9 @@ function randomizeBiome()
 		rbe8 = "gaia/fauna_deer";
 		rbe9 = "gaia/fauna_fish";
 		rbe10 = "gaia/fauna_sheep";
-		rbe11 = "gaia/geology_stonemine_medit_quarry";
-		rbe12 = "gaia/geology_stone_mediterranean";
-		rbe13 = "gaia/geology_metal_mediterranean_slabs";
+		rbe11 = "gaia/geology_stonemine_temperate_quarry";
+		rbe12 = "gaia/geology_stone_temperate";
+		rbe13 = "gaia/geology_metal_temperate_slabs";
 
 		// decorative props
 		rba1 = "actor|props/flora/grass_soft_large_tall.xml";
@@ -109,7 +121,7 @@ function randomizeBiome()
 		rba7 = "actor|props/flora/bush_medit_me.xml";
 		rba8 = "actor|props/flora/bush_medit_sm.xml";
 		rba9 = "actor|flora/trees/oak.xml";
-		}
+	}
 	//snowy
 	else if (biomeID == 2)
 	{
@@ -127,11 +139,11 @@ function randomizeBiome()
 		rbt2 = "polar_tundra_snow";
 		rbt3 = "polar_tundra_snow";
 		rbt4 = ["alpine_cliff_a", "alpine_cliff_b"];
-		rbt5 = "snow grass 2";
-		rbt6 = "polar_snow_a";
-		rbt7 = "polar_ice_snow";
+		rbt5 = "polar_snow_a";
+		rbt6 = "polar_ice_snow";
+		rbt7 = "polar_ice";
 		rbt8 = ["polar_snow_rocks", "polar_cliff_snow"];
-		rbt9 = ["polar_ice_b", "polar_ice_c"];
+		rbt9 = "snow grass 2";
 		rbt10 = "new_alpine_citytile";
 		rbt11 = "polar_ice_cracked";
 		rbt12 = "snow grass 2";
@@ -165,7 +177,10 @@ function randomizeBiome()
 		rba8 = "actor|props/flora/bush_desert_dry_a.xml";
 		rba9 = "actor|flora/trees/pine_w.xml";
 			
-
+		setFogFactor(0.6);
+		setFogThickness(0.21);
+		setPPSaturation(0.37);
+		setPPEffect("hdr");
 	}
 	//desert
 	else if (biomeID == 3)
@@ -180,13 +195,22 @@ function randomizeBiome()
 		setWaterMurkiness(0.22);
 		setWaterReflectionTintStrength(0.0);
 		
+		setFogFactor(0.5);
+		setFogThickness(0.0);
+		setFogColor(0.852, 0.746, 0.493);
+
+		setPPEffect("hdr");
+		setPPContrast(0.67);
+		setPPSaturation(0.42);
+		setPPBloom(0.23);
+		
 		rbt1 = ["desert_dirt_rough", "desert_dirt_rough_2", "desert_sand_dunes_50", "desert_sand_smooth"];
 		rbt2 = "forestfloor_dirty";
 		rbt3 = "desert_forestfloor_palms";
 		rbt4 = ["desert_cliff_1", "desert_cliff_2", "desert_cliff_3", "desert_cliff_4", "desert_cliff_5"];
-		rbt5 = ["desert_dirt_persia_1", "desert_dirt_persia_2"];
-		rbt6 = "dirta";
-		rbt7 = "medit_dirt_dry";
+		rbt5 = "desert_dirt_rough";
+		rbt6 = "desert_dirt_rocks_1";
+		rbt7 = "desert_dirt_rocks_2";
 		rbt8 = ["desert_dirt_rocks_1", "desert_dirt_rocks_2", "desert_dirt_rocks_3"];
 		rbt9 = ["desert_lakebed_dry", "desert_lakebed_dry_b"];
 		rbt10 = "desert_city_tile";
@@ -234,12 +258,20 @@ function randomizeBiome()
 		setWaterWaviness(2);
 		setWaterReflectionTintStrength(0.15);
 
+		setFogThickness(0.26);
+		setFogFactor(0.4);
+
+		setPPEffect("hdr");
+		setPPSaturation(0.48);
+		setPPContrast(0.53);
+		setPPBloom(0.12);
+		
 		rbt1 = ["alpine_dirt_grass_50"];
 		rbt2 = "alpine_forrestfloor";
 		rbt3 = "alpine_forrestfloor";
 		rbt4 = ["alpine_cliff_a", "alpine_cliff_b", "alpine_cliff_c"];
-		rbt5 = "alpine_grass_rocky";
-		rbt6 = ["alpine_grass_snow_50", "alpine_dirt_snow"];
+		rbt5 = "alpine_dirt";
+		rbt6 = ["alpine_grass_snow_50", "alpine_dirt_snow", "alpine_dirt_snow"];
 		rbt7 = ["alpine_snow_a", "alpine_snow_b"];
 		rbt8 = "alpine_cliff_snow";
 		rbt9 = ["alpine_dirt", "alpine_grass_d"];
@@ -266,14 +298,14 @@ function randomizeBiome()
 		rbe13 = "gaia/geology_metal_alpine_slabs";
 
 		// decorative props
-		rba1 = "actor|props/flora/grass_soft_dry_small_tall.xml";
-		rba2 = "actor|props/flora/grass_soft_dry_large.xml";
+		rba1 = "actor|props/flora/grass_soft_small_tall.xml";
+		rba2 = "actor|props/flora/grass_soft_large.xml";
 		rba3 = "actor|props/flora/reeds_pond_dry.xml";
 		rba4 = "actor|geology/stone_granite_large.xml";
 		rba5 = "actor|geology/stone_granite_large.xml";
 		rba6 = "actor|geology/stone_granite_med.xml";
-		rba7 = "actor|props/flora/bush_desert_dry_a.xml";
-		rba8 = "actor|props/flora/bush_desert_dry_a.xml";
+		rba7 = "actor|props/flora/bush_desert_a.xml";
+		rba8 = "actor|props/flora/bush_desert_a.xml";
 		rba9 = "actor|flora/trees/pine.xml";
 	}
 	//medit
@@ -287,8 +319,16 @@ function randomizeBiome()
 		setWaterMurkiness(0.8);
 		setWaterReflectionTintStrength(0.1);
 
+		setFogFactor(0.3);
+		setFogThickness(0.25);
+
+		setPPEffect("hdr");
+		setPPContrast(0.62);
+		setPPSaturation(0.51);
+		setPPBloom(0.12);
+		
 		rbt1 = ["medit_grass_field_a", "medit_grass_field_b"];
-		rbt2 = "medit_plants_dirt";
+		rbt2 = "medit_grass_field";
 		rbt3 = "medit_grass_shrubs";
 		rbt4 = ["medit_cliff_grass", "medit_cliff_greek", "medit_cliff_greek_2", "medit_cliff_aegean", "medit_cliff_italia", "medit_cliff_italia_grass"];
 		rbt5 = "medit_grass_field_b";
@@ -346,13 +386,21 @@ function randomizeBiome()
 		setWaterMurkiness(0.77);
 		setWaterReflectionTintStrength(0.0);
 
+		setFogFactor(0.25);
+		setFogThickness(0.15);
+		setFogColor(0.847059, 0.737255, 0.482353);
+
+		setPPEffect("hdr");
+		setPPContrast(0.57031);
+		setPPBloom(0.34);
+		
 		rbt1 = ["savanna_grass_a", "savanna_grass_b"];
 		rbt2 = "savanna_forestfloor_a";
 		rbt3 = "savanna_forestfloor_b";
 		rbt4 = ["savanna_cliff_a", "savanna_cliff_b"];
 		rbt5 = "savanna_shrubs_a";
 		rbt6 = "savanna_dirt_rocks_b";
-		rbt7 = "dirt_brown_e";
+		rbt7 = "savanna_dirt_rocks_a";
 		rbt8 = ["savanna_grass_a", "savanna_grass_b"];
 		rbt9 = ["savanna_dirt_rocks_b", "dirt_brown_e"];
 		rbt10 = "savanna_tile_a";
@@ -416,6 +464,14 @@ function randomizeBiome()
 		setWaterMurkiness(0.35);
 		setWaterReflectionTintStrength(0.0);
 
+		setFogFactor(0.4);
+		setFogThickness(0.2);
+
+		setPPEffect("hdr");
+		setPPContrast(0.67);
+		setPPSaturation(0.62);
+		setPPBloom(0.6);
+		
 		rbt1 = ["tropic_grass_c", "tropic_grass_c", "tropic_grass_c", "tropic_grass_c", "tropic_grass_plants", "tropic_plants", "tropic_plants_b"];
 		rbt2 = "tropic_plants_c";
 		rbt3 = "tropic_plants_c";
@@ -429,8 +485,8 @@ function randomizeBiome()
 		rbt11 = "tropic_citytile_plants";
 		rbt12 = "tropic_plants_b";
 		rbt13 = "temp_mud_plants";
-		rbt14 = "tropic_beach_dry";
-		rbt15 = "tropic_beach_wet";
+		rbt14 = "tropic_beach_dry_plants";
+		rbt15 = "tropic_beach_dry";
 
 		// gaia entities
 		rbe1 = "gaia/flora_tree_toona";
@@ -471,20 +527,28 @@ function randomizeBiome()
 		setWaterMurkiness(0.83);
 		setWaterReflectionTintStrength(0.35);
 
+		setFogFactor(0.35);
+		setFogThickness(0.22);
+		setFogColor(0.82,0.82, 0.73);
+		setPPSaturation(0.56);
+		setPPContrast(0.56);
+		setPPBloom(0.38);
+		setPPEffect("hdr");
+		
 		rbt1 = ["temp_grass_aut", "temp_grass_aut", "temp_grass_d_aut"];
-		rbt2 = "temp_grass_aut";
-		rbt3 = "temp_grass_plants_aut";
+		rbt2 = "temp_forestfloor_aut";
+		rbt3 = "temp_plants_bog_aut";
 		rbt4 = ["temp_cliff_a", "temp_cliff_b"];
-		rbt5 = "temp_plants_bog_aut";
+		rbt5 = "temp_grass_plants_aut";
 		rbt6 = ["temp_grass_b_aut", "temp_grass_c_aut"];
-		rbt7 = ["temp_plants_bog_aut", "temp_mud_a"];
-		rbt8 = ["temp_highlands_aut", "temp_grass_long_b_aut"];
+		rbt7 = ["temp_grass_b_aut", "temp_grass_long_b_aut"];
+		rbt8 = "temp_highlands_aut";
 		rbt9 = ["temp_cliff_a", "temp_cliff_b"];
 		rbt10 = "temp_road_aut";
 		rbt11 = "temp_road_overgrown_aut";
 		rbt12 = "temp_grass_plants_aut";
 		rbt13 = "temp_grass_plants_aut";
-		rbt14 = "steppe_grass_dirt_66";
+		rbt14 = "temp_forestfloor_pine";
 		rbt15 = "medit_sand_wet";
 
 		// gaia entities
