@@ -167,6 +167,14 @@ function openDeleteDialog(selection)
 // Menu functions
 // =============================================================================
 
+function openSave()
+{
+	closeMenu();
+	closeOpenDialogs();
+	pauseGame();
+	Engine.PushGuiPage("page_savegame.xml", {"gameDataCallback": getSavedGameData, "closeCallback": resumeGame});
+}
+
 function openSettings(pause)
 {
 	getGUIObjectByName("settingsDialogPanel").hidden = false;
@@ -361,6 +369,12 @@ function toggleDiplomacy()
 		openDiplomacy();
 };
 
+function toggleGameSpeed()
+{
+	var gameSpeed = getGUIObjectByName("gameSpeed");
+	gameSpeed.hidden = !gameSpeed.hidden;
+}
+
 function pauseGame()
 {
 	getGUIObjectByName("pauseButtonText").caption = RESUME;
@@ -406,6 +420,9 @@ function openManual()
 
 function toggleDeveloperOverlay()
 {
+	if (Engine.HasXmppClient() && Engine.IsRankedGame())
+		return;
+
 	var devCommands = getGUIObjectByName("devCommands");
 	var text = devCommands.hidden ? "opened." : "closed.";
 	submitChatDirectly("The Developer Overlay was " + text);
