@@ -146,7 +146,7 @@ function formatLimitString(trainEntLimit, trainEntCount)
 {
 	if (trainEntLimit == undefined)
 		return "";
-	var text = "\n\nCurrent count: " + trainEntCount + ", limit: " + trainEntLimit + ".";
+	var text = "\n\nCurrent Count: " + trainEntCount + ", Limit: " + trainEntLimit + ".";
 	if (trainEntCount >= trainEntLimit)
 		text = "[color=\"red\"]" + text + "[/color]";
 	return text;
@@ -191,14 +191,14 @@ function formatBatchTrainingString(buildingsCountToTrainFullBatch, fullBatchSize
 		batchDetailsString += ")";
 	}
 
-	return "\n\n[font=\"serif-bold-13\"]Shift-click[/font][font=\"serif-13\"] to train "
+	return "\n[font=\"serif-bold-13\"]Shift-click[/font][font=\"serif-13\"] to train "
 		+ totalBatchTrainingCount + batchDetailsString + ".[/font]";
 }
 
 /**
  * Helper function for updateUnitCommands; sets up "unit panels" (i.e. panels with rows of icons) for the currently selected
  * unit.
- * 
+ *
  * @param guiName Short identifier string of this panel; see constants defined at the top of this file.
  * @param usedPanels Output object; usedPanels[guiName] will be set to 1 to indicate that this panel was used during this
  * 				run of updateUnitCommands and should not be hidden. TODO: why is this done this way instead of having
@@ -305,7 +305,7 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 	for (i = 0; i < numberOfItems; i++)
 	{
 		var item = items[i];
-		
+
 		// If a tech has been researched it leaves an empty slot
 		if (guiName == RESEARCH && !item)
 		{
@@ -315,7 +315,7 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 			getGUIObjectByName("unit"+guiName+"Pair["+i+"]").hidden = true;
 			continue;
 		}
-		
+
 		// Get the entity type and load the template for that type if necessary
 		var entType;
 		var template;
@@ -336,7 +336,7 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 					entType = item.technologyTemplate;
 					template = GetTechnologyData(entType);
 				}
-			
+
 				if (!template)
 					continue; 	// ignore attempts to use invalid templates (an error should have been
 								// reported already)
@@ -349,7 +349,7 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 					if (!template1)
 						continue; 	// ignore attempts to use invalid templates (an error should have been
 									// reported already)
-					
+
 					entType = item.bottom;
 				}
 				else
@@ -360,7 +360,7 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 				if (!template)
 					continue; 	// ignore attempts to use invalid templates (an error should have been
 								// reported already)
-				
+
 				break;
 			case SELECTION:
 			case GARRISON:
@@ -414,12 +414,19 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 				if (item.template)
 				{
 					var template = GetTemplateData(item.template);
-					tooltip += "\n" + getEntityCostTooltip(template);
+					var wallCount = g_Selection.toList().reduce(function (count, ent) {
+							var state = GetEntityState(ent);
+							if (hasClass(state, "LongWall") && !state.gate)
+								count++;
+							return count;
+						}, 0);
+
+					tooltip += "\n" + getEntityCostTooltip(template, wallCount);
 
 					var affordableMask = getGUIObjectByName("unitGateUnaffordable["+i+"]");
 					affordableMask.hidden = true;
 
-					var neededResources = Engine.GuiInterfaceCall("GetNeededResources", template.cost);
+					var neededResources = Engine.GuiInterfaceCall("GetNeededResources", multiplyEntityCosts(template, wallCount));
 					if (neededResources)
 					{
 						affordableMask.hidden = false;
@@ -439,6 +446,9 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 
 			case TRAINING:
 				var tooltip = getEntityNamesFormatted(template);
+				var key = Engine.ConfigDB_GetValue("user", "hotkey.session.queueunit." + (i + 1));
+				if (key)
+					tooltip = "[color=\"255 251 131\"][font=\"serif-bold-16\"][" + key + "][/font][/color] " + tooltip;
 
 				if (template.tooltip)
 					tooltip += "\n[font=\"serif-13\"]" + template.tooltip + "[/font]";
@@ -446,33 +456,17 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 				var [buildingsCountToTrainFullBatch, fullBatchSize, remainderBatch] =
 					getTrainingBatchStatus(playerState, unitEntState.id, entType, selection);
 				if (Engine.HotkeyIsPressed("session.batchtrain"))
-				{
 					trainNum = buildingsCountToTrainFullBatch * fullBatchSize + remainderBatch;
-				}
 
 				tooltip += "\n" + getEntityCostTooltip(template, trainNum, unitEntState.id);
 
-				if (template.health)
-					tooltip += "\n[font=\"serif-bold-13\"]Health:[/font] " + template.health;
-				if (template.armour)
-					tooltip += "\n[font=\"serif-bold-13\"]Armour:[/font] " + damageTypesToText(template.armour);
-				if (template.attack)
-					tooltip += "\n" + getEntityAttack(template);
-				if (template.speed)
-					tooltip += "\n" + getEntitySpeed(template);
-
-				var [trainEntLimit, trainEntCount, canBeTrainedCount] =
-					getEntityLimitAndCount(playerState, entType)
+				var [trainEntLimit, trainEntCount, canBeAddedCount] =
+					getEntityLimitAndCount(playerState, entType);
 				tooltip += formatLimitString(trainEntLimit, trainEntCount);
 
-				tooltip += formatBatchTrainingString(buildingsCountToTrainFullBatch, fullBatchSize, remainderBatch);
-				var key = g_ConfigDB.system["hotkey.session.queueunit." + (i+1)];
-				if (key !== undefined)
-				{
-					tooltip += "\n[font=\"serif-bold-13\"]HotKey (" + key  + ").[/font]";
-				}
+				tooltip += "[color=\"255 251 131\"]" + formatBatchTrainingString(buildingsCountToTrainFullBatch, fullBatchSize, remainderBatch) + "[/color]";
 				break;
-				
+
 			case RESEARCH:
 				var tooltip = getEntityNamesFormatted(template);
 				if (template.tooltip)
@@ -495,11 +489,12 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 				if (template.tooltip)
 					tooltip += "\n[font=\"serif-13\"]" + template.tooltip + "[/font]";
 
-				tooltip += "\n" + getEntityCostTooltip(template); // see utility_functions.js
-				tooltip += getPopulationBonusTooltip(template); // see utility_functions.js
+				tooltip += "\n" + getEntityCostTooltip(template);
+				tooltip += getPopulationBonusTooltip(template);
 
-				if (template.health)
-					tooltip += "\n[font=\"serif-bold-13\"]Health:[/font] " + template.health;
+				var [entLimit, entCount, canBeAddedCount] =
+					getEntityLimitAndCount(playerState, entType);
+				tooltip += formatLimitString(entLimit, entCount);
 
 				break;
 
@@ -528,7 +523,7 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 		var affordableMask = getGUIObjectByName("unit"+guiName+"Unaffordable["+i+"]");
 		var affordableMask1 = getGUIObjectByName("unit"+guiName+"Unaffordable["+(i+rowLength)+"]");
 		var icon = getGUIObjectByName("unit"+guiName+"Icon["+i+"]");
-		var selection = getGUIObjectByName("unit"+guiName+"Selection["+i+"]");
+		var guiSelection = getGUIObjectByName("unit"+guiName+"Selection["+i+"]");
 		var pair = getGUIObjectByName("unit"+guiName+"Pair["+i+"]");
 		button.hidden = false;
 		button.tooltip = tooltip;
@@ -577,17 +572,13 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 		// Get icon image
 		if (guiName == FORMATION)
 		{
-			var formationOk = Engine.GuiInterfaceCall("CanMoveEntsIntoFormation", {
-				"ents": g_Selection.toList(),
-				"formationName": item
-			});
-
+			var formationOk = canMoveSelectionIntoFormation(item);
 			var grayscale = "";
 			button.enabled = formationOk;
 			if (!formationOk)
  			{
 				grayscale = "grayscale:";
-				
+
 				// Display a meaningful tooltip why the formation is disabled
 				var requirements = Engine.GuiInterfaceCall("GetFormationRequirements", {
 					"formationName": item
@@ -612,9 +603,9 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 				"formationName": item
 			});
 
-			selection.hidden = !formationSelected;
+			guiSelection.hidden = !formationSelected;
 			icon.sprite = "stretched:"+grayscale+"session/icons/formations/"+item.replace(/\s+/,'').toLowerCase()+".png";
-			
+
  		}
 		else if (guiName == STANCE)
 		{
@@ -623,7 +614,7 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 				"stance": item
 			});
 
-			selection.hidden = !stanceSelected;
+			guiSelection.hidden = !stanceSelected;
 			icon.sprite = "stretched:session/icons/stances/"+item+".png";
 		}
 		else if (guiName == COMMAND)
@@ -637,14 +628,14 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 			if (item.gate)
 			{
 				gateIcon = "icons/lock_" + GATE_ACTIONS[item.locked ? 0 : 1].toLowerCase() + "ed.png";
-				selection.hidden = item.gate.locked === undefined ? false : item.gate.locked != item.locked;
+				guiSelection.hidden = item.gate.locked === undefined ? false : item.gate.locked != item.locked;
 			}
 			// otherwise show gate upgrade icon
 			else
 			{
 				template = GetTemplateData(item.template);
 				gateIcon = template.icon ?  "portraits/" + template.icon : "icons/gate_closed.png";
-				selection.hidden = true;
+				guiSelection.hidden = true;
 			}
 
 			icon.sprite = "stretched:session/" + gateIcon;
@@ -669,7 +660,7 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 			button.enabled = true;
 			if (affordableMask)
 				affordableMask.hidden = true;	// actually used for the red "lack of resource" overlay, and darkening if unavailable. Sort of a hack.
-	
+
 			// In case this is an icon that would require tech checking, make sure we have the requirements.
 			if (guiName != SELECTION && guiName != GARRISON && guiName != QUEUE && template.requiredTechnology && !Engine.GuiInterfaceCall("IsTechnologyResearched", template.requiredTechnology))
 			{
@@ -677,21 +668,45 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 				var techName = getEntityNames(GetTechnologyData(template.requiredTechnology));
 				button.tooltip += "\nRequires " + techName;
 				grayscale = "grayscale:";
-                affordableMask.hidden = false;
+				affordableMask.hidden = false;
 				affordableMask.sprite = "colour: 0 0 0 127";
 			}
-			
+
 			if (guiName == RESEARCH && !Engine.GuiInterfaceCall("CheckTechnologyRequirements", entType))
 			{
 				button.enabled = false;
 				button.tooltip += "\n" + GetTechnologyData(entType).requirementsTooltip;
 				grayscale = "grayscale:";
-                affordableMask.hidden = false;
+				affordableMask.hidden = false;
 				affordableMask.sprite = "colour: 0 0 0 127";
 			}
-			
+
+			if ((guiName == CONSTRUCTION || guiName == TRAINING) && canBeAddedCount == 0)
+			{
+				grayscale = "grayscale:";
+				affordableMask.hidden = false;
+				affordableMask.sprite = "colour: 0 0 0 127";
+			}
+
+			if (guiName == GARRISON)
+			{
+				var ents = garrisonGroups.getEntsByName(item);
+				var entplayer = GetEntityState(ents[0]).player;
+				button.sprite = "colour: " + g_Players[entplayer].color.r + " " + g_Players[entplayer].color.g + " " + g_Players[entplayer].color.b;
+
+				var player = Engine.GetPlayerID();
+				if(player != unitEntState.player && !g_DevSettings.controlAll)
+				{
+					if (entplayer != player)
+					{
+						button.enabled = false;
+						grayscale = "grayscale:";
+					}
+				}
+			}
+
 			icon.sprite = "stretched:" + grayscale + "session/portraits/" + template.icon;
-			
+
 			if (guiName == RESEARCH)
 			{
 				// Check resource requirements
@@ -702,7 +717,7 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 					{
 						button.enabled = false;
 						affordableMask.hidden = false;
-						
+
 						var totalCost = 0;
 						for each (var resource in neededResources)
 							totalCost += resource;
@@ -724,7 +739,7 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 						button1.enabled = false;
 						button1.tooltip += "\n" + GetTechnologyData(entType1).requirementsTooltip;
 						grayscale = "grayscale:";
-                        affordableMask1.hidden = false;
+						affordableMask1.hidden = false;
 						affordableMask1.sprite = "colour: 0 0 0 127";
 					}
 					icon1.sprite = "stretched:" + grayscale + "session/portraits/" +template1.icon;
@@ -760,20 +775,9 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 				var totalCosts = {};
 				var trainNum = 1;
 				var button_disableable = true;
+
 				if (guiName == TRAINING)
 				{
-					var trainingCategory = null;
-					if (template.trainingRestrictions)
-						trainingCategory = template.trainingRestrictions.category;
-					if (trainingCategory && playerState.entityLimits[trainingCategory] &&
-						playerState.entityCounts[trainingCategory] >= playerState.entityLimits[trainingCategory])
-					{
-						grayscale = "grayscale:";
-                        affordableMask.hidden = false;
-						affordableMask.sprite = "colour: 0 0 0 100";
-					}
-					icon.sprite = "stretched:" + grayscale + "session/portraits/" + template.icon;
-
 					if (Engine.HotkeyIsPressed("session.batchtrain"))
 					{
 						var [buildingsCountToTrainFullBatch, fullBatchSize, remainderBatch, batchTrainingCount] =
@@ -794,14 +798,18 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 					if (button.enabled !== false)
 					{
 						button.enabled = (button_disableable ? false : true);
-						affordableMask.hidden = false;
+						// Don't display the red overlay if we can't even train/build it
+						if (canBeAddedCount != 0)
+						{
+							affordableMask.hidden = false;
 
-						var totalCost = 0;
-						for each (var resource in neededResources)
-							totalCost += resource;
-						var alpha = 50 + totalCost/10;
-						alpha = alpha > 125 ? 125 : alpha;
-						affordableMask.sprite = "colour: 255 0 0 " + (alpha);
+							var totalCost = 0;
+							for each (var resource in neededResources)
+								totalCost += resource;
+							var alpha = 50 + totalCost/10;
+							alpha = alpha > 125 ? 125 : alpha;
+							affordableMask.sprite = "colour: 255 0 0 " + (alpha);
+						}
 					}
 					button.tooltip += getNeededResourcesTooltip(neededResources);
 				}
@@ -826,7 +834,7 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 		buttonSideLength = getGUIObjectByName("unit"+guiName+"Button["+(rowLength*numRows)+"]").size.bottom;
 
 	var buttonSpacer = buttonSideLength+1;
-	
+
 	// Layout buttons
 	if (guiName == COMMAND)
 	{
@@ -847,7 +855,7 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 		for (var i = 0; i < numRows; i++)
 			layoutButtonRow(i, guiName, buttonSideLength, buttonSpacer, rowLength*i, rowLength*(i+1) );
 	}
-	
+
 	// Layout pair icons
 	if (guiName == RESEARCH)
 	{
@@ -870,13 +878,13 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, c
 	}
 
 	// Hide any buttons we're no longer using
-	for (i = numButtons; i < g_unitPanelButtons[guiName]; ++i)
+	for (var i = numButtons; i < g_unitPanelButtons[guiName]; ++i)
 		getGUIObjectByName("unit"+guiName+"Button["+i+"]").hidden = true;
 
 	// Hide unused pair buttons and symbols
 	if (guiName == RESEARCH)
 	{
-		for (i = numButtons; i < g_unitPanelButtons[guiName]; ++i)
+		for (var i = numButtons; i < g_unitPanelButtons[guiName]; ++i)
 		{
 			getGUIObjectByName("unit"+guiName+"Button["+(i+rowLength)+"]").hidden = true;
 			getGUIObjectByName("unit"+guiName+"Pair["+i+"]").hidden = true;
@@ -961,7 +969,7 @@ function setupUnitBarterPanel(unitEntState, playerState)
 				if (i == g_barterSell)
 				{
 					amount = "-" + amountToSell;
-					
+
 					var neededRes = {};
 					neededRes[resource] = amountToSell;
 					var neededResources = Engine.GuiInterfaceCall("GetNeededResources", neededRes);
@@ -990,7 +998,7 @@ function setupUnitBarterPanel(unitEntState, playerState)
  * Updates the right hand side "Unit Commands" panel. Runs in the main session loop via updateSelectionDetails().
  * Delegates to setupUnitPanel to set up individual subpanels, appropriately activated depending on the selected
  * unit's state.
- * 
+ *
  * @param entState Entity state of the (first) selected unit.
  * @param supplementalDetailsPanel Reference to the "supplementalSelectionDetails" GUI Object
  * @param commandsPanel Reference to the "commandsPanel" GUI Object
@@ -1003,13 +1011,14 @@ function updateUnitCommands(entState, supplementalDetailsPanel, commandsPanel, s
 
 	// If the selection is friendly units, add the command panels
 	var player = Engine.GetPlayerID();
+
+	// Get player state to check some constraints
+	// e.g. presence of a hero or build limits
+	var simState = GetSimState();
+	var playerState = simState.players[player];
+
 	if (entState.player == player || g_DevSettings.controlAll)
 	{
-		// Get player state to check some constraints
-		// e.g. presence of a hero or build limits
-		var simState = Engine.GuiInterfaceCall("GetSimulationState");
-		var playerState = simState.players[player];
-
 		if (selection.length > 1)
 			setupUnitPanel(SELECTION, usedPanels, entState, playerState, g_Selection.groups.getTemplateNames(),
 				function (entType, rightPressed) { changePrimarySelectionGroup(entType, rightPressed); } );
@@ -1024,7 +1033,7 @@ function updateUnitCommands(entState, supplementalDetailsPanel, commandsPanel, s
 			var groups = new EntityGroups();
 			for (var i in selection)
 			{
-				state = GetEntityState(selection[i]);
+				var state = GetEntityState(selection[i]);
 				if (state.garrisonHolder)
 					groups.add(state.garrisonHolder.entities)
 			}
@@ -1056,15 +1065,16 @@ function updateUnitCommands(entState, supplementalDetailsPanel, commandsPanel, s
 			setupUnitBarterPanel(entState, playerState);
 		}
 
-		var buildableEnts = getAllBuildableEntities(selection);
-		var trainableEnts = getAllTrainableEntities(selection);
+		var buildableEnts = getAllBuildableEntitiesFromSelection();
+		var trainableEnts = getAllTrainableEntitiesFromSelection();
 
 		// Whether the GUI's right panel has been filled.
 		var rightUsed = true;
 
 		// The first selected entity's type has priority.
 		if (entState.buildEntities)
-			setupUnitPanel(CONSTRUCTION, usedPanels, entState, playerState, buildableEnts, startBuildingPlacement);
+			setupUnitPanel(CONSTRUCTION, usedPanels, entState, playerState, buildableEnts,
+				function (trainEntType) { startBuildingPlacement(trainEntType, playerState); } );
 		else if (entState.production && entState.production.entities)
 			setupUnitPanel(TRAINING, usedPanels, entState, playerState, trainableEnts,
 				function (trainEntType) { addTrainingToQueue(selection, trainEntType, playerState); } );
@@ -1078,7 +1088,7 @@ function updateUnitCommands(entState, supplementalDetailsPanel, commandsPanel, s
 			var gates = [];
 			for (var i in selection)
 			{
-				state = GetEntityState(selection[i]);
+				var state = GetEntityState(selection[i]);
 				if (hasClass(state, "LongWall") && !state.gate && !longWallTypes[state.template])
 				{
 					var gateTemplate = getWallGateTemplate(state.id);
@@ -1170,7 +1180,8 @@ function updateUnitCommands(entState, supplementalDetailsPanel, commandsPanel, s
 			// The right pane is empty. Fill the pane with a sane type.
 			// Prefer buildables for units and trainables for structures.
 			if (buildableEnts.length && (hasClass(entState, "Unit") || !trainableEnts.length))
-				setupUnitPanel(CONSTRUCTION, usedPanels, entState, playerState, buildableEnts, startBuildingPlacement);
+				setupUnitPanel(CONSTRUCTION, usedPanels, entState, playerState, buildableEnts,
+					function (trainEntType) { startBuildingPlacement(trainEntType, playerState); });
 			else if (trainableEnts.length)
 				setupUnitPanel(TRAINING, usedPanels, entState, playerState, trainableEnts,
 					function (trainEntType) { addTrainingToQueue(selection, trainEntType, playerState); } );
@@ -1187,10 +1198,34 @@ function updateUnitCommands(entState, supplementalDetailsPanel, commandsPanel, s
 		if (entState.production && entState.production.queue.length)
 			setupUnitPanel(QUEUE, usedPanels, entState, playerState, entState.production.queue,
 				function (item) { removeFromProductionQueue(entState.id, item.id); } );
-		
+
 		supplementalDetailsPanel.hidden = false;
 		commandsPanel.hidden = false;
 	}
+	else if (playerState.isMutualAlly[entState.player]) // owned by allied player
+	{
+		if (entState.garrisonHolder)
+		{
+			var groups = new EntityGroups();
+			for (var i in selection)
+			{
+				var state = GetEntityState(selection[i]);
+				if (state.garrisonHolder)
+					groups.add(state.garrisonHolder.entities)
+			}
+
+			setupUnitPanel(GARRISON, usedPanels, entState, playerState, groups.getTemplateNames(),
+				function (item) { unloadTemplate(item); } );
+
+			supplementalDetailsPanel.hidden = false;
+		}
+		else
+		{
+			supplementalDetailsPanel.hidden = true;
+		}
+
+		commandsPanel.hidden = true;
+	}
 	else // owned by another player
 	{
 		supplementalDetailsPanel.hidden = true;
@@ -1227,12 +1262,20 @@ function getAllTrainableEntities(selection)
 		if ((state = GetEntityState(selection[i])) && state.production && state.production.entities.length)
 			trainableEnts = trainableEnts.concat(state.production.entities);
 	}
-	
+
 	// Remove duplicates
 	removeDupes(trainableEnts);
 	return trainableEnts;
 }
 
+function getAllTrainableEntitiesFromSelection()
+{
+	if (!g_allTrainableEntities)
+		g_allTrainableEntities = getAllTrainableEntities(g_Selection.toList());
+
+	return g_allTrainableEntities;
+}
+
 // Get all of the available entities which can be built by the selected entities
 function getAllBuildableEntities(selection)
 {
@@ -1244,8 +1287,29 @@ function getAllBuildableEntities(selection)
 		if ((state = GetEntityState(selection[i])) && state.buildEntities && state.buildEntities.length)
 			buildableEnts = buildableEnts.concat(state.buildEntities);
 	}
-	
+
 	// Remove duplicates
 	removeDupes(buildableEnts);
 	return buildableEnts;
 }
+
+function getAllBuildableEntitiesFromSelection()
+{
+	if (!g_allBuildableEntities)
+		g_allBuildableEntities = getAllBuildableEntities(g_Selection.toList());
+
+	return g_allBuildableEntities;
+}
+
+// Check if the selection can move into formation, and cache the result
+function canMoveSelectionIntoFormation(formationName)
+{
+	if (!(formationName in g_canMoveIntoFormation))
+	{
+		g_canMoveIntoFormation[formationName] = Engine.GuiInterfaceCall("CanMoveEntsIntoFormation", {
+			"ents": g_Selection.toList(),
+			"formationName": formationName
+		});
+	}
+	return g_canMoveIntoFormation[formationName];
+}
