@@ -37,7 +37,7 @@ function getPlayerData(playerAssignments)
 {
 	var players = [];
 
-	var simState = Engine.GuiInterfaceCall("GetSimulationState");
+	var simState = GetSimState();
 	if (!simState)
 		return players;
 
@@ -48,9 +48,9 @@ function getPlayerData(playerAssignments)
 		var name = playerState.name;
 		var civ = playerState.civ;
 		var color = {
-		    "r": playerState.colour.r*255, 
-		    "g": playerState.colour.g*255, 
-		    "b": playerState.colour.b*255, 
+		    "r": playerState.colour.r*255,
+		    "g": playerState.colour.g*255,
+		    "b": playerState.colour.b*255,
 		    "a": playerState.colour.a*255
 		};
 
@@ -60,8 +60,10 @@ function getPlayerData(playerAssignments)
 		    "color": color,
 		    "team": playerState.team,
 		    "teamsLocked": playerState.teamsLocked,
+		    "cheatsEnabled": playerState.cheatsEnabled,
 		    "state": playerState.state,
 		    "isAlly": playerState.isAlly,
+		    "isMutualAlly": playerState.isMutualAlly,
 		    "isNeutral": playerState.isNeutral,
 		    "isEnemy": playerState.isEnemy,
 		    "guid": undefined, // network guid for players controlled by hosts
@@ -87,18 +89,6 @@ function getPlayerData(playerAssignments)
 	return players;
 }
 
-// Returns whether a player has physical allies.
-function hasAllies(playerID, playerData)
-{
-	if (playerData[playerID] && playerData[playerID].team != -1)
-	{
-		for (var i = 0; i < playerData.length; i++)
-			if (playerData[i].team == playerData[playerID].team)
-				return true;
-	}
-	return false;
-}
-
 function findGuidForPlayerID(playerAssignments, player)
 {
 	for (var playerGuid in playerAssignments)
@@ -176,6 +166,42 @@ function damageTypeDetails(dmg)
 	}
 }
 
+// Converts an armor level into the actual reduction percentage
+function armorLevelToPercentage(level)
+{
+	return 100 - Math.round(Math.pow(0.9, level) * 100);
+}
+
+// Also for the unit details panel
+function armorTypeDetails(dmg)
+{
+	if (dmg)
+	{
+		var dmgArray = [];
+		if (dmg.hack)
+		{
+			dmgArray.push(dmg.hack + "[font=\"sans-10\"][color=\"orange\"] Hack[/color][/font] " +
+				" [font=\"sans-10\"](" + armorLevelToPercentage(dmg.hack) + "%)[/font]");
+		}
+		if (dmg.pierce)
+		{
+			dmgArray.push(dmg.pierce + "[font=\"sans-10\"][color=\"orange\"] Pierce[/color][/font] " +
+				" [font=\"sans-10\"](" + armorLevelToPercentage(dmg.pierce) + "%)[/font]");
+		}
+		if (dmg.crush)
+		{
+			dmgArray.push(dmg.crush + "[font=\"sans-10\"][color=\"orange\"] Crush[/color][/font] " +
+				" [font=\"sans-10\"](" + armorLevelToPercentage(dmg.crush) + "%)[/font]");
+		}
+
+		return dmgArray.join(", ");
+	}
+	else
+	{
+		return "[font=\"serif-12\"](None)[/font]";
+	}
+}
+
 // For the training tooltip
 function damageTypesToText(dmg)
 {
@@ -189,6 +215,27 @@ function damageTypesToText(dmg)
 	var pierceDamage = dmg.pierce;
 	var crushDamage = dmg.crush;
 
+	var dmgArray = [];
+	if (hackDamage) dmgArray.push(Math.round(hackDamage) + hackLabel);
+	if (pierceDamage) dmgArray.push(Math.round(pierceDamage) + pierceLabel);
+	if (crushDamage) dmgArray.push(Math.round(crushDamage) + crushLabel);
+
+	return dmgArray.join("[font=\"serif-12\"], [/font]");
+}
+
+// Also for the training tooltip
+function armorTypesToText(dmg)
+{
+	if (!dmg)
+		return "[font=\"serif-12\"](None)[/font]";
+
+	var hackDamage = dmg.hack;
+	var pierceDamage = dmg.pierce;
+	var crushDamage = dmg.crush;
+	var hackLabel = "[font=\"serif-12\"] Hack (" + armorLevelToPercentage(hackDamage) + "%)[/font]";
+	var pierceLabel = "[font=\"serif-12\"] Pierce (" + armorLevelToPercentage(pierceDamage) + "%)[/font]";
+	var crushLabel = "[font=\"serif-12\"] Crush (" + armorLevelToPercentage(crushDamage) + "%)[/font]";
+
 	var dmgArray = [];
 	if (hackDamage) dmgArray.push(hackDamage + hackLabel);
 	if (pierceDamage) dmgArray.push(pierceDamage + pierceLabel);
@@ -246,6 +293,33 @@ function getEntityCommandsList(entState)
 		    "icon": "focus-rally.png"
 		});
 	}
+	
+	if (entState.unitAI && entState.unitAI.hasWorkOrders)
+	{
+		commands.push({
+		    "name": "back-to-work",
+		    "tooltip": "Back to Work",
+		    "icon": "production.png"
+		});
+	}
+
+	if (entState.unitAI && entState.unitAI.canGuard && !entState.unitAI.isGuarding)
+	{
+		commands.push({
+		    "name": "add-guard",
+		    "tooltip": "Guard",
+		    "icon": "add-guard.png"
+		});
+	}
+
+	if (entState.unitAI && entState.unitAI.isGuarding)
+	{
+		commands.push({
+		    "name": "remove-guard",
+		    "tooltip": "Remove guard",
+		    "icon": "remove-guard.png"
+		});
+	}
 
 	return commands;
 }
@@ -355,7 +429,7 @@ function getWallPieceTooltip(wallTypes)
  */
 function getEntityCostTooltip(template, trainNum, entity)
 {
-	var cost = "[font=\"serif-bold-13\"]Costs:[/font] ";
+	var cost = "";
 
 	// Entities with a wallset component are proxies for initiating wall placement and as such do not have a cost of
 	// their own; the individual wall pieces within it do.
@@ -465,7 +539,24 @@ function getEntityNames(template)
 
 function getEntityNamesFormatted(template)
 {
-	return '[font="serif-bold-16"]' + getEntityNames(template) + "[/font]";
+	var names = "";
+	var generic = template.name.generic;
+	var specific = template.name.specific;
+	if (specific)
+	{
+		// drop caps for specific name
+		names += '[font="serif-bold-16"]' + specific[0] + '[/font]' +
+			'[font="serif-bold-12"]' + specific.slice(1).toUpperCase() + '[/font]';
+
+		if (generic)
+			names += '[font="serif-bold-16"] (' + generic + ')[/font]';
+	}
+	else if (generic)
+		names = '[font="serif-bold-16"]' + generic + "[/font]";
+	else
+		names = "???";
+
+	return names;
 }
 
 function getEntityRankedName(entState)
@@ -489,3 +580,36 @@ function getRankIconSprite(entState)
 
 	return "";
 }
+
+/**
+ * Returns a message with the details of the trade gain.
+ */
+function getTradingTooltip(gain)
+{
+	var tooltip = gain.traderGain;
+	if (gain.market1Gain && gain.market1Owner == gain.traderOwner)
+		tooltip += "+" + gain.market1Gain;
+	if (gain.market2Gain && gain.market2Owner == gain.traderOwner)
+		tooltip += "+" + gain.market2Gain;
+	tooltip += " (you)";
+
+	if (gain.market1Gain && gain.market1Owner != gain.traderOwner)
+		tooltip += ", " + gain.market1Gain + " (player " + gain.market1Owner + ")";
+	if (gain.market2Gain && gain.market2Owner != gain.traderOwner)
+		tooltip += ", " + gain.market2Gain + " (player " + gain.market2Owner + ")";
+
+	return tooltip;
+}
+
+/**
+ * Returns the entity itself except when garrisoned where it returns its garrisonHolder
+ */
+function getEntityOrHolder(ent)
+{
+	var entState = GetEntityState(ent);
+	if (entState && !entState.position && entState.unitAI && entState.unitAI.orders.length > 0 &&
+			entState.unitAI.orders[0].type == "Garrison")
+		return entState.unitAI.orders[0].data.target;
+
+	return ent;
+}
