@@ -48,10 +48,9 @@ function init(data)
 	{
 		// load the map sizes from the JSON file
 		var mapSizes = initMapSizes();
-		var mapSizeIndex;
 
 		// retrieve the index of the map size
-		for (mapSizeIndex in mapSizes.tiles)
+		for (var mapSizeIndex in mapSizes.tiles)
 		{
 			if (mapSizes.tiles[mapSizeIndex] == data.mapSettings.Size)
 			{
@@ -196,7 +195,7 @@ function init(data)
 			militaryScore.size = left + " 2 " + (left + width) + " 100%"; left += width;
 			explorationScore.size = left + " 2 " + (left + width) + " 100%"; left += width;
 			totalScore.size = left + " 2 " + (left + width) + " 100%"; left += width;
-			size = getGUIObjectByName("playerBox0["+i+"]").size;
+			var size = getGUIObjectByName("playerBox0["+i+"]").size;
 			size.right = left + 10;
 			getGUIObjectByName("playerBox0["+i+"]").size = size;
 			
@@ -309,6 +308,4 @@ function init(data)
 
 function onTick()
 {
-	// Update music state
-	global.music.updateTimer();
 }
